#This script performs a leave one out cross validation on the thermal resource predictions. 
#Load in the output from StratifiedKrigingInterpolation.R to use this script.


library(sp)
library(gstat)
library(rgdal)
library(spdep)
library(maptools)
library(graphics)
library(lattice)
library(qualityTools)
library(MASS)
library(GISTools)
library(latticeExtra)


######################################
#Cross Validation# LOOCV
######################################

#Heat Flow
kcv.CT = krige.cv(Qs~1, locations = CT, model = vmf.CT, maxdist=50000, nmin = 5, nmax = 50)
kcv.CNY = krige.cv(Qs~1, locations = CNY, model = vmf.CNY, maxdist=50000, nmin = 5, nmax = 50)
kcv.CWV = krige.cv(Qs~1, locations = CWV, model = vmf.CWV, maxdist=50000, nmin = 5, nmax = 50)
kcv.ENY = krige.cv(Qs~1, locations = ENY, model = vmf.ENY, maxdist=50000, nmin = 5, nmax = 50)
kcv.ENYPA = krige.cv(Qs~1, locations = ENYPA, model = vmf.ENYPA, maxdist=50000, nmin = 5, nmax = 50)
kcv.MT = krige.cv(Qs~1, locations = MT, model = vmf.MT, maxdist=50000, nmin = 5, nmax = 50)
kcv.NWPANY = krige.cv(Qs~1, locations = NWPANY, model = vmf.NWPANY, maxdist=50000, nmin = 5, nmax = 50)
kcv.SWPA = krige.cv(Qs~1, locations = SWPA, model = vmf.SWPA, maxdist=50000, nmin = 5, nmax = 50)
kcv.WPA = krige.cv(Qs~1, locations = WPA, model = vmf.WPA, maxdist=50000, nmin = 5, nmax = 50) 

writePointsShape(kcv.CT,"kcv_CT.shp")
writePointsShape(kcv.CNY,"kcv_CNY.shp")
writePointsShape(kcv.CWV,"kcv_CWV.shp")
writePointsShape(kcv.ENY,"kcv_ENY.shp")
writePointsShape(kcv.ENYPA,"kcv_ENYPA.shp")
writePointsShape(kcv.MT,"kcv_MT.shp")
writePointsShape(kcv.NWPANY,"kcv_NWPANY.shp")
writePointsShape(kcv.SWPA,"kcv_SWPA.shp")
writePointsShape(kcv.WPA,"kcv_WPA.shp")


#Depth 80 C
kcv.CT = krige.cv(Dpth80C~1, locations = CT, model = vmf.CT, maxdist=50000, nmin = 5, nmax = 50)
kcv.CNY = krige.cv(Dpth80C~1, locations = CNY, model = vmf.CNY, maxdist=50000, nmin = 5, nmax = 50)
kcv.CWV = krige.cv(Dpth80C~1, locations = CWV, model = vmf.CWV, maxdist=50000, nmin = 5, nmax = 50)
kcv.ENY = krige.cv(Dpth80C~1, locations = ENY, model = vmf.ENY, maxdist=50000, nmin = 5, nmax = 50)
kcv.ENYPA = krige.cv(Dpth80C~1, locations = ENYPA, model = vmf.ENYPA, maxdist=50000, nmin = 5, nmax = 50)
kcv.MT = krige.cv(Dpth80C~1, locations = MT, model = vmf.MT, maxdist=50000, nmin = 5, nmax = 50)
kcv.NWPANY = krige.cv(Dpth80C~1, locations = NWPANY, model = vmf.NWPANY, maxdist=50000, nmin = 5, nmax = 50)
kcv.SWPA = krige.cv(Dpth80C~1, locations = SWPA, model = vmf.SWPA, maxdist=50000, nmin = 5, nmax = 50)
kcv.WPA = krige.cv(Dpth80C~1, locations = WPA, model = vmf.WPA, maxdist=50000, nmin = 5, nmax = 50) 

writePointsShape(kcv.CT,"kcv_CT_D80C.shp")
writePointsShape(kcv.CNY,"kcv_CNY_D80C.shp")
writePointsShape(kcv.CWV,"kcv_CWV_D80C.shp")
writePointsShape(kcv.ENY,"kcv_ENY_D80C.shp")
writePointsShape(kcv.ENYPA,"kcv_ENYPA_D80C.shp")
writePointsShape(kcv.MT,"kcv_MT_D80C.shp")
writePointsShape(kcv.NWPANY,"kcv_NWPANY_D80C.shp")
writePointsShape(kcv.SWPA,"kcv_SWPA_D80C.shp")
writePointsShape(kcv.WPA,"kcv_WPA_D80C.shp")


#Depth 100 C
kcv.CT = krige.cv(Dpt100C~1, locations = CT, model = vmf.CT, maxdist=50000, nmin = 5, nmax = 50)
kcv.CNY = krige.cv(Dpt100C~1, locations = CNY, model = vmf.CNY, maxdist=50000, nmin = 5, nmax = 50)
kcv.CWV = krige.cv(Dpt100C~1, locations = CWV, model = vmf.CWV, maxdist=50000, nmin = 5, nmax = 50)
kcv.ENY = krige.cv(Dpt100C~1, locations = ENY, model = vmf.ENY, maxdist=50000, nmin = 5, nmax = 50)
kcv.ENYPA = krige.cv(Dpt100C~1, locations = ENYPA, model = vmf.ENYPA, maxdist=50000, nmin = 5, nmax = 50)
kcv.MT = krige.cv(Dpt100C~1, locations = MT, model = vmf.MT, maxdist=50000, nmin = 5, nmax = 50)
kcv.NWPANY = krige.cv(Dpt100C~1, locations = NWPANY, model = vmf.NWPANY, maxdist=50000, nmin = 5, nmax = 50)
kcv.SWPA = krige.cv(Dpt100C~1, locations = SWPA, model = vmf.SWPA, maxdist=50000, nmin = 5, nmax = 50)
kcv.WPA = krige.cv(Dpt100C~1, locations = WPA, model = vmf.WPA, maxdist=50000, nmin = 5, nmax = 50) 

writePointsShape(kcv.CT,"kcv_CT_D100C.shp")
writePointsShape(kcv.CNY,"kcv_CNY_D100C.shp")
writePointsShape(kcv.CWV,"kcv_CWV_D100C.shp")
writePointsShape(kcv.ENY,"kcv_ENY_D100C.shp")
writePointsShape(kcv.ENYPA,"kcv_ENYPA_D100C.shp")
writePointsShape(kcv.MT,"kcv_MT_D100C.shp")
writePointsShape(kcv.NWPANY,"kcv_NWPANY_D100C.shp")
writePointsShape(kcv.SWPA,"kcv_SWPA_D100C.shp")
writePointsShape(kcv.WPA,"kcv_WPA_D100C.shp")


#Temp 1.5 km
kcv.CT = krige.cv(Tmp1_5k~1, locations = CT, model = vmf.CT, maxdist=50000, nmin = 5, nmax = 50)
kcv.CNY = krige.cv(Tmp1_5k~1, locations = CNY, model = vmf.CNY, maxdist=40000, nmin = 5, nmax = 50)
kcv.CWV = krige.cv(Tmp1_5k~1, locations = CWV, model = vmf.CWV, maxdist=50000, nmin = 5, nmax = 50)
kcv.ENY = krige.cv(Tmp1_5k~1, locations = ENY, model = vmf.ENY, maxdist=50000, nmin = 5, nmax = 50)
kcv.ENYPA = krige.cv(Tmp1_5k~1, locations = ENYPA, model = vmf.ENYPA, maxdist=50000, nmin = 5, nmax = 50)
kcv.MT = krige.cv(Tmp1_5k~1, locations = MT, model = vmf.MT, maxdist=50000, nmin = 5, nmax = 50)
kcv.NWPANY = krige.cv(Tmp1_5k~1, locations = NWPANY, model = vmf.NWPANY, maxdist=50000, nmin = 5, nmax = 50)
kcv.SWPA = krige.cv(Tmp1_5k~1, locations = SWPA, model = vmf.SWPA, maxdist=50000, nmin = 5, nmax = 50)
kcv.WPA = krige.cv(Tmp1_5k~1, locations = WPA, model = vmf.WPA, maxdist=50000, nmin = 5, nmax = 50) 

writePointsShape(kcv.CT,"kcv_CT_T1p5.shp")
writePointsShape(kcv.CNY,"kcv_CNY_T1p5.shp")
writePointsShape(kcv.CWV,"kcv_CWV_T1p5.shp")
writePointsShape(kcv.ENY,"kcv_ENY_T1p5.shp")
writePointsShape(kcv.ENYPA,"kcv_ENYPA_T1p5.shp")
writePointsShape(kcv.MT,"kcv_MT_T1p5.shp")
writePointsShape(kcv.NWPANY,"kcv_NWPANY_T1p5.shp")
writePointsShape(kcv.SWPA,"kcv_SWPA_T1p5.shp")
writePointsShape(kcv.WPA,"kcv_WPA_T1p5.shp")


#Temp 2.5 km
kcv.CT = krige.cv(Tmp2_5k~1, locations = CT, model = vmf.CT, maxdist=50000, nmin = 5, nmax = 50)
kcv.CNY = krige.cv(Tmp2_5k~1, locations = CNY, model = vmf.CNY, maxdist=50000, nmin = 5, nmax = 50)
kcv.CWV = krige.cv(Tmp2_5k~1, locations = CWV, model = vmf.CWV, maxdist=50000, nmin = 5, nmax = 50)
kcv.ENY = krige.cv(Tmp2_5k~1, locations = ENY, model = vmf.ENY, maxdist=50000, nmin = 5, nmax = 50)
kcv.ENYPA = krige.cv(Tmp2_5k~1, locations = ENYPA, model = vmf.ENYPA, maxdist=50000, nmin = 5, nmax = 50)
kcv.MT = krige.cv(Tmp2_5k~1, locations = MT, model = vmf.MT, maxdist=50000, nmin = 5, nmax = 50)
kcv.NWPANY = krige.cv(Tmp2_5k~1, locations = NWPANY, model = vmf.NWPANY, maxdist=50000, nmin = 5, nmax = 50)
kcv.SWPA = krige.cv(Tmp2_5k~1, locations = SWPA, model = vmf.SWPA, maxdist=50000, nmin = 5, nmax = 50)
kcv.WPA = krige.cv(Tmp2_5k~1, locations = WPA, model = vmf.WPA, maxdist=50000, nmin = 5, nmax = 50) 

writePointsShape(kcv.CT,"kcv_CT_T2p5.shp")
writePointsShape(kcv.CNY,"kcv_CNY_T2p5.shp")
writePointsShape(kcv.CWV,"kcv_CWV_T2p5.shp")
writePointsShape(kcv.ENY,"kcv_ENY_T2p5.shp")
writePointsShape(kcv.ENYPA,"kcv_ENYPA_T2p5.shp")
writePointsShape(kcv.MT,"kcv_MT_T2p5.shp")
writePointsShape(kcv.NWPANY,"kcv_NWPANY_T2p5.shp")
writePointsShape(kcv.SWPA,"kcv_SWPA_T2p5.shp")
writePointsShape(kcv.WPA,"kcv_WPA_T2p5.shp")


#Temp 3.5 km
kcv.CT = krige.cv(Tmp3_5k~1, locations = CT, model = vmf.CT, maxdist=50000, nmin = 5, nmax = 50)
kcv.CNY = krige.cv(Tmp3_5k~1, locations = CNY, model = vmf.CNY, maxdist=50000, nmin = 5, nmax = 50)
kcv.CWV = krige.cv(Tmp3_5k~1, locations = CWV, model = vmf.CWV, maxdist=50000, nmin = 5, nmax = 50)
kcv.ENY = krige.cv(Tmp3_5k~1, locations = ENY, model = vmf.ENY, maxdist=50000, nmin = 5, nmax = 50)
kcv.ENYPA = krige.cv(Tmp3_5k~1, locations = ENYPA, model = vmf.ENYPA, maxdist=50000, nmin = 5, nmax = 50)
kcv.MT = krige.cv(Tmp3_5k~1, locations = MT, model = vmf.MT, maxdist=50000, nmin = 5, nmax = 50)
kcv.NWPANY = krige.cv(Tmp3_5k~1, locations = NWPANY, model = vmf.NWPANY, maxdist=50000, nmin = 5, nmax = 50)
kcv.SWPA = krige.cv(Tmp3_5k~1, locations = SWPA, model = vmf.SWPA, maxdist=50000, nmin = 5, nmax = 50)
kcv.WPA = krige.cv(Tmp3_5k~1, locations = WPA, model = vmf.WPA, maxdist=50000, nmin = 5, nmax = 50) 

writePointsShape(kcv.CT,"kcv_CT_T3p5.shp")
writePointsShape(kcv.CNY,"kcv_CNY_T3p5.shp")
writePointsShape(kcv.CWV,"kcv_CWV_T3p5.shp")
writePointsShape(kcv.ENY,"kcv_ENY_T3p5.shp")
writePointsShape(kcv.ENYPA,"kcv_ENYPA_T3p5.shp")
writePointsShape(kcv.MT,"kcv_MT_T3p5.shp")
writePointsShape(kcv.NWPANY,"kcv_NWPANY_T3p5.shp")
writePointsShape(kcv.SWPA,"kcv_SWPA_T3p5.shp")
writePointsShape(kcv.WPA,"kcv_WPA_T3p5.shp")