##Jared Smith's Kriging for DOE Project##
##Date Last Modified: 09/06/2015##

#This code should only be run once the outlier analysis, negative gradients, and points in the same spatial location have been sorted
#using other functions developed as part of this project.
#Wells must be in UTM17N NAD83 coordinates for variograms to be in km units.


#REQUIRED TOOLS AND LIBRARIES##
library(sp)
library(gstat)
library(rgdal)
library(spdep)
library(maptools)
library(graphics)
library(lattice)
library(qualityTools)
library(MASS)
library(GISTools)
library(latticeExtra)

#Point file load, spatially referenced. Needs to be in UTM 17N coordinates for NAD83
#Heat Flow
CT = readOGR(dsn=getwd(), layer="WellsCT_1")
CNY = readOGR(dsn=getwd(), layer="WellsCNY_1")
CWV = readOGR(dsn=getwd(), layer="WellsCWV_1")
ENY = readOGR(dsn=getwd(), layer="WellsENY_1")
ENYPA = readOGR(dsn=getwd(), layer="WellsENYPA_1")
MT = readOGR(dsn=getwd(), layer="WellsMT_1")
NWPANY = readOGR(dsn=getwd(), layer="WellsNWPANY_1")  
SWPA = readOGR(dsn=getwd(), layer="WellsSWPA_1")
VR = readOGR(dsn=getwd(), layer="WellsVR_1")
WPA = readOGR(dsn=getwd(), layer="WellsWPA_1")

#Depth80C
CT = readOGR(dsn=getwd(), layer="WellsCT_1")
CNY = readOGR(dsn=getwd(), layer="WellsCNY_1")
CWV = readOGR(dsn=getwd(), layer="WellsCWV_1")
ENY = readOGR(dsn=getwd(), layer="WellsENY_1")
ENYPA = readOGR(dsn=getwd(), layer="WellsENYPA_1")
MT = readOGR(dsn=getwd(), layer="WellsMT_1")
NWPANY = readOGR(dsn=getwd(), layer="WellsNWPANY_1")  
SWPA = readOGR(dsn=getwd(), layer="WellsSWPA_1")
VR = readOGR(dsn=getwd(), layer="WellsVR_1")
WPA = readOGR(dsn=getwd(), layer="WellsWPA_1")

#Depth100C
CT = readOGR(dsn=getwd(), layer="WellsCT_1")
CNY = readOGR(dsn=getwd(), layer="WellsCNY_1")
CWV = readOGR(dsn=getwd(), layer="WellsCWV_1")
ENY = readOGR(dsn=getwd(), layer="WellsENY_1")
ENYPA = readOGR(dsn=getwd(), layer="WellsENYPA_1")
MT = readOGR(dsn=getwd(), layer="WellsMT_1")
NWPANY = readOGR(dsn=getwd(), layer="WellsNWPANY_1")  
SWPA = readOGR(dsn=getwd(), layer="WellsSWPA_1")
VR = readOGR(dsn=getwd(), layer="WellsVR_1")
WPA = readOGR(dsn=getwd(), layer="WellsWPA_1")

#Temp1.5km
CT = readOGR(dsn=getwd(), layer="WellsCT_1")
CNY = readOGR(dsn=getwd(), layer="WellsCNY_1")
CWV = readOGR(dsn=getwd(), layer="WellsCWV_1")
ENY = readOGR(dsn=getwd(), layer="WellsENY_1")
ENYPA = readOGR(dsn=getwd(), layer="WellsENYPA_1")
MT = readOGR(dsn=getwd(), layer="WellsMT_1")
NWPANY = readOGR(dsn=getwd(), layer="WellsNWPANY_1")  
SWPA = readOGR(dsn=getwd(), layer="WellsSWPA_1")
VR = readOGR(dsn=getwd(), layer="WellsVR_1")
WPA = readOGR(dsn=getwd(), layer="WellsWPA_1")

#Temp2.5km
CT = readOGR(dsn=getwd(), layer="WellsCT_1")
CNY = readOGR(dsn=getwd(), layer="WellsCNY_1")
CWV = readOGR(dsn=getwd(), layer="WellsCWV_1")
ENY = readOGR(dsn=getwd(), layer="WellsENY_1")
ENYPA = readOGR(dsn=getwd(), layer="WellsENYPA_1")
MT = readOGR(dsn=getwd(), layer="WellsMT_1")
NWPANY = readOGR(dsn=getwd(), layer="WellsNWPANY_1")  
SWPA = readOGR(dsn=getwd(), layer="WellsSWPA_1")
VR = readOGR(dsn=getwd(), layer="WellsVR_1")
WPA = readOGR(dsn=getwd(), layer="WellsWPA_1")

#Temp3.5km
CT = readOGR(dsn=getwd(), layer="WellsCT_1")
CNY = readOGR(dsn=getwd(), layer="WellsCNY_1")
CWV = readOGR(dsn=getwd(), layer="WellsCWV_1")
ENY = readOGR(dsn=getwd(), layer="WellsENY_1")
ENYPA = readOGR(dsn=getwd(), layer="WellsENYPA_1")
MT = readOGR(dsn=getwd(), layer="WellsMT_1")
NWPANY = readOGR(dsn=getwd(), layer="WellsNWPANY_1")  
SWPA = readOGR(dsn=getwd(), layer="WellsSWPA_1")
VR = readOGR(dsn=getwd(), layer="WellsVR_1")
WPA = readOGR(dsn=getwd(), layer="WellsWPA_1")

##Load the interpolation grid. 1 km grid cells. As rasters, they are already gridded. This is the easiest method.
grd.CT = readGDAL("grdct3")  
grd.CNY = readGDAL("grdcny3")
grd.CWV = readGDAL("grdcwv3")
grd.ENY = readGDAL("grdeny3")
grd.ENYPA = readGDAL("grdenypa3")
grd.MT = readGDAL("grdmt3")
grd.NWPANY = readGDAL("grdnwpany3")
grd.SWPA = readGDAL("grdswpa3")
grd.VR = readGDAL("grdvr3")
grd.WPA = readGDAL("grdwpa3")

#Project everything into the same coordinate system, even though they should all be in the same one.
proj4string(CT) = CRS("+init=epsg:26917")
proj4string(grd.CT) = CRS("+init=epsg:26917")
proj4string(CNY) = CRS("+init=epsg:26917")
proj4string(grd.CNY) = CRS("+init=epsg:26917")
proj4string(CWV) = CRS("+init=epsg:26917")
proj4string(grd.CWV) = CRS("+init=epsg:26917")
proj4string(ENY) = CRS("+init=epsg:26917")
proj4string(grd.ENY) = CRS("+init=epsg:26917")
proj4string(ENYPA) = CRS("+init=epsg:26917")
proj4string(grd.ENYPA) = CRS("+init=epsg:26917")
proj4string(MT) = CRS("+init=epsg:26917")
proj4string(grd.MT) = CRS("+init=epsg:26917")
proj4string(NWPANY) = CRS("+init=epsg:26917")
proj4string(grd.NWPANY) = CRS("+init=epsg:26917")
proj4string(SWPA) = CRS("+init=epsg:26917")
proj4string(grd.SWPA) = CRS("+init=epsg:26917")
proj4string(VR) = CRS("+init=epsg:26917")
proj4string(grd.VR) = CRS("+init=epsg:26917")
proj4string(WPA) = CRS("+init=epsg:26917")
proj4string(grd.WPA) = CRS("+init=epsg:26917")

#Double check that there are no points in the same spatial location. If there are, do not proceed until there are no duplicate locations.
#NWPANY
A = zerodist(NWPANY)
#CNY
B = zerodist(CNY)
#ENYPA
C = zerodist(ENYPA) 
#MT
D = zerodist(MT)
#CT
E = zerodist(CT)
#CWV
F = zerodist(CWV)
#ENY
G = zerodist(ENY)
#SWPA
H = zerodist(SWPA) 
#VR
I = zerodist(VR) 
#WPA
J = zerodist(WPA)

#Histograms of the data
#Heatflow
hist(CT$Qs)
hist(CNY$Qs)
hist(CWV$Qs) 
hist(ENY$Qs) 
hist(ENYPA$Qs)
hist(MT$Qs)
hist(NWPANY$Qs)
hist(SWPA$Qs)
hist(VR$Qs)
hist(WPA$Qs)

#Depth80C
hist(CT$Dpth80C)
hist(CNY$Dpth80C)
hist(CWV$Dpth80C) 
hist(ENY$Dpth80C) 
hist(ENYPA$Dpth80C)
hist(MT$Dpth80C)
hist(NWPANY$Dpth80C)
hist(SWPA$Dpth80C)
hist(VR$Dpth80C)
hist(WPA$Dpth80C)

#Depth100C
hist(CT$Dpt100C)
hist(CNY$Dpt100C)
hist(CWV$Dpt100C) 
hist(ENY$Dpt100C) 
hist(ENYPA$Dpt100C)
hist(MT$Dpt100C)
hist(NWPANY$Dpt100C)
hist(SWPA$Dpt100C)
hist(VR$Dpt100C)
hist(WPA$Dpt100C)

#Temp1.5km
hist(CT$Tmp1_5k)
hist(CNY$Tmp1_5k)
hist(CWV$Tmp1_5k) 
hist(ENY$Tmp1_5k) 
hist(ENYPA$Tmp1_5k)
hist(MT$Tmp1_5k)
hist(NWPANY$Tmp1_5k)
hist(SWPA$Tmp1_5k)
hist(VR$Tmp1_5k)
hist(WPA$Tmp1_5k)

#Temp2.5km
hist(CT$Tmp2_5k)
hist(CNY$Tmp2_5k)
hist(CWV$Tmp2_5k) 
hist(ENY$Tmp2_5k) 
hist(ENYPA$Tmp2_5k)
hist(MT$Tmp2_5k)
hist(NWPANY$Tmp2_5k)
hist(SWPA$Tmp2_5k)
hist(VR$Tmp2_5k)
hist(WPA$Tmp2_5k)

#Temp3.5km
hist(CT$Tmp3_5k)
hist(CNY$Tmp3_5k)
hist(CWV$Tmp3_5k) 
hist(ENY$Tmp3_5k) 
hist(ENYPA$Tmp3_5k)
hist(MT$Tmp3_5k)
hist(NWPANY$Tmp3_5k)
hist(SWPA$Tmp3_5k)
hist(VR$Tmp3_5k)
hist(WPA$Tmp3_5k)


##### Autocorrelation experimental (sample) variogram of gradient for each section
#cutoff = maximum distance at which pairs of data points will be considered for inclusion in sample variogram estimates
#width = cutoff distance divided by number of bins
#VR has points that are spread too far away to make a reliable variogram for the region.

#HeatFlow
(v.CT <- variogram(Qs~1, CT, cutoff=60000, width=60000/50)) 
(v.CNY <- variogram(Qs~1, CNY, cutoff=60000, width=60000/10)) 
(v.CWV <- variogram(Qs~1, CWV, cutoff=60000, width=60000/50)) 
(v.ENY <- variogram(Qs~1, ENY, cutoff=60000, width=60000/10)) 
(v.ENYPA <- variogram(Qs~1, ENYPA, cutoff=60000, width=60000/30))
(v.MT <- variogram(Qs~1, MT, cutoff=60000, width=60000/60))
(v.NWPANY <- variogram(Qs~1, NWPANY, cutoff=60000, width=60000/20)) 
(v.SWPA <- variogram(Qs~1, SWPA, cutoff=60000, width=60000/50)) 
#(v.VR <- variogram(Qs~1, VR, cutoff=60000, width=60000/48))
(v.WPA <- variogram(Qs~1, WPA, cutoff=60000, width=60000/50)) 

#Depth80C
(v.CT <- variogram(Dpth80C~1, CT, cutoff=80000, width=80000/60)) 
(v.CNY <- variogram(Dpth80C~1, CNY, cutoff=60000, width=60000/10)) 
(v.CWV <- variogram(Dpth80C~1, CWV, cutoff=60000, width=60000/50)) 
(v.ENY <- variogram(Dpth80C~1, ENY, cutoff=60000, width=60000/10)) 
(v.ENYPA <- variogram(Dpth80C~1, ENYPA, cutoff=60000, width=60000/30))
(v.MT <- variogram(Dpth80C~1, MT, cutoff=60000, width=60000/60)) 
(v.NWPANY <- variogram(Dpth80C~1, NWPANY, cutoff=60000, width=60000/20)) 
(v.SWPA <- variogram(Dpth80C~1, SWPA, cutoff=60000, width=60000/40)) 
#(v.VR <- variogram(Dpth80C~1, VR, cutoff=60000, width=60000/48))
(v.WPA <- variogram(Dpth80C~1, WPA, cutoff=60000, width=60000/40))

#Temp1.5km
(v.CT <- variogram(Tmp1_5k~1, CT, cutoff=50000, width=50000/40)) 
(v.CNY <- variogram(Tmp1_5k~1, CNY, cutoff=40000, width=40000/10)) 
(v.CWV <- variogram(Tmp1_5k~1, CWV, cutoff=60000, width=60000/60)) 
(v.ENY <- variogram(Tmp1_5k~1, ENY, cutoff=80000, width=80000/25)) 
(v.ENYPA <- variogram(Tmp1_5k~1, ENYPA, cutoff=60000, width=60000/30))
(v.MT <- variogram(Tmp1_5k~1, MT, cutoff=60000, width=60000/600)) 
(v.NWPANY <- variogram(Tmp1_5k~1, NWPANY, cutoff=60000, width=60000/30)) 
(v.SWPA <- variogram(Tmp1_5k~1, SWPA, cutoff=60000, width=60000/40)) 
#(v.VR <- variogram(Tmp1_5k~1, VR, cutoff=60000, width=60000/48))
(v.WPA <- variogram(Tmp1_5k~1, WPA, cutoff=60000, width=60000/40))

#Temp2.5km
(v.CT <- variogram(Tmp2_5k~1, CT, cutoff=80000, width=80000/40)) 
(v.CNY <- variogram(Tmp2_5k~1, CNY, cutoff=55000, width=55000/10)) 
(v.CWV <- variogram(Tmp2_5k~1, CWV, cutoff=60000, width=60000/60)) 
(v.ENY <- variogram(Tmp2_5k~1, ENY, cutoff=80000, width=80000/15)) 
(v.ENYPA <- variogram(Tmp2_5k~1, ENYPA, cutoff=60000, width=60000/30))
(v.MT <- variogram(Tmp2_5k~1, MT, cutoff=60000, width=60000/60)) 
(v.NWPANY <- variogram(Tmp2_5k~1, NWPANY, cutoff=50000, width=50000/20)) 
(v.SWPA <- variogram(Tmp2_5k~1, SWPA, cutoff=60000, width=60000/40)) 
#(v.VR <- variogram(Tmp2_5k~1, VR, cutoff=60000, width=60000/48))
(v.WPA <- variogram(Tmp2_5k~1, WPA, cutoff=60000, width=60000/40))

#Temp3.5km
(v.CT <- variogram(Tmp3_5k~1, CT, cutoff=50000, width=50000/40)) 
(v.CNY <- variogram(Tmp3_5k~1, CNY, cutoff=50000, width=50000/10)) 
(v.CWV <- variogram(Tmp3_5k~1, CWV, cutoff=50000, width=50000/60)) 
(v.ENY <- variogram(Tmp3_5k~1, ENY, cutoff=60000, width=60000/12)) 
(v.ENYPA <- variogram(Tmp3_5k~1, ENYPA, cutoff=60000, width=60000/30))
(v.MT <- variogram(Tmp3_5k~1, MT, cutoff=60000, width=60000/60)) 
(v.NWPANY <- variogram(Tmp3_5k~1, NWPANY, cutoff=60000, width=60000/20)) 
(v.SWPA <- variogram(Tmp3_5k~1, SWPA, cutoff=60000, width=60000/40)) 
#(v.VR <- variogram(Tmp3_5k~1, VR, cutoff=60000, width=60000/48))
(v.WPA <- variogram(Tmp3_5k~1, WPA, cutoff=60000, width=60000/40))

#Depth100C
(v.CT <- variogram(Dpt100C~1, CT, cutoff=80000, width=80000/60)) 
(v.CNY <- variogram(Dpt100C~1, CNY, cutoff=55000, width=55000/10)) 
(v.CWV <- variogram(Dpt100C~1, CWV, cutoff=60000, width=60000/50)) 
(v.ENY <- variogram(Dpt100C~1, ENY, cutoff=80000, width=80000/25)) #Sill is at 2500000, Range is about 100000
(v.ENYPA <- variogram(Dpt100C~1, ENYPA, cutoff=40000, width=40000/40))
(v.MT <- variogram(Dpt100C~1, MT, cutoff=60000, width=60000/60)) 
(v.NWPANY <- variogram(Dpt100C~1, NWPANY, cutoff=50000, width=50000/30)) 
(v.SWPA <- variogram(Dpt100C~1, SWPA, cutoff=60000, width=60000/40)) 
#(v.VR <- variogram(Dpt100C~1, VR, cutoff=60000, width=60000/48))
(v.WPA <- variogram(Dpt100C~1, WPA, cutoff=60000, width=60000/40))

##PLOT THE SAMPLE Omnidirectional VARIOGRAMS## 
#Units of the y axis may be changed according to the parameter of interest. Units of temperature are provided here.
p1 = plot(v.CT, plot.numbers=F, xlab="Chataqua, NY", ylab=expression(paste("Semivariance (",degree,"C)")^2))
p2 = plot(v.CNY,plot.numbers=F, xlab="Central NY", ylab=expression(paste("Semivariance (",degree,"C)")^2))
p9 = plot(v.CWV, plot.numbers=F, xlab="Central WV", ylab=expression(paste("Semivariance (",degree,"C)")^2))  
p3 = plot(v.ENY, plot.numbers=F, xlab="Eastern NY", ylab=expression(paste("Semivariance (",degree,"C)")^2))
p4 = plot(v.ENYPA, plot.numbers=F, xlab="Eastern NY & PA", ylab=expression(paste("Semivariance (",degree,"C)")^2)) 
p8 = plot(v.MT, plot.numbers=F, xlab="Western WV", ylab=expression(paste("Semivariance (",degree,"C)")^2))
p5 = plot(v.NWPANY, plot.numbers=F, xlab="Northwest NY & PA", ylab=expression(paste("Semivariance (",degree,"C)")^2))
p6 = plot(v.SWPA, plot.numbers=F, xlab="Southwest PA", ylab=expression(paste("Semivariance (",degree,"C)")^2))
#p10 = plot(v.VR, plot.numbers=F, xlab="Valley and Ridge", ylab=expression(paste("Semivariance (",degree,"C)")^2))
p7 = plot(v.WPA, plot.numbers=F, xlab="Western PA", ylab=expression(paste("Semivariance (",degree,"C)")^2))

par(mfrow=c(3,3))
plot(p1, split = c(1,1,3,3), more=T) 
plot(p2, split = c(2,1,3,3), more=T) 
plot(p3, split = c(3,1,3,3), more=T) 
plot(p4, split = c(1,2,3,3), more=T) 
plot(p5, split = c(2,2,3,3), more=T) 
plot(p6, split = c(3,2,3,3), more=T) 
plot(p7, split = c(1,3,3,3), more=T)
plot(p8, split = c(2,3,3,3), more=T)
plot(p9, split = c(3,3,3,3), more=F)


#PLOT SURFACE PLOTS OF THE ANISOTROPY
#HeatFlow
p1 = plot(variogram(Qs~1, CT, map=TRUE, cutoff=60000, width=60000/50), main=list(label="Chataqua, NY", cex=2.9), col.regions=terrain.colors(64), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label="Distance to points (km)", cex=2), scales=list(x=list(at=c(-50000,-25000,0,25000,50000), labels=c(50,25,0,25,50), cex=2), y=list(at=c(-50000,-25000,0,25000,50000), labels=c(50,25,0,25,50), cex=2)), strip=FALSE) #10 degrees
p2 = plot(variogram(Qs~1, CNY, map=TRUE, cutoff=60000, width=60000/10), main=list("Central NY", cex=2.9), col.regions=terrain.colors(64), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label="Distance to points (km)", cex=2), scales=list(x=list(at=c(-50000,-25000,0,25000,50000), labels=c(50,25,0,25,50), cex=2), y=list(at=c(-50000,-25000,0,25000,50000), labels=c(50,25,0,25,50), cex=2)), strip=FALSE) #Isotropic
p9 = plot(variogram(Qs~1, CWV, map=TRUE, cutoff=60000, width=60000/50), main=list("Central WV", cex=2.9), col.regions=terrain.colors(64), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label="Distance to points (km)", cex=2), scales=list(x=list(at=c(-100000,-50000,0,50000,100000), labels=c(100,50,0,50,100), cex=2), y=list(at=c(-100000,-50000,0,50000,100000), labels=c(100,50,0,50,100), cex=2)), strip=FALSE) #nearly vertical, 10 degrees.
p3 = plot(variogram(Qs~1, ENY, map=TRUE, cutoff=60000, width=60000/10), main=list("Eastern NY", cex=2.9), col.regions=terrain.colors(64), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label="Distance to points (km)", cex=2), scales=list(x=list(at=c(-60000,-40000,-20000,0,20000,40000,60000), labels=c(60,40,20,0,20,40,60), cex=2), y=list(at=c(-60000,-40000,-20000,0,20000,40000,60000), labels=c(60,40,20,0,20,40,60), cex=2)), strip=FALSE) #45 degrees
p4 = plot(variogram(Qs~1, ENYPA, map=TRUE, cutoff=60000, width=60000/30), main=list("Eastern NY & PA", cex=2.9), col.regions=terrain.colors(64), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label="Distance to points (km)", cex=2), scales=list(x=list(at=c(-60000,-40000,-20000,0,20000,40000,60000), labels=c(60,40,20,0,20,40,60), cex=2), y=list(at=c(-60000,-40000,-20000,0,20000,40000,60000), labels=c(60,40,20,0,20,40,60), cex=2)), strip=FALSE) #15 (clear in next figure)
p8 = plot(variogram(Qs~1, MT, map=TRUE, cutoff=60000, width=60000/500), main=list("Western WV", cex=2.9), col.regions=terrain.colors(64), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label="Distance to points (km)", cex=2), scales=list(x=list(at=c(-80000,-60000,-40000,-20000,0,20000,40000,60000,80000), labels=c(80,60,40,20,0,20,40,60,80), cex=2), y=list(at=c(-80000,-60000,-40000,-20000,0,20000,40000,60000,80000), labels=c(80,60,40,20,0,20,40,60,80), cex=2)), strip=FALSE) #About 35 degrees
p5 = plot(variogram(Qs~1, NWPANY, map=TRUE, cutoff=60000, width=60000/20), main=list("Northwest NY & PA", cex=2.9), col.regions=terrain.colors(64), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label="Distance to points (km)", cex=2), scales=list(x=list(at=c(-150000,-100000,-50000,0,50000,100000,150000), labels=c(150,100,50,0,50,100,150), cex=2), y=list(at=c(-150000,-100000,-50000,0,50000,100000,150000), labels=c(150,100,50,0,50,100,150), cex=2)), strip=FALSE) #Isotropic
p6 = plot(variogram(Qs~1, SWPA, map=TRUE, cutoff=60000, width=60000/50), main=list("Southwest PA", cex=2.9), col.regions=terrain.colors(64), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label="Distance to points (km)", cex=2), scales=list(x=list(at=c(-50000,-25000,0,25000,50000), labels=c(50,25,0,25,50), cex=2), y=list(at=c(-50000,-25000,0,25000,50000), labels=c(50,25,0,25,50), cex=2)), strip=FALSE) #Not sure, maybe 20 degrees
#p10 = plot(variogram(Qs~1, VR, map=TRUE, cutoff=60000, width=60000/48), main=list("Valley and Ridge", cex=2.9), col.regions=terrain.colors(64), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label="Distance to points (km)", cex=2), scales=list(x=list(at=c(-150000,-100000,-50000,0,50000,100000,150000), labels=c(150,100,50,0,50,100,150), cex=2), y=list(at=c(-150000,-100000,-50000,0,50000,100000,150000), labels=c(150,100,50,0,50,100,150), cex=2)), strip=FALSE) #10 degrees
p7 = plot(variogram(Qs~1, WPA, map=TRUE, cutoff=60000, width=60000/50), main=list("Western PA", cex=2.9), col.regions=terrain.colors(64), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label="Distance to points (km)", cex=2), scales=list(x=list(at=c(-50000,-25000,0,25000,50000), labels=c(50,25,0,25,50), cex=2), y=list(at=c(-50000,-25000,0,25000,50000), labels=c(50,25,0,25,50), cex=2)), strip=FALSE) #Isotropic (kinda)

#Depth80C
p1 = plot(variogram(Dpth80C~1, CT, map=TRUE, cutoff=60000, width=60000/50), main=list(label="Chataqua, NY", cex=2.9), col.regions=terrain.colors(64), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label="Distance to points (km)", cex=2), scales=list(x=list(at=c(-50000,-25000,0,25000,50000), labels=c(50,25,0,25,50), cex=2), y=list(at=c(-50000,-25000,0,25000,50000), labels=c(50,25,0,25,50), cex=2)), strip=FALSE) #10
p2 = plot(variogram(Dpth80C~1, CNY, map=TRUE, cutoff=60000, width=60000/10), main=list("Central NY", cex=2.9), col.regions=terrain.colors(64), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label="Distance to points (km)", cex=2), scales=list(x=list(at=c(-50000,-25000,0,25000,50000), labels=c(50,25,0,25,50), cex=2), y=list(at=c(-50000,-25000,0,25000,50000), labels=c(50,25,0,25,50), cex=2)), strip=FALSE) #Isotropic
p9 = plot(variogram(Dpth80C~1, CWV, map=TRUE, cutoff=60000, width=60000/50), main=list("Central WV", cex=2.9), col.regions=terrain.colors(64), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label="Distance to points (km)", cex=2), scales=list(x=list(at=c(-100000,-50000,0,50000,100000), labels=c(100,50,0,50,100), cex=2), y=list(at=c(-100000,-50000,0,50000,100000), labels=c(100,50,0,50,100), cex=2)), strip=FALSE) #nearly vertical, 10 degrees.
p3 = plot(variogram(Dpth80C~1, ENY, map=TRUE, cutoff=60000, width=60000/10), main=list("Eastern NY", cex=2.9), col.regions=terrain.colors(64), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label="Distance to points (km)", cex=2), scales=list(x=list(at=c(-60000,-40000,-20000,0,20000,40000,60000), labels=c(60,40,20,0,20,40,60), cex=2), y=list(at=c(-60000,-40000,-20000,0,20000,40000,60000), labels=c(60,40,20,0,20,40,60), cex=2)), strip=FALSE) #45 degrees
p4 = plot(variogram(Dpth80C~1, ENYPA, map=TRUE, cutoff=60000, width=60000/30), main=list("Eastern NY & PA", cex=2.9), col.regions=terrain.colors(64), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label="Distance to points (km)", cex=2), scales=list(x=list(at=c(-60000,-40000,-20000,0,20000,40000,60000), labels=c(60,40,20,0,20,40,60), cex=2), y=list(at=c(-60000,-40000,-20000,0,20000,40000,60000), labels=c(60,40,20,0,20,40,60), cex=2)), strip=FALSE) #15 (clear in next figure)
p8 = plot(variogram(Dpth80C~1, MT, map=TRUE, cutoff=60000, width=60000/60), main=list("Western WV", cex=2.9), col.regions=terrain.colors(64), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label="Distance to points (km)", cex=2), scales=list(x=list(at=c(-80000,-60000,-40000,-20000,0,20000,40000,60000,80000), labels=c(80,60,40,20,0,20,40,60,80), cex=2), y=list(at=c(-80000,-60000,-40000,-20000,0,20000,40000,60000,80000), labels=c(80,60,40,20,0,20,40,60,80), cex=2)), strip=FALSE) #5 degrees
p5 = plot(variogram(Dpth80C~1, NWPANY, map=TRUE, cutoff=60000, width=60000/20), main=list("Northwest NY & PA", cex=2.9), col.regions=terrain.colors(64), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label="Distance to points (km)", cex=2), scales=list(x=list(at=c(-150000,-100000,-50000,0,50000,100000,150000), labels=c(150,100,50,0,50,100,150), cex=2), y=list(at=c(-150000,-100000,-50000,0,50000,100000,150000), labels=c(150,100,50,0,50,100,150), cex=2)), strip=FALSE) #Isotropic
p6 = plot(variogram(Dpth80C~1, SWPA, map=TRUE, cutoff=60000, width=60000/40), main=list("Southwest PA", cex=2.9), col.regions=terrain.colors(64), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label="Distance to points (km)", cex=2), scales=list(x=list(at=c(-50000,-25000,0,25000,50000), labels=c(50,25,0,25,50), cex=2), y=list(at=c(-50000,-25000,0,25000,50000), labels=c(50,25,0,25,50), cex=2)), strip=FALSE) #Not sure, maybe 20 degrees
#p10 = plot(variogram(Dpth80C~1, VR, map=TRUE, cutoff=6000, width=60000/40), main=list("Valley and Ridge", cex=2.9), col.regions=terrain.colors(64), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label="Distance to points (km)", cex=2), scales=list(x=list(at=c(-150000,-100000,-50000,0,50000,100000,150000), labels=c(150,100,50,0,50,100,150), cex=2), y=list(at=c(-150000,-100000,-50000,0,50000,100000,150000), labels=c(150,100,50,0,50,100,150), cex=2)), strip=FALSE) #10 degrees
p7 = plot(variogram(Dpth80C~1, WPA, map=TRUE, cutoff=60000, width=60000/40), main=list("Western PA", cex=2.9), col.regions=terrain.colors(64), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label="Distance to points (km)", cex=2), scales=list(x=list(at=c(-50000,-25000,0,25000,50000), labels=c(50,25,0,25,50), cex=2), y=list(at=c(-50000,-25000,0,25000,50000), labels=c(50,25,0,25,50), cex=2)), strip=FALSE) #Isotropic (kinda)

#Depth100C
p1 = plot(variogram(Dpt100C~1, CT, map=TRUE, cutoff=80000, width=80000/60), main=list(label="Chataqua, NY", cex=2.9), col.regions=terrain.colors(64), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label="Distance to points (km)", cex=2), scales=list(x=list(at=c(-50000,-25000,0,25000,50000), labels=c(50,25,0,25,50), cex=2), y=list(at=c(-50000,-25000,0,25000,50000), labels=c(50,25,0,25,50), cex=2)), strip=FALSE) 
p2 = plot(variogram(Dpt100C~1, CNY, map=TRUE, cutoff=55000, width=55000/10), main=list("Central NY", cex=2.9), col.regions=terrain.colors(64), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label="Distance to points (km)", cex=2), scales=list(x=list(at=c(-50000,-25000,0,25000,50000), labels=c(50,25,0,25,50), cex=2), y=list(at=c(-50000,-25000,0,25000,50000), labels=c(50,25,0,25,50), cex=2)), strip=FALSE) 
p9 = plot(variogram(Dpt100C~1, CWV, map=TRUE, cutoff=60000, width=60000/50), main=list("Central WV", cex=2.9), col.regions=terrain.colors(64), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label="Distance to points (km)", cex=2), scales=list(x=list(at=c(-100000,-50000,0,50000,100000), labels=c(100,50,0,50,100), cex=2), y=list(at=c(-100000,-50000,0,50000,100000), labels=c(100,50,0,50,100), cex=2)), strip=FALSE) 
p3 = plot(variogram(Dpt100C~1, ENY, map=TRUE, cutoff=80000, width=80000/25), main=list("Eastern NY", cex=2.9), col.regions=terrain.colors(64), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label="Distance to points (km)", cex=2), scales=list(x=list(at=c(-60000,-40000,-20000,0,20000,40000,60000), labels=c(60,40,20,0,20,40,60), cex=2), y=list(at=c(-60000,-40000,-20000,0,20000,40000,60000), labels=c(60,40,20,0,20,40,60), cex=2)), strip=FALSE) 
p4 = plot(variogram(Dpt100C~1, ENYPA, map=TRUE, cutoff=40000, width=40000/40), main=list("Eastern NY & PA", cex=2.9), col.regions=terrain.colors(64), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label="Distance to points (km)", cex=2), scales=list(x=list(at=c(-60000,-40000,-20000,0,20000,40000,60000), labels=c(60,40,20,0,20,40,60), cex=2), y=list(at=c(-60000,-40000,-20000,0,20000,40000,60000), labels=c(60,40,20,0,20,40,60), cex=2)), strip=FALSE) 
p8 = plot(variogram(Dpt100C~1, MT, map=TRUE, cutoff=60000, width=60000/60), main=list("Western WV", cex=2.9), col.regions=terrain.colors(64), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label="Distance to points (km)", cex=2), scales=list(x=list(at=c(-80000,-60000,-40000,-20000,0,20000,40000,60000,80000), labels=c(80,60,40,20,0,20,40,60,80), cex=2), y=list(at=c(-80000,-60000,-40000,-20000,0,20000,40000,60000,80000), labels=c(80,60,40,20,0,20,40,60,80), cex=2)), strip=FALSE) 
p5 = plot(variogram(Dpt100C~1, NWPANY, map=TRUE, cutoff=50000, width=50000/30), main=list("Northwest NY & PA", cex=2.9), col.regions=terrain.colors(64), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label="Distance to points (km)", cex=2), scales=list(x=list(at=c(-150000,-100000,-50000,0,50000,100000,150000), labels=c(150,100,50,0,50,100,150), cex=2), y=list(at=c(-150000,-100000,-50000,0,50000,100000,150000), labels=c(150,100,50,0,50,100,150), cex=2)), strip=FALSE) 
p6 = plot(variogram(Dpt100C~1, SWPA, map=TRUE, cutoff=60000, width=60000/40), main=list("Southwest PA", cex=2.9), col.regions=terrain.colors(64), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label="Distance to points (km)", cex=2), scales=list(x=list(at=c(-50000,-25000,0,25000,50000), labels=c(50,25,0,25,50), cex=2), y=list(at=c(-50000,-25000,0,25000,50000), labels=c(50,25,0,25,50), cex=2)), strip=FALSE)
#p10 = plot(variogram(Dpt100C~1, VR, map=TRUE, cutoff=60000, width=60000/40), main=list("Valley and Ridge", cex=2.9), col.regions=terrain.colors(64), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label="Distance to points (km)", cex=2), scales=list(x=list(at=c(-150000,-100000,-50000,0,50000,100000,150000), labels=c(150,100,50,0,50,100,150), cex=2), y=list(at=c(-150000,-100000,-50000,0,50000,100000,150000), labels=c(150,100,50,0,50,100,150), cex=2)), strip=FALSE) 
p7 = plot(variogram(Dpt100C~1, WPA, map=TRUE, cutoff=60000, width=60000/40), main=list("Western PA", cex=2.9), col.regions=terrain.colors(64), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label="Distance to points (km)", cex=2), scales=list(x=list(at=c(-50000,-25000,0,25000,50000), labels=c(50,25,0,25,50), cex=2), y=list(at=c(-50000,-25000,0,25000,50000), labels=c(50,25,0,25,50), cex=2)), strip=FALSE) 

#Temp1.5km
p1 = plot(variogram(Tmp1_5k~1, CT, map=TRUE, cutoff=50000, width=50000/40), main=list(label="Chataqua, NY", cex=2.9), col.regions=terrain.colors(64), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label="Distance to points (km)", cex=2), scales=list(x=list(at=c(-50000,-25000,0,25000,50000), labels=c(50,25,0,25,50), cex=2), y=list(at=c(-50000,-25000,0,25000,50000), labels=c(50,25,0,25,50), cex=2)), strip=FALSE) 
p2 = plot(variogram(Tmp1_5k~1, CNY, map=TRUE, cutoff=40000, width=40000/10), main=list("Central NY", cex=2.9), col.regions=terrain.colors(64), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label="Distance to points (km)", cex=2), scales=list(x=list(at=c(-50000,-25000,0,25000,50000), labels=c(50,25,0,25,50), cex=2), y=list(at=c(-50000,-25000,0,25000,50000), labels=c(50,25,0,25,50), cex=2)), strip=FALSE) 
p9 = plot(variogram(Tmp1_5k~1, CWV, map=TRUE, cutoff=60000, width=60000/60), main=list("Central WV", cex=2.9), col.regions=terrain.colors(64), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label="Distance to points (km)", cex=2), scales=list(x=list(at=c(-100000,-50000,0,50000,100000), labels=c(100,50,0,50,100), cex=2), y=list(at=c(-100000,-50000,0,50000,100000), labels=c(100,50,0,50,100), cex=2)), strip=FALSE) 
p3 = plot(variogram(Tmp1_5k~1, ENY, map=TRUE, cutoff=80000, width=80000/25), main=list("Eastern NY", cex=2.9), col.regions=terrain.colors(64), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label="Distance to points (km)", cex=2), scales=list(x=list(at=c(-60000,-40000,-20000,0,20000,40000,60000), labels=c(60,40,20,0,20,40,60), cex=2), y=list(at=c(-60000,-40000,-20000,0,20000,40000,60000), labels=c(60,40,20,0,20,40,60), cex=2)), strip=FALSE) 
p4 = plot(variogram(Tmp1_5k~1, ENYPA, map=TRUE, cutoff=60000, width=60000/30), main=list("Eastern NY & PA", cex=2.9), col.regions=terrain.colors(64), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label="Distance to points (km)", cex=2), scales=list(x=list(at=c(-60000,-40000,-20000,0,20000,40000,60000), labels=c(60,40,20,0,20,40,60), cex=2), y=list(at=c(-60000,-40000,-20000,0,20000,40000,60000), labels=c(60,40,20,0,20,40,60), cex=2)), strip=FALSE) 
p8 = plot(variogram(Tmp1_5k~1, MT, map=TRUE, cutoff=60000, width=60000/60), main=list("Western WV", cex=2.9), col.regions=terrain.colors(64), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label="Distance to points (km)", cex=2), scales=list(x=list(at=c(-80000,-60000,-40000,-20000,0,20000,40000,60000,80000), labels=c(80,60,40,20,0,20,40,60,80), cex=2), y=list(at=c(-80000,-60000,-40000,-20000,0,20000,40000,60000,80000), labels=c(80,60,40,20,0,20,40,60,80), cex=2)), strip=FALSE) 
p5 = plot(variogram(Tmp1_5k~1, NWPANY, map=TRUE, cutoff=60000, width=60000/30), main=list("Northwest NY & PA", cex=2.9), col.regions=terrain.colors(64), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label="Distance to points (km)", cex=2), scales=list(x=list(at=c(-150000,-100000,-50000,0,50000,100000,150000), labels=c(150,100,50,0,50,100,150), cex=2), y=list(at=c(-150000,-100000,-50000,0,50000,100000,150000), labels=c(150,100,50,0,50,100,150), cex=2)), strip=FALSE) 
p6 = plot(variogram(Tmp1_5k~1, SWPA, map=TRUE, cutoff=60000, width=60000/40), main=list("Southwest PA", cex=2.9), col.regions=terrain.colors(64), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label="Distance to points (km)", cex=2), scales=list(x=list(at=c(-50000,-25000,0,25000,50000), labels=c(50,25,0,25,50), cex=2), y=list(at=c(-50000,-25000,0,25000,50000), labels=c(50,25,0,25,50), cex=2)), strip=FALSE) 
#p10 = plot(variogram(Tmp1_5k~1, VR, map=TRUE, cutoff=60000, width=60000/40), main=list("Valley and Ridge", cex=2.9), col.regions=terrain.colors(64), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label="Distance to points (km)", cex=2), scales=list(x=list(at=c(-150000,-100000,-50000,0,50000,100000,150000), labels=c(150,100,50,0,50,100,150), cex=2), y=list(at=c(-150000,-100000,-50000,0,50000,100000,150000), labels=c(150,100,50,0,50,100,150), cex=2)), strip=FALSE)
p7 = plot(variogram(Tmp1_5k~1, WPA, map=TRUE, cutoff=60000, width=60000/40), main=list("Western PA", cex=2.9), col.regions=terrain.colors(64), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label="Distance to points (km)", cex=2), scales=list(x=list(at=c(-50000,-25000,0,25000,50000), labels=c(50,25,0,25,50), cex=2), y=list(at=c(-50000,-25000,0,25000,50000), labels=c(50,25,0,25,50), cex=2)), strip=FALSE) 

#Temp2.5km
p1 = plot(variogram(Tmp2_5k~1, CT, map=TRUE, cutoff=80000, width=80000/40), main=list(label="Chataqua, NY", cex=2.9), col.regions=terrain.colors(64), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label="Distance to points (km)", cex=2), scales=list(x=list(at=c(-50000,-25000,0,25000,50000), labels=c(50,25,0,25,50), cex=2), y=list(at=c(-50000,-25000,0,25000,50000), labels=c(50,25,0,25,50), cex=2)), strip=FALSE) 
p2 = plot(variogram(Tmp2_5k~1, CNY, map=TRUE, cutoff=55000, width=55000/10), main=list("Central NY", cex=2.9), col.regions=terrain.colors(64), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label="Distance to points (km)", cex=2), scales=list(x=list(at=c(-50000,-25000,0,25000,50000), labels=c(50,25,0,25,50), cex=2), y=list(at=c(-50000,-25000,0,25000,50000), labels=c(50,25,0,25,50), cex=2)), strip=FALSE) 
p9 = plot(variogram(Tmp2_5k~1, CWV, map=TRUE, cutoff=60000, width=60000/60), main=list("Central WV", cex=2.9), col.regions=terrain.colors(64), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label="Distance to points (km)", cex=2), scales=list(x=list(at=c(-100000,-50000,0,50000,100000), labels=c(100,50,0,50,100), cex=2), y=list(at=c(-100000,-50000,0,50000,100000), labels=c(100,50,0,50,100), cex=2)), strip=FALSE) 
p3 = plot(variogram(Tmp2_5k~1, ENY, map=TRUE, cutoff=80000, width=80000/15), main=list("Eastern NY", cex=2.9), col.regions=terrain.colors(64), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label="Distance to points (km)", cex=2), scales=list(x=list(at=c(-60000,-40000,-20000,0,20000,40000,60000), labels=c(60,40,20,0,20,40,60), cex=2), y=list(at=c(-60000,-40000,-20000,0,20000,40000,60000), labels=c(60,40,20,0,20,40,60), cex=2)), strip=FALSE) 
p4 = plot(variogram(Tmp2_5k~1, ENYPA, map=TRUE, cutoff=60000, width=60000/30), main=list("Eastern NY & PA", cex=2.9), col.regions=terrain.colors(64), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label="Distance to points (km)", cex=2), scales=list(x=list(at=c(-60000,-40000,-20000,0,20000,40000,60000), labels=c(60,40,20,0,20,40,60), cex=2), y=list(at=c(-60000,-40000,-20000,0,20000,40000,60000), labels=c(60,40,20,0,20,40,60), cex=2)), strip=FALSE) 
p8 = plot(variogram(Tmp2_5k~1, MT, map=TRUE, cutoff=60000, width=60000/60), main=list("Western WV", cex=2.9), col.regions=terrain.colors(64), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label="Distance to points (km)", cex=2), scales=list(x=list(at=c(-80000,-60000,-40000,-20000,0,20000,40000,60000,80000), labels=c(80,60,40,20,0,20,40,60,80), cex=2), y=list(at=c(-80000,-60000,-40000,-20000,0,20000,40000,60000,80000), labels=c(80,60,40,20,0,20,40,60,80), cex=2)), strip=FALSE) 
p5 = plot(variogram(Tmp2_5k~1, NWPANY, map=TRUE, cutoff=50000, width=50000/20), main=list("Northwest NY & PA", cex=2.9), col.regions=terrain.colors(64), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label="Distance to points (km)", cex=2), scales=list(x=list(at=c(-150000,-100000,-50000,0,50000,100000,150000), labels=c(150,100,50,0,50,100,150), cex=2), y=list(at=c(-150000,-100000,-50000,0,50000,100000,150000), labels=c(150,100,50,0,50,100,150), cex=2)), strip=FALSE) 
p6 = plot(variogram(Tmp2_5k~1, SWPA, map=TRUE, cutoff=60000, width=60000/40), main=list("Southwest PA", cex=2.9), col.regions=terrain.colors(64), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label="Distance to points (km)", cex=2), scales=list(x=list(at=c(-50000,-25000,0,25000,50000), labels=c(50,25,0,25,50), cex=2), y=list(at=c(-50000,-25000,0,25000,50000), labels=c(50,25,0,25,50), cex=2)), strip=FALSE) 
#p10 = plot(variogram(Tmp2_5k~1, VR, map=TRUE, cutoff=60000, width=60000/40), main=list("Valley and Ridge", cex=2.9), col.regions=terrain.colors(64), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label="Distance to points (km)", cex=2), scales=list(x=list(at=c(-150000,-100000,-50000,0,50000,100000,150000), labels=c(150,100,50,0,50,100,150), cex=2), y=list(at=c(-150000,-100000,-50000,0,50000,100000,150000), labels=c(150,100,50,0,50,100,150), cex=2)), strip=FALSE)
p7 = plot(variogram(Tmp2_5k~1, WPA, map=TRUE, cutoff=60000, width=60000/40), main=list("Western PA", cex=2.9), col.regions=terrain.colors(64), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label="Distance to points (km)", cex=2), scales=list(x=list(at=c(-50000,-25000,0,25000,50000), labels=c(50,25,0,25,50), cex=2), y=list(at=c(-50000,-25000,0,25000,50000), labels=c(50,25,0,25,50), cex=2)), strip=FALSE) 

#Temp3.5km
p1 = plot(variogram(Tmp3_5k~1, CT, map=TRUE, cutoff=50000, width=50000/40), main=list(label="Chataqua, NY", cex=2.9), col.regions=terrain.colors(64), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label="Distance to points (km)", cex=2), scales=list(x=list(at=c(-50000,-25000,0,25000,50000), labels=c(50,25,0,25,50), cex=2), y=list(at=c(-50000,-25000,0,25000,50000), labels=c(50,25,0,25,50), cex=2)), strip=FALSE) #Isotropic
p2 = plot(variogram(Tmp3_5k~1, CNY, map=TRUE, cutoff=50000, width=50000/10), main=list("Central NY", cex=2.9), col.regions=terrain.colors(64), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label="Distance to points (km)", cex=2), scales=list(x=list(at=c(-50000,-25000,0,25000,50000), labels=c(50,25,0,25,50), cex=2), y=list(at=c(-50000,-25000,0,25000,50000), labels=c(50,25,0,25,50), cex=2)), strip=FALSE) #Isotropic
p9 = plot(variogram(Tmp3_5k~1, CWV, map=TRUE, cutoff=50000, width=50000/60), main=list("Central WV", cex=2.9), col.regions=terrain.colors(64), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label="Distance to points (km)", cex=2), scales=list(x=list(at=c(-100000,-50000,0,50000,100000), labels=c(100,50,0,50,100), cex=2), y=list(at=c(-100000,-50000,0,50000,100000), labels=c(100,50,0,50,100), cex=2)), strip=FALSE) #nearly vertical, 10 degrees.
p3 = plot(variogram(Tmp3_5k~1, ENY, map=TRUE, cutoff=60000, width=60000/12), main=list("Eastern NY", cex=2.9), col.regions=terrain.colors(64), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label="Distance to points (km)", cex=2), scales=list(x=list(at=c(-60000,-40000,-20000,0,20000,40000,60000), labels=c(60,40,20,0,20,40,60), cex=2), y=list(at=c(-60000,-40000,-20000,0,20000,40000,60000), labels=c(60,40,20,0,20,40,60), cex=2)), strip=FALSE) #45 degrees
p4 = plot(variogram(Tmp3_5k~1, ENYPA, map=TRUE, cutoff=60000, width=60000/30), main=list("Eastern NY & PA", cex=2.9), col.regions=terrain.colors(64), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label="Distance to points (km)", cex=2), scales=list(x=list(at=c(-60000,-40000,-20000,0,20000,40000,60000), labels=c(60,40,20,0,20,40,60), cex=2), y=list(at=c(-60000,-40000,-20000,0,20000,40000,60000), labels=c(60,40,20,0,20,40,60), cex=2)), strip=FALSE) #15 (clear in next figure)
p8 = plot(variogram(Tmp3_5k~1, MT, map=TRUE, cutoff=60000, width=60000/60), main=list("Western WV", cex=2.9), col.regions=terrain.colors(64), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label="Distance to points (km)", cex=2), scales=list(x=list(at=c(-80000,-60000,-40000,-20000,0,20000,40000,60000,80000), labels=c(80,60,40,20,0,20,40,60,80), cex=2), y=list(at=c(-80000,-60000,-40000,-20000,0,20000,40000,60000,80000), labels=c(80,60,40,20,0,20,40,60,80), cex=2)), strip=FALSE) #Isotropic
p5 = plot(variogram(Tmp3_5k~1, NWPANY, map=TRUE, cutoff=60000, width=60000/20), main=list("Northwest NY & PA", cex=2.9), col.regions=terrain.colors(64), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label="Distance to points (km)", cex=2), scales=list(x=list(at=c(-150000,-100000,-50000,0,50000,100000,150000), labels=c(150,100,50,0,50,100,150), cex=2), y=list(at=c(-150000,-100000,-50000,0,50000,100000,150000), labels=c(150,100,50,0,50,100,150), cex=2)), strip=FALSE) #Isotropic
p6 = plot(variogram(Tmp3_5k~1, SWPA, map=TRUE, cutoff=60000, width=60000/40), main=list("Southwest PA", cex=2.9), col.regions=terrain.colors(64), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label="Distance to points (km)", cex=2), scales=list(x=list(at=c(-50000,-25000,0,25000,50000), labels=c(50,25,0,25,50), cex=2), y=list(at=c(-50000,-25000,0,25000,50000), labels=c(50,25,0,25,50), cex=2)), strip=FALSE) #Isotropic
#p10 = plot(variogram(Tmp3_5k~1, VR, map=TRUE, cutoff=60000, width=60000/40), main=list("Valley and Ridge", cex=2.9), col.regions=terrain.colors(64), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label="Distance to points (km)", cex=2), scales=list(x=list(at=c(-150000,-100000,-50000,0,50000,100000,150000), labels=c(150,100,50,0,50,100,150), cex=2), y=list(at=c(-150000,-100000,-50000,0,50000,100000,150000), labels=c(150,100,50,0,50,100,150), cex=2)), strip=FALSE) #10 degrees
p7 = plot(variogram(Tmp3_5k~1, WPA, map=TRUE, cutoff=60000, width=60000/40), main=list("Western PA", cex=2.9), col.regions=terrain.colors(64), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label="Distance to points (km)", cex=2), scales=list(x=list(at=c(-50000,-25000,0,25000,50000), labels=c(50,25,0,25,50), cex=2), y=list(at=c(-50000,-25000,0,25000,50000), labels=c(50,25,0,25,50), cex=2)), strip=FALSE) #Isotropic (kinda)

par(mfrow=c(3,3))
plot(p1, split = c(1,1,3,3), more=T) 
plot(p2, split = c(2,1,3,3), more=T) 
plot(p3, split = c(3,1,3,3), more=T) 
plot(p4, split = c(1,2,3,3), more=T) 
plot(p5, split = c(2,2,3,3), more=T) 
plot(p6, split = c(3,2,3,3), more=T) 
plot(p7, split = c(1,3,3,3), more=T)
plot(p8, split = c(2,3,3,3), more=T)
plot(p9, split = c(3,3,3,3), more=F)

#PLOT SURFACE PLOTS ON SAME SEMIVARIANCE COLOR SCALE
#Calculate the maximum and minimum semivariance from the sections
(varmax = round(max(v.CT$gamma, v.CNY$gamma, v.CWV$gamma, v.ENY$gamma, v.MT$gamma, v.ENYPA$gamma, v.NWPANY$gamma, v.SWPA$gamma, v.WPA$gamma)))
(varmin = round(min(v.CT$gamma, v.CNY$gamma, v.CWV$gamma, v.ENY$gamma, v.MT$gamma, v.ENYPA$gamma, v.NWPANY$gamma, v.SWPA$gamma, v.WPA$gamma)))

#Change the color ramp to reflect the anisotropy in the regions. 

#HeatFlow
ramp = seq(0,varmax,by=5)
colramp = colorRampPalette(c('green', 'yellow', 'orange', 'red'))
color = colramp(length(ramp))

p1 = plot(variogram(Qs~1, CT, map=TRUE, cutoff=60000, width=60000/50), main=list(label="Chataqua, NY", cex=2.9), col.regions=color, at=ramp, colorkey=list(at=ramp, labels=list(at=seq(0,varmax,20), labels=seq(0,varmax,20), cex=1.5)), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label="Distance to points (km)", cex=2), scales=list(x=list(at=c(-60000,-30000,0,30000,60000), labels=c(60,30,0,30,60), cex=2), y=list(at=c(-60000,-30000,0,30000,60000), labels=c(60,30,0,30,60), cex=2)), strip=FALSE) 
p2 = plot(variogram(Qs~1, CNY, map=TRUE, cutoff=60000, width=60000/15), main=list("Central NY", cex=2.9), col.regions=color, at=ramp, colorkey=list(at=ramp, labels=list(at=seq(0,varmax,20), labels=seq(0,varmax,20), cex=1.5)), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label="Distance to points (km)", cex=2), scales=list(x=list(at=c(-60000,-30000,0,30000,60000), labels=c(60,30,0,30,60), cex=2), y=list(at=c(-60000,-30000,0,30000,60000), labels=c(60,30,0,30,60), cex=2)), strip=FALSE)
p9 = plot(variogram(Qs~1, CWV, map=TRUE, cutoff=60000, width=60000/50), main=list("Central WV", cex=2.9), col.regions=color, at=ramp, colorkey=list(at=ramp, labels=list(at=seq(0,varmax,20), labels=seq(0,varmax,20), cex=1.5)), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label="Distance to points (km)", cex=2), scales=list(x=list(at=c(-60000,-30000,0,30000,60000), labels=c(60,30,0,30,60), cex=2), y=list(at=c(-60000,-30000,0,30000,60000), labels=c(60,30,0,30,60), cex=2)), strip=FALSE) 
p3 = plot(variogram(Qs~1, ENY, map=TRUE, cutoff=60000, width=60000/20), main=list("Eastern NY", cex=2.9), col.regions=color, at=ramp, colorkey=list(at=ramp, labels=list(at=seq(0,varmax,20), labels=seq(0,varmax,20), cex=1.5)), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label="Distance to points (km)", cex=2), scales=list(x=list(at=c(-60000,-30000,0,30000,60000), labels=c(60,30,0,30,60), cex=2), y=list(at=c(-60000,-30000,0,30000,60000), labels=c(60,30,0,30,60), cex=2)), strip=FALSE)
p4 = plot(variogram(Qs~1, ENYPA, map=TRUE, cutoff=60000, width=60000/30), main=list("Eastern NY & PA", cex=2.9), col.regions=color, at=ramp, colorkey=list(at=ramp, labels=list(at=seq(0,varmax,20), labels=seq(0,varmax,20), cex=1.5)), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label="Distance to points (km)", cex=2), scales=list(x=list(at=c(-60000,-30000,0,30000,60000), labels=c(60,30,0,30,60), cex=2), y=list(at=c(-60000,-30000,0,30000,60000), labels=c(60,30,0,30,60), cex=2)), strip=FALSE) 
p8 = plot(variogram(Qs~1, MT, map=TRUE, cutoff=60000, width=60000/60), main=list("Western WV", cex=2.9), col.regions=color, at=ramp, colorkey=list(at=ramp, labels=list(at=seq(0,varmax,20), labels=seq(0,varmax,20), cex=1.5)), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label="Distance to points (km)", cex=2), scales=list(x=list(at=c(-60000,-30000,0,30000,60000), labels=c(60,30,0,30,60), cex=2), y=list(at=c(-60000,-30000,0,30000,60000), labels=c(60,30,0,30,60), cex=2)), strip=FALSE)
p5 = plot(variogram(Qs~1, NWPANY, map=TRUE, cutoff=60000, width=60000/20), main=list("Northwest NY & PA", cex=2.9), col.regions=color, at=ramp, colorkey=list(at=ramp, labels=list(at=seq(0,varmax,20), labels=seq(0,varmax,20), cex=1.5)), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label="Distance to points (km)", cex=2), scales=list(x=list(at=c(-60000,-30000,0,30000,60000), labels=c(60,30,0,30,60), cex=2), y=list(at=c(-60000,-30000,0,30000,60000), labels=c(60,30,0,30,60), cex=2)), strip=FALSE)  
p6 = plot(variogram(Qs~1, SWPA, map=TRUE, cutoff=60000, width=60000/50), main=list("Southwest PA", cex=2.9), col.regions=color, at=ramp, colorkey=list(at=ramp, labels=list(at=seq(0,varmax,20), labels=seq(0,varmax,20), cex=1.5)), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label="Distance to points (km)", cex=2), scales=list(x=list(at=c(-60000,-30000,0,30000,60000), labels=c(60,30,0,30,60), cex=2), y=list(at=c(-60000,-30000,0,30000,60000), labels=c(60,30,0,30,60), cex=2)), strip=FALSE) 
#p10 = plot(variogram(Qs~1, VR, map=TRUE, cutoff=60000, width=60000/48), main=list("Valley and Ridge", cex=2.9), col.regions=color, at=ramp, colorkey=list(at=ramp, labels=list(at=c(0,20,40,60), labels=c(0,20,40,60), cex=1.5)), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label="Distance to points (km)", cex=2), scales=list(x=list(at=c(-150000,-100000,-50000,0,50000,100000,150000), labels=c(150,100,50,0,50,100,150), cex=2), y=list(at=c(-150000,-100000,-50000,0,50000,100000,150000), labels=c(150,100,50,0,50,100,150), cex=2)), strip=FALSE)
p7 = plot(variogram(Qs~1, WPA, map=TRUE, cutoff=60000, width=60000/50), main=list("Western PA", cex=2.9), col.regions=color, at=ramp, colorkey=list(at=ramp, labels=list(at=seq(0,varmax,20), labels=seq(0,varmax,20), cex=1.5)), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label="Distance to points (km)", cex=2), scales=list(x=list(at=c(-60000,-30000,0,30000,60000), labels=c(60,30,0,30,60), cex=2), y=list(at=c(-60000,-30000,0,30000,60000), labels=c(60,30,0,30,60), cex=2)), strip=FALSE) 

#Depth80C
ramp = seq(0,varmax,by=100000)
colramp = colorRampPalette(c('green', 'yellow', 'orange', 'red'))
color = colramp(length(ramp))

p1 = plot(variogram(Dpth80C~1, CT, map=TRUE, cutoff=60000, width=60000/50), main=list(label="Chataqua, NY", cex=2.9), col.regions=color, at=ramp, colorkey=list(at=ramp, labels=list(at=seq(0,varmax,500000), labels=seq(0,varmax,500000), cex=1.5)), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label="Distance to points (km)", cex=2), scales=list(x=list(at=c(-60000,-30000,0,30000,60000), labels=c(60,30,0,30,60), cex=2), y=list(at=c(-60000,-30000,0,30000,60000), labels=c(60,30,0,30,60), cex=2)), strip=FALSE) 
p2 = plot(variogram(Dpth80C~1, CNY, map=TRUE, cutoff=60000, width=60000/10), main=list("Central NY", cex=2.9), col.regions=color, at=ramp, colorkey=list(at=ramp, labels=list(at=seq(0,varmax,500000), labels=seq(0,varmax,500000), cex=1.5)), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label="Distance to points (km)", cex=2), scales=list(x=list(at=c(-60000,-30000,0,30000,60000), labels=c(60,30,0,30,60), cex=2), y=list(at=c(-60000,-30000,0,30000,60000), labels=c(60,30,0,30,60), cex=2)), strip=FALSE)
p9 = plot(variogram(Dpth80C~1, CWV, map=TRUE, cutoff=60000, width=60000/50), main=list("Central WV", cex=2.9), col.regions=color, at=ramp, colorkey=list(at=ramp, labels=list(at=seq(0,varmax,500000), labels=seq(0,varmax,500000), cex=1.5)), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label="Distance to points (km)", cex=2), scales=list(x=list(at=c(-60000,-30000,0,30000,60000), labels=c(60,30,0,30,60), cex=2), y=list(at=c(-60000,-30000,0,30000,60000), labels=c(60,30,0,30,60), cex=2)), strip=FALSE) 
p3 = plot(variogram(Dpth80C~1, ENY, map=TRUE, cutoff=60000, width=60000/20), main=list("Eastern NY", cex=2.9), col.regions=color, at=ramp, colorkey=list(at=ramp, labels=list(at=seq(0,varmax,500000), labels=seq(0,varmax,500000), cex=1.5)), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label="Distance to points (km)", cex=2), scales=list(x=list(at=c(-60000,-30000,0,30000,60000), labels=c(60,30,0,30,60), cex=2), y=list(at=c(-60000,-30000,0,30000,60000), labels=c(60,30,0,30,60), cex=2)), strip=FALSE)
p4 = plot(variogram(Dpth80C~1, ENYPA, map=TRUE, cutoff=60000, width=60000/30), main=list("Eastern NY & PA", cex=2.9), col.regions=color, at=ramp, colorkey=list(at=ramp, labels=list(at=seq(0,varmax,500000), labels=seq(0,varmax,500000), cex=1.5)), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label="Distance to points (km)", cex=2), scales=list(x=list(at=c(-60000,-30000,0,30000,60000), labels=c(60,30,0,30,60), cex=2), y=list(at=c(-60000,-30000,0,30000,60000), labels=c(60,30,0,30,60), cex=2)), strip=FALSE) 
p8 = plot(variogram(Dpth80C~1, MT, map=TRUE, cutoff=60000, width=60000/60), main=list("Western WV", cex=2.9), col.regions=color, at=ramp, colorkey=list(at=ramp, labels=list(at=seq(0,varmax,500000), labels=seq(0,varmax,500000), cex=1.5)), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label="Distance to points (km)", cex=2), scales=list(x=list(at=c(-60000,-30000,0,30000,60000), labels=c(60,30,0,30,60), cex=2), y=list(at=c(-60000,-30000,0,30000,60000), labels=c(60,30,0,30,60), cex=2)), strip=FALSE)
p5 = plot(variogram(Dpth80C~1, NWPANY, map=TRUE, cutoff=60000, width=60000/20), main=list("Northwest NY & PA", cex=2.9), col.regions=color, at=ramp, colorkey=list(at=ramp, labels=list(at=seq(0,varmax,500000), labels=seq(0,varmax,500000), cex=1.5)), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label="Distance to points (km)", cex=2), scales=list(x=list(at=c(-60000,-30000,0,30000,60000), labels=c(60,30,0,30,60), cex=2), y=list(at=c(-60000,-30000,0,30000,60000), labels=c(60,30,0,30,60), cex=2)), strip=FALSE)  
p6 = plot(variogram(Dpth80C~1, SWPA, map=TRUE, cutoff=60000, width=60000/40), main=list("Southwest PA", cex=2.9), col.regions=color, at=ramp, colorkey=list(at=ramp, labels=list(at=seq(0,varmax,500000), labels=seq(0,varmax,500000), cex=1.5)), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label="Distance to points (km)", cex=2), scales=list(x=list(at=c(-60000,-30000,0,30000,60000), labels=c(60,30,0,30,60), cex=2), y=list(at=c(-60000,-30000,0,30000,60000), labels=c(60,30,0,30,60), cex=2)), strip=FALSE) 
#p10 = plot(variogram(Dpth80C~1, VR, map=TRUE, cutoff=60000, width=60000/48), main=list("Valley and Ridge", cex=2.9), col.regions=color, at=ramp, colorkey=list(at=ramp, labels=list(at=c(0,20,40,60), labels=c(0,20,40,60), cex=1.5)), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label="Distance to points (km)", cex=2), scales=list(x=list(at=c(-150000,-100000,-50000,0,50000,100000,150000), labels=c(150,100,50,0,50,100,150), cex=2), y=list(at=c(-150000,-100000,-50000,0,50000,100000,150000), labels=c(150,100,50,0,50,100,150), cex=2)), strip=FALSE)
p7 = plot(variogram(Dpth80C~1, WPA, map=TRUE, cutoff=60000, width=60000/40), main=list("Western PA", cex=2.9), col.regions=color, at=ramp, colorkey=list(at=ramp, labels=list(at=seq(0,varmax,500000), labels=seq(0,varmax,500000), cex=1.5)), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label="Distance to points (km)", cex=2), scales=list(x=list(at=c(-60000,-30000,0,30000,60000), labels=c(60,30,0,30,60), cex=2), y=list(at=c(-60000,-30000,0,30000,60000), labels=c(60,30,0,30,60), cex=2)), strip=FALSE) 

#Depth100C
ramp = seq(0,varmax,by=100000)
colramp = colorRampPalette(c('green', 'yellow', 'orange', 'red'))
color = colramp(length(ramp))

p1 = plot(variogram(Dpt100C~1, CT, map=TRUE, cutoff=80000, width=80000/60), main=list(label="Chataqua, NY", cex=2.9), col.regions=color, at=ramp, colorkey=list(at=ramp, labels=list(at=seq(0,varmax,500000), labels=seq(0,varmax,500000), cex=1.5)), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label="Distance to points (km)", cex=2), scales=list(x=list(at=c(-60000,-30000,0,30000,60000), labels=c(60,30,0,30,60), cex=2), y=list(at=c(-60000,-30000,0,30000,60000), labels=c(60,30,0,30,60), cex=2)), strip=FALSE) 
p2 = plot(variogram(Dpt100C~1, CNY, map=TRUE, cutoff=55000, width=55000/10), main=list("Central NY", cex=2.9), col.regions=color, at=ramp, colorkey=list(at=ramp, labels=list(at=seq(0,varmax,500000), labels=seq(0,varmax,500000), cex=1.5)), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label="Distance to points (km)", cex=2), scales=list(x=list(at=c(-60000,-30000,0,30000,60000), labels=c(60,30,0,30,60), cex=2), y=list(at=c(-60000,-30000,0,30000,60000), labels=c(60,30,0,30,60), cex=2)), strip=FALSE)
p9 = plot(variogram(Dpt100C~1, CWV, map=TRUE, cutoff=60000, width=60000/50), main=list("Central WV", cex=2.9), col.regions=color, at=ramp, colorkey=list(at=ramp, labels=list(at=seq(0,varmax,500000), labels=seq(0,varmax,500000), cex=1.5)), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label="Distance to points (km)", cex=2), scales=list(x=list(at=c(-60000,-30000,0,30000,60000), labels=c(60,30,0,30,60), cex=2), y=list(at=c(-60000,-30000,0,30000,60000), labels=c(60,30,0,30,60), cex=2)), strip=FALSE) 
p3 = plot(variogram(Dpt100C~1, ENY, map=TRUE, cutoff=80000, width=80000/25), main=list("Eastern NY", cex=2.9), col.regions=color, at=ramp, colorkey=list(at=ramp, labels=list(at=seq(0,varmax,500000), labels=seq(0,varmax,500000), cex=1.5)), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label="Distance to points (km)", cex=2), scales=list(x=list(at=c(-60000,-30000,0,30000,60000), labels=c(60,30,0,30,60), cex=2), y=list(at=c(-60000,-30000,0,30000,60000), labels=c(60,30,0,30,60), cex=2)), strip=FALSE)
p4 = plot(variogram(Dpt100C~1, ENYPA, map=TRUE, cutoff=40000, width=40000/40), main=list("Eastern NY & PA", cex=2.9), col.regions=color, at=ramp, colorkey=list(at=ramp, labels=list(at=seq(0,varmax,500000), labels=seq(0,varmax,500000), cex=1.5)), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label="Distance to points (km)", cex=2), scales=list(x=list(at=c(-60000,-30000,0,30000,60000), labels=c(60,30,0,30,60), cex=2), y=list(at=c(-60000,-30000,0,30000,60000), labels=c(60,30,0,30,60), cex=2)), strip=FALSE) 
p8 = plot(variogram(Dpt100C~1, MT, map=TRUE, cutoff=60000, width=60000/60), main=list("Western WV", cex=2.9), col.regions=color, at=ramp, colorkey=list(at=ramp, labels=list(at=seq(0,varmax,500000), labels=seq(0,varmax,500000), cex=1.5)), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label="Distance to points (km)", cex=2), scales=list(x=list(at=c(-60000,-30000,0,30000,60000), labels=c(60,30,0,30,60), cex=2), y=list(at=c(-60000,-30000,0,30000,60000), labels=c(60,30,0,30,60), cex=2)), strip=FALSE)
p5 = plot(variogram(Dpt100C~1, NWPANY, map=TRUE, cutoff=50000, width=50000/30), main=list("Northwest NY & PA", cex=2.9), col.regions=color, at=ramp, colorkey=list(at=ramp, labels=list(at=seq(0,varmax,500000), labels=seq(0,varmax,500000), cex=1.5)), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label="Distance to points (km)", cex=2), scales=list(x=list(at=c(-60000,-30000,0,30000,60000), labels=c(60,30,0,30,60), cex=2), y=list(at=c(-60000,-30000,0,30000,60000), labels=c(60,30,0,30,60), cex=2)), strip=FALSE)  
p6 = plot(variogram(Dpt100C~1, SWPA, map=TRUE, cutoff=60000, width=60000/40), main=list("Southwest PA", cex=2.9), col.regions=color, at=ramp, colorkey=list(at=ramp, labels=list(at=seq(0,varmax,500000), labels=seq(0,varmax,500000), cex=1.5)), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label="Distance to points (km)", cex=2), scales=list(x=list(at=c(-60000,-30000,0,30000,60000), labels=c(60,30,0,30,60), cex=2), y=list(at=c(-60000,-30000,0,30000,60000), labels=c(60,30,0,30,60), cex=2)), strip=FALSE) 
#p10 = plot(variogram(Dpt100C~1, VR, map=TRUE, cutoff=60000, width=60000/48), main=list("Valley and Ridge", cex=2.9), col.regions=color, at=ramp, colorkey=list(at=ramp, labels=list(at=c(0,20,40,60), labels=c(0,20,40,60), cex=1.5)), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label="Distance to points (km)", cex=2), scales=list(x=list(at=c(-150000,-100000,-50000,0,50000,100000,150000), labels=c(150,100,50,0,50,100,150), cex=2), y=list(at=c(-150000,-100000,-50000,0,50000,100000,150000), labels=c(150,100,50,0,50,100,150), cex=2)), strip=FALSE)
p7 = plot(variogram(Dpt100C~1, WPA, map=TRUE, cutoff=60000, width=60000/40), main=list("Western PA", cex=2.9), col.regions=color, at=ramp, colorkey=list(at=ramp, labels=list(at=seq(0,varmax,500000), labels=seq(0,varmax,500000), cex=1.5)), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label="Distance to points (km)", cex=2), scales=list(x=list(at=c(-60000,-30000,0,30000,60000), labels=c(60,30,0,30,60), cex=2), y=list(at=c(-60000,-30000,0,30000,60000), labels=c(60,30,0,30,60), cex=2)), strip=FALSE) 

#Temp1.5km
ramp = seq(0,varmax,by=15)
colramp = colorRampPalette(c('green', 'yellow', 'orange', 'red'))
color = colramp(length(ramp))

p1 = plot(variogram(Tmp1_5k~1, CT, map=TRUE, cutoff=50000, width=50000/40), main=list(label="Chataqua, NY", cex=2.9), col.regions=color, at=ramp, colorkey=list(at=ramp, labels=list(at=c(0,20,40,60), labels=c(0,20,40,60), cex=1.5)), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label="Distance to points (km)", cex=2), scales=list(x=list(at=c(-50000,-25000,0,25000,50000), labels=c(50,25,0,25,50), cex=2), y=list(at=c(-50000,-25000,0,25000,50000), labels=c(50,25,0,25,50), cex=2)), strip=FALSE) 
p2 = plot(variogram(Tmp1_5k~1, CNY, map=TRUE, cutoff=40000, width=40000/10), main=list("Central NY", cex=2.9), col.regions=color, at=ramp, colorkey=list(at=ramp, labels=list(at=c(0,20,40,60), labels=c(0,20,40,60), cex=1.5)), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label="Distance to points (km)", cex=2), scales=list(x=list(at=c(-50000,-25000,0,25000,50000), labels=c(50,25,0,25,50), cex=2), y=list(at=c(-50000,-25000,0,25000,50000), labels=c(50,25,0,25,50), cex=2)), strip=FALSE)
p9 = plot(variogram(Tmp1_5k~1, CWV, map=TRUE, cutoff=60000, width=60000/60), main=list("Central WV", cex=2.9), col.regions=color, at=ramp, colorkey=list(at=ramp, labels=list(at=c(0,20,40,60), labels=c(0,20,40,60), cex=1.5)), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label="Distance to points (km)", cex=2), scales=list(x=list(at=c(-120000,-80000,-40000,0,40000,80000,120000), labels=c(120,80,40,0,40,80,120), cex=2), y=list(at=c(-120000,-80000,-40000,0,40000,80000,120000), labels=c(120,80,40,0,40,80,120), cex=2)), strip=FALSE) 
p3 = plot(variogram(Tmp1_5k~1, ENY, map=TRUE, cutoff=80000, width=80000/25), main=list("Eastern NY", cex=2.9), col.regions=color, at=ramp, colorkey=list(at=ramp, labels=list(at=c(0,20,40,60), labels=c(0,20,40,60), cex=1.5)), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label="Distance to points (km)", cex=2), scales=list(x=list(at=c(-60000,-40000,-20000,0,20000,40000,60000), labels=c(60,40,20,0,20,40,60), cex=2), y=list(at=c(-60000,-40000,-20000,0,20000,40000,60000), labels=c(60,40,20,0,20,40,60), cex=2)), strip=FALSE) #near vertical
p4 = plot(variogram(Tmp1_5k~1, ENYPA, map=TRUE, cutoff=60000, width=60000/30), main=list("Eastern NY & PA", cex=2.9), col.regions=color, at=ramp, colorkey=list(at=ramp, labels=list(at=c(0,20,40,60), labels=c(0,20,40,60), cex=1.5)), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label="Distance to points (km)", cex=2), scales=list(x=list(at=c(-50000,-25000,0,25000,50000), labels=c(50,25,0,25,50), cex=2), y=list(at=c(-50000,-25000,0,25000,50000), labels=c(50,25,0,25,50), cex=2)), strip=FALSE) #15 degrees
p8 = plot(variogram(Tmp1_5k~1, MT, map=TRUE, cutoff=60000, width=60000/600), main=list("Western WV", cex=2.9), col.regions=color, at=ramp, colorkey=list(at=ramp, labels=list(at=c(0,20,40,60), labels=c(0,20,40,60), cex=1.5)), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label="Distance to points (km)", cex=2), scales=list(x=list(at=c(-80000,-60000,-40000,-20000,0,20000,40000,60000,80000), labels=c(80,60,40,20,0,20,40,60,80), cex=2), y=list(at=c(-80000,-60000,-40000,-20000,0,20000,40000,60000,80000), labels=c(80,60,40,20,0,20,40,60,80), cex=2)), strip=FALSE)
p5 = plot(variogram(Tmp1_5k~1, NWPANY, map=TRUE, cutoff=60000, width=60000/30), main=list("Northwest NY & PA", cex=2.9), col.regions=color, at=ramp, colorkey=list(at=ramp, labels=list(at=c(0,20,40,60), labels=c(0,20,40,60), cex=1.5)), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label="Distance to points (km)", cex=2), scales=list(x=list(at=c(-50000,-25000,0,25000,50000), labels=c(50,25,0,25,50), cex=2), y=list(at=c(-50000,-25000,0,25000,50000), labels=c(50,25,0,25,50), cex=2)), strip=FALSE)  
p6 = plot(variogram(Tmp1_5k~1, SWPA, map=TRUE, cutoff=60000, width=60000/40), main=list("Southwest PA", cex=2.9), col.regions=color, at=ramp, colorkey=list(at=ramp, labels=list(at=c(0,20,40,60), labels=c(0,20,40,60), cex=1.5)), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label="Distance to points (km)", cex=2), scales=list(x=list(at=c(-50000,-25000,0,25000,50000), labels=c(50,25,0,25,50), cex=2), y=list(at=c(-50000,-25000,0,25000,50000), labels=c(50,25,0,25,50), cex=2)), strip=FALSE) 
#p10 = plot(variogram(Tmp1_5k~1, VR, map=TRUE, cutoff=60000, width=60000/40), main=list("Valley and Ridge", cex=2.9), col.regions=color, at=ramp, colorkey=list(at=ramp, labels=list(at=c(0,20,40,60), labels=c(0,20,40,60), cex=1.5)), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label="Distance to points (km)", cex=2), scales=list(x=list(at=c(-150000,-100000,-50000,0,50000,100000,150000), labels=c(150,100,50,0,50,100,150), cex=2), y=list(at=c(-150000,-100000,-50000,0,50000,100000,150000), labels=c(150,100,50,0,50,100,150), cex=2)), strip=FALSE)
p7 = plot(variogram(Tmp1_5k~1, WPA, map=TRUE, cutoff=60000, width=60000/40), main=list("Western PA", cex=2.9), col.regions=color, at=ramp, colorkey=list(at=ramp, labels=list(at=c(0,20,40,60), labels=c(0,20,40,60), cex=1.5)), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label="Distance to points (km)", cex=2), scales=list(x=list(at=c(-50000,-25000,0,25000,50000), labels=c(50,25,0,25,50), cex=2), y=list(at=c(-50000,-25000,0,25000,50000), labels=c(50,25,0,25,50), cex=2)), strip=FALSE) 

#Temp2.5km
ramp = seq(0,varmax,by=50)
colramp = colorRampPalette(c('green', 'yellow', 'orange', 'red'))
color = colramp(length(ramp))

p1 = plot(variogram(Tmp2_5k~1, CT, map=TRUE, cutoff=80000, width=80000/40), main=list(label="Chataqua, NY", cex=2.9), col.regions=color, at=ramp, colorkey=list(at=ramp, labels=list(at=c(0,20,40,60), labels=c(0,20,40,60), cex=1.5)), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label="Distance to points (km)", cex=2), scales=list(x=list(at=c(-50000,-25000,0,25000,50000), labels=c(50,25,0,25,50), cex=2), y=list(at=c(-50000,-25000,0,25000,50000), labels=c(50,25,0,25,50), cex=2)), strip=FALSE) 
p2 = plot(variogram(Tmp2_5k~1, CNY, map=TRUE, cutoff=55000, width=55000/10), main=list("Central NY", cex=2.9), col.regions=color, at=ramp, colorkey=list(at=ramp, labels=list(at=c(0,20,40,60), labels=c(0,20,40,60), cex=1.5)), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label="Distance to points (km)", cex=2), scales=list(x=list(at=c(-50000,-25000,0,25000,50000), labels=c(50,25,0,25,50), cex=2), y=list(at=c(-50000,-25000,0,25000,50000), labels=c(50,25,0,25,50), cex=2)), strip=FALSE)
p9 = plot(variogram(Tmp2_5k~1, CWV, map=TRUE, cutoff=60000, width=60000/60), main=list("Central WV", cex=2.9), col.regions=color, at=ramp, colorkey=list(at=ramp, labels=list(at=c(0,20,40,60), labels=c(0,20,40,60), cex=1.5)), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label="Distance to points (km)", cex=2), scales=list(x=list(at=c(-120000,-80000,-40000,0,40000,80000,120000), labels=c(120,80,40,0,40,80,120), cex=2), y=list(at=c(-120000,-80000,-40000,0,40000,80000,120000), labels=c(120,80,40,0,40,80,120), cex=2)), strip=FALSE) 
p3 = plot(variogram(Tmp2_5k~1, ENY, map=TRUE, cutoff=80000, width=80000/15), main=list("Eastern NY", cex=2.9), col.regions=color, at=ramp, colorkey=list(at=ramp, labels=list(at=c(0,20,40,60), labels=c(0,20,40,60), cex=1.5)), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label="Distance to points (km)", cex=2), scales=list(x=list(at=c(-60000,-40000,-20000,0,20000,40000,60000), labels=c(60,40,20,0,20,40,60), cex=2), y=list(at=c(-60000,-40000,-20000,0,20000,40000,60000), labels=c(60,40,20,0,20,40,60), cex=2)), strip=FALSE) #near vertical
p4 = plot(variogram(Tmp2_5k~1, ENYPA, map=TRUE, cutoff=60000, width=60000/30), main=list("Eastern NY & PA", cex=2.9), col.regions=color, at=ramp, colorkey=list(at=ramp, labels=list(at=c(0,20,40,60), labels=c(0,20,40,60), cex=1.5)), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label="Distance to points (km)", cex=2), scales=list(x=list(at=c(-50000,-25000,0,25000,50000), labels=c(50,25,0,25,50), cex=2), y=list(at=c(-50000,-25000,0,25000,50000), labels=c(50,25,0,25,50), cex=2)), strip=FALSE) #15 degrees
p8 = plot(variogram(Tmp2_5k~1, MT, map=TRUE, cutoff=60000, width=60000/60), main=list("Western WV", cex=2.9), col.regions=color, at=ramp, colorkey=list(at=ramp, labels=list(at=c(0,20,40,60), labels=c(0,20,40,60), cex=1.5)), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label="Distance to points (km)", cex=2), scales=list(x=list(at=c(-80000,-60000,-40000,-20000,0,20000,40000,60000,80000), labels=c(80,60,40,20,0,20,40,60,80), cex=2), y=list(at=c(-80000,-60000,-40000,-20000,0,20000,40000,60000,80000), labels=c(80,60,40,20,0,20,40,60,80), cex=2)), strip=FALSE)
p5 = plot(variogram(Tmp2_5k~1, NWPANY, map=TRUE, cutoff=50000, width=50000/20), main=list("Northwest NY & PA", cex=2.9), col.regions=color, at=ramp, colorkey=list(at=ramp, labels=list(at=c(0,20,40,60), labels=c(0,20,40,60), cex=1.5)), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label="Distance to points (km)", cex=2), scales=list(x=list(at=c(-50000,-25000,0,25000,50000), labels=c(50,25,0,25,50), cex=2), y=list(at=c(-50000,-25000,0,25000,50000), labels=c(50,25,0,25,50), cex=2)), strip=FALSE)  
p6 = plot(variogram(Tmp2_5k~1, SWPA, map=TRUE, cutoff=60000, width=60000/40), main=list("Southwest PA", cex=2.9), col.regions=color, at=ramp, colorkey=list(at=ramp, labels=list(at=c(0,20,40,60), labels=c(0,20,40,60), cex=1.5)), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label="Distance to points (km)", cex=2), scales=list(x=list(at=c(-50000,-25000,0,25000,50000), labels=c(50,25,0,25,50), cex=2), y=list(at=c(-50000,-25000,0,25000,50000), labels=c(50,25,0,25,50), cex=2)), strip=FALSE) 
#p10 = plot(variogram(Tmp2_5k~1, VR, map=TRUE, cutoff=60000, width=60000/40), main=list("Valley and Ridge", cex=2.9), col.regions=color, at=ramp, colorkey=list(at=ramp, labels=list(at=c(0,20,40,60), labels=c(0,20,40,60), cex=1.5)), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label="Distance to points (km)", cex=2), scales=list(x=list(at=c(-150000,-100000,-50000,0,50000,100000,150000), labels=c(150,100,50,0,50,100,150), cex=2), y=list(at=c(-150000,-100000,-50000,0,50000,100000,150000), labels=c(150,100,50,0,50,100,150), cex=2)), strip=FALSE)
p7 = plot(variogram(Tmp2_5k~1, WPA, map=TRUE, cutoff=60000, width=60000/40), main=list("Western PA", cex=2.9), col.regions=color, at=ramp, colorkey=list(at=ramp, labels=list(at=c(0,20,40,60), labels=c(0,20,40,60), cex=1.5)), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label="Distance to points (km)", cex=2), scales=list(x=list(at=c(-50000,-25000,0,25000,50000), labels=c(50,25,0,25,50), cex=2), y=list(at=c(-50000,-25000,0,25000,50000), labels=c(50,25,0,25,50), cex=2)), strip=FALSE) 

#Temp3.5km
ramp = seq(0,varmax,by=50)
colramp = colorRampPalette(c('green', 'yellow', 'orange', 'red'))
color = colramp(length(ramp))

p1 = plot(variogram(Tmp3_5k~1, CT, map=TRUE, cutoff=50000, width=50000/40), main=list(label="Chataqua, NY", cex=2.9), col.regions=color, at=ramp, colorkey=list(at=ramp, labels=list(at=c(0,20,40,60), labels=c(0,20,40,60), cex=1.5)), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label="Distance to points (km)", cex=2), scales=list(x=list(at=c(-50000,-25000,0,25000,50000), labels=c(50,25,0,25,50), cex=2), y=list(at=c(-50000,-25000,0,25000,50000), labels=c(50,25,0,25,50), cex=2)), strip=FALSE) 
p2 = plot(variogram(Tmp3_5k~1, CNY, map=TRUE, cutoff=50000, width=50000/10), main=list("Central NY", cex=2.9), col.regions=color, at=ramp, colorkey=list(at=ramp, labels=list(at=c(0,20,40,60), labels=c(0,20,40,60), cex=1.5)), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label="Distance to points (km)", cex=2), scales=list(x=list(at=c(-50000,-25000,0,25000,50000), labels=c(50,25,0,25,50), cex=2), y=list(at=c(-50000,-25000,0,25000,50000), labels=c(50,25,0,25,50), cex=2)), strip=FALSE)
p9 = plot(variogram(Tmp3_5k~1, CWV, map=TRUE, cutoff=50000, width=50000/60), main=list("Central WV", cex=2.9), col.regions=color, at=ramp, colorkey=list(at=ramp, labels=list(at=c(0,20,40,60), labels=c(0,20,40,60), cex=1.5)), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label="Distance to points (km)", cex=2), scales=list(x=list(at=c(-120000,-80000,-40000,0,40000,80000,120000), labels=c(120,80,40,0,40,80,120), cex=2), y=list(at=c(-120000,-80000,-40000,0,40000,80000,120000), labels=c(120,80,40,0,40,80,120), cex=2)), strip=FALSE) 
p3 = plot(variogram(Tmp3_5k~1, ENY, map=TRUE, cutoff=60000, width=60000/12), main=list("Eastern NY", cex=2.9), col.regions=color, at=ramp, colorkey=list(at=ramp, labels=list(at=c(0,20,40,60), labels=c(0,20,40,60), cex=1.5)), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label="Distance to points (km)", cex=2), scales=list(x=list(at=c(-60000,-40000,-20000,0,20000,40000,60000), labels=c(60,40,20,0,20,40,60), cex=2), y=list(at=c(-60000,-40000,-20000,0,20000,40000,60000), labels=c(60,40,20,0,20,40,60), cex=2)), strip=FALSE) #near vertical
p4 = plot(variogram(Tmp3_5k~1, ENYPA, map=TRUE, cutoff=60000, width=60000/30), main=list("Eastern NY & PA", cex=2.9), col.regions=color, at=ramp, colorkey=list(at=ramp, labels=list(at=c(0,20,40,60), labels=c(0,20,40,60), cex=1.5)), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label="Distance to points (km)", cex=2), scales=list(x=list(at=c(-50000,-25000,0,25000,50000), labels=c(50,25,0,25,50), cex=2), y=list(at=c(-50000,-25000,0,25000,50000), labels=c(50,25,0,25,50), cex=2)), strip=FALSE) #15 degrees
p8 = plot(variogram(Tmp3_5k~1, MT, map=TRUE, cutoff=60000, width=60000/60), main=list("Western WV", cex=2.9), col.regions=color, at=ramp, colorkey=list(at=ramp, labels=list(at=c(0,20,40,60), labels=c(0,20,40,60), cex=1.5)), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label="Distance to points (km)", cex=2), scales=list(x=list(at=c(-80000,-60000,-40000,-20000,0,20000,40000,60000,80000), labels=c(80,60,40,20,0,20,40,60,80), cex=2), y=list(at=c(-80000,-60000,-40000,-20000,0,20000,40000,60000,80000), labels=c(80,60,40,20,0,20,40,60,80), cex=2)), strip=FALSE)
p5 = plot(variogram(Tmp3_5k~1, NWPANY, map=TRUE, cutoff=60000, width=60000/20), main=list("Northwest NY & PA", cex=2.9), col.regions=color, at=ramp, colorkey=list(at=ramp, labels=list(at=c(0,20,40,60), labels=c(0,20,40,60), cex=1.5)), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label="Distance to points (km)", cex=2), scales=list(x=list(at=c(-50000,-25000,0,25000,50000), labels=c(50,25,0,25,50), cex=2), y=list(at=c(-50000,-25000,0,25000,50000), labels=c(50,25,0,25,50), cex=2)), strip=FALSE)  
p6 = plot(variogram(Tmp3_5k~1, SWPA, map=TRUE, cutoff=60000, width=60000/40), main=list("Southwest PA", cex=2.9), col.regions=color, at=ramp, colorkey=list(at=ramp, labels=list(at=c(0,20,40,60), labels=c(0,20,40,60), cex=1.5)), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label="Distance to points (km)", cex=2), scales=list(x=list(at=c(-50000,-25000,0,25000,50000), labels=c(50,25,0,25,50), cex=2), y=list(at=c(-50000,-25000,0,25000,50000), labels=c(50,25,0,25,50), cex=2)), strip=FALSE) 
#p10 = plot(variogram(Tmp3_5k~1, VR, map=TRUE, cutoff=60000, width=60000/40), main=list("Valley and Ridge", cex=2.9), col.regions=color, at=ramp, colorkey=list(at=ramp, labels=list(at=c(0,20,40,60), labels=c(0,20,40,60), cex=1.5)), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label="Distance to points (km)", cex=2), scales=list(x=list(at=c(-150000,-100000,-50000,0,50000,100000,150000), labels=c(150,100,50,0,50,100,150), cex=2), y=list(at=c(-150000,-100000,-50000,0,50000,100000,150000), labels=c(150,100,50,0,50,100,150), cex=2)), strip=FALSE)
p7 = plot(variogram(Tmp3_5k~1, WPA, map=TRUE, cutoff=60000, width=60000/40), main=list("Western PA", cex=2.9), col.regions=color, at=ramp, colorkey=list(at=ramp, labels=list(at=c(0,20,40,60), labels=c(0,20,40,60), cex=1.5)), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label="Distance to points (km)", cex=2), scales=list(x=list(at=c(-50000,-25000,0,25000,50000), labels=c(50,25,0,25,50), cex=2), y=list(at=c(-50000,-25000,0,25000,50000), labels=c(50,25,0,25,50), cex=2)), strip=FALSE) 


par(mfrow=c(3,3))
png("Anisotropy.png", width=20, height=20, units="in", res=150)
plot(p1, split = c(1,1,3,3), more=T) 
plot(p2, split = c(2,1,3,3), more=T) 
plot(p3, split = c(3,1,3,3), more=T) 
plot(p4, split = c(1,2,3,3), more=T) 
plot(p5, split = c(2,2,3,3), more=T) 
plot(p6, split = c(3,2,3,3), more=T) 
plot(p7, split = c(1,3,3,3), more=T)
plot(p8, split = c(2,3,3,3), more=T)
plot(p9, split = c(3,3,3,3), more=F)
dev.off()

#MAKE DIRECTIONAL VARIOGRAMS
#Directional Variograms based on the major and minor axes of anisotropy.

#HeatFlow
(v.CTa <- variogram(Qs~1, CT, alpha=seq(0,180,10), cutoff=60000, width=60000/50)) #10-20
(v.CNYa <- variogram(Qs~1, CNY, alpha=seq(0,180,10), cutoff=60000, width=60000/10)) #Not enough data to check.
(v.CWVa <- variogram(Qs~1, CWV, alpha=seq(0,180,10), cutoff=60000, width=60000/50)) #30 
(v.ENYa <- variogram(Qs~1, ENY, alpha=seq(0,180,10), cutoff=60000, width=60000/10)) #45 degrees      
(v.ENYPAa <- variogram(Qs~1, ENYPA, alpha=seq(0,180,10), cutoff=60000, width=60000/30)) #10 degrees   
(v.MTa <- variogram(Qs~1, MT, alpha=seq(0,180,10), cutoff=60000, width=60000/60)) #10-20 degrees
(v.NWPANYa <- variogram(Qs~1, NWPANY, alpha=seq(0,180,10), cutoff=60000, width=60000/20)) #100? maybe none   
(v.SWPAa <- variogram(Qs~1, SWPA, alpha=seq(0,180,10), cutoff=60000, width=60000/50)) #20
(v.WPAa <- variogram(Qs~1, WPA, alpha=seq(0,180,10), cutoff=60000, width=60000/50)) #iSOTROPIC

(v.CTa <- variogram(Qs~1, CT, alpha=c(10,100), cutoff=60000, width=60000/50))
(v.CNYa <- variogram(Qs~1, CNY, alpha=c(0,45,90,135), cutoff=60000, width=60000/10))
(v.CWVa <- variogram(Qs~1, CWV, alpha=c(5,95), cutoff=60000, width=60000/50))  
(v.ENYa <- variogram(Qs~1, ENY, alpha=c(45,135), cutoff=60000, width=60000/10))       
(v.ENYPAa <- variogram(Qs~1, ENYPA, alpha=c(10,100), cutoff=60000, width=60000/30))   
(v.MTa <- variogram(Qs~1, MT, alpha=c(30, 120), cutoff=60000, width=60000/60)) 
(v.NWPANYa <- variogram(Qs~1, NWPANY, alpha=c(0,45,90,135), cutoff=60000, width=60000/20))    
(v.SWPAa <- variogram(Qs~1, SWPA, alpha=c(20,110), cutoff=60000, width=60000/50)) 
(v.WPAa <- variogram(Qs~1, WPA, alpha=c(0,45,90,135), cutoff=60000, width=60000/50)) 

#Depth80C
(v.CTa <- variogram(Dpth80C~1, CT, alpha=seq(0,180,10), cutoff=80000, width=80000/60)) #10-20
(v.CNYa <- variogram(Dpth80C~1, CNY, alpha=seq(0,180,10), cutoff=60000, width=60000/10)) #Not enough data
(v.CWVa <- variogram(Dpth80C~1, CWV, alpha=seq(0,180,10), cutoff=60000, width=60000/50)) #20-30
(v.ENYa <- variogram(Dpth80C~1, ENY, alpha=seq(0,180,10), cutoff=60000, width=60000/10)) #Not sure
(v.ENYPAa <- variogram(Dpth80C~1, ENYPA, alpha=seq(0,180,10), cutoff=60000, width=60000/30)) #50-70   
(v.MTa <- variogram(Dpth80C~1, MT, alpha=seq(0,180,10), cutoff=60000, width=60000/60)) #iso?
(v.NWPANYa <- variogram(Dpth80C~1, NWPANY, alpha=seq(0,180,10), cutoff=60000, width=60000/20)) # iso?
(v.SWPAa <- variogram(Dpth80C~1, SWPA, alpha=seq(0,180,10), cutoff=60000, width=60000/40)) #40
(v.WPAa <- variogram(Dpth80C~1, WPA, alpha=seq(0,180,10), cutoff=60000, width=60000/40)) #iso?

(v.CTa <- variogram(Dpth80C~1, CT, alpha=c(10,100), cutoff=80000, width=80000/60))
(v.CNYa <- variogram(Dpth80C~1, CNY, alpha=c(0,45,90,135), cutoff=60000, width=60000/10))
(v.CWVa <- variogram(Dpth80C~1, CWV, alpha=c(25,115), cutoff=60000, width=60000/50))  
(v.ENYa <- variogram(Dpth80C~1, ENY, alpha=c(45,135), cutoff=60000, width=60000/10))       
(v.ENYPAa <- variogram(Dpth80C~1, ENYPA, alpha=c(60,150), cutoff=60000, width=60000/30))   
(v.MTa <- variogram(Dpth80C~1, MT, alpha=c(5, 105), cutoff=60000, width=60000/60)) 
(v.NWPANYa <- variogram(Dpth80C~1, NWPANY, alpha=c(0,45,90,135), cutoff=60000, width=60000/20))    
(v.SWPAa <- variogram(Dpth80C~1, SWPA, alpha=c(40,130), cutoff=60000, width=60000/40)) 
(v.WPAa <- variogram(Dpth80C~1, WPA, alpha=c(0,45,90,135), cutoff=60000, width=60000/40))

#Depth100C
(v.CTa <- variogram(Dpt100C~1, CT, alpha=seq(0,180,10), cutoff=80000, width=80000/60)) #10-20
(v.CNYa <- variogram(Dpt100C~1, CNY, alpha=seq(0,180,25), cutoff=55000, width=55000/10)) #Not enough data for 10 degree angles. Used 30. Clear difference, but angles vary greatly
(v.CWVa <- variogram(Dpt100C~1, CWV, alpha=seq(0,180,10), cutoff=60000, width=60000/50)) #10-30
(v.ENYa <- variogram(Dpt100C~1, ENY, alpha=seq(0,180,10), cutoff=80000, width=80000/25)) #50
(v.ENYPAa <- variogram(Dpt100C~1, ENYPA, alpha=seq(0,180,10), cutoff=40000, width=40000/40)) #50-70   
(v.MTa <- variogram(Dpt100C~1, MT, alpha=seq(0,180,10), cutoff=60000, width=60000/60)) #10-20
(v.NWPANYa <- variogram(Dpt100C~1, NWPANY, alpha=seq(0,180,10), cutoff=50000, width=50000/30)) # iso?
(v.SWPAa <- variogram(Dpt100C~1, SWPA, alpha=seq(0,180,10), cutoff=60000, width=60000/40)) #40
(v.WPAa <- variogram(Dpt100C~1, WPA, alpha=seq(0,180,10), cutoff=60000, width=60000/40)) #20

(v.CTa <- variogram(Dpt100C~1, CT, alpha=c(10,100), cutoff=80000, width=80000/60))
(v.CNYa <- variogram(Dpt100C~1, CNY, alpha=c(0,45,90,135), cutoff=55000, width=55000/10))
(v.CWVa <- variogram(Dpt100C~1, CWV, alpha=c(20,110), cutoff=60000, width=60000/50))  
(v.ENYa <- variogram(Dpt100C~1, ENY, alpha=c(50,140), cutoff=80000, width=80000/25))       
(v.ENYPAa <- variogram(Dpt100C~1, ENYPA, alpha=c(60,150), cutoff=40000, width=40000/40))   
(v.MTa <- variogram(Dpt100C~1, MT, alpha=c(15, 105), cutoff=60000, width=60000/60)) 
(v.NWPANYa <- variogram(Dpt100C~1, NWPANY, alpha=c(0,45,90,135), cutoff=50000, width=50000/30))    
(v.SWPAa <- variogram(Dpt100C~1, SWPA, alpha=c(40,130), cutoff=60000, width=60000/40)) 
(v.WPAa <- variogram(Dpt100C~1, WPA, alpha=c(20,110), cutoff=60000, width=60000/40))

#Temp1_5km
(v.CTa <- variogram(Tmp1_5k~1, CT, alpha=seq(0,180,10), cutoff=50000, width=50000/40)) #10-20
(v.CNYa <- variogram(Tmp1_5k~1, CNY, alpha=seq(0,180,10), cutoff=40000, width=40000/10)) #30
(v.CWVa <- variogram(Tmp1_5k~1, CWV, alpha=seq(0,180,10), cutoff=60000, width=60000/60)) #10
(v.ENYa <- variogram(Tmp1_5k~1, ENY, alpha=seq(0,180,10), cutoff=80000, width=80000/25)) #iso
(v.ENYPAa <- variogram(Tmp1_5k~1, ENYPA, alpha=seq(0,180,10), cutoff=60000, width=60000/30)) #20 
(v.MTa <- variogram(Tmp1_5k~1, MT, alpha=seq(0,180,10), cutoff=60000, width=60000/600)) #20 (short range signal)
(v.NWPANYa <- variogram(Tmp1_5k~1, NWPANY, alpha=seq(0,180,10), cutoff=60000, width=60000/30)) #140
(v.SWPAa <- variogram(Tmp1_5k~1, SWPA, alpha=seq(0,180,10), cutoff=60000, width=60000/40)) #40
(v.WPAa <- variogram(Tmp1_5k~1, WPA, alpha=seq(0,180,10), cutoff=60000, width=60000/40)) #iso

(v.CTa <- variogram(Tmp1_5k~1, CT, alpha=c(15,105), cutoff=50000, width=50000/40))
(v.CNYa <- variogram(Tmp1_5k~1, CNY, alpha=c(30,120), cutoff=40000, width=40000/10))
(v.CWVa <- variogram(Tmp1_5k~1, CWV, alpha=c(10,100), cutoff=60000, width=60000/60)) 
(v.ENYa <- variogram(Tmp1_5k~1, ENY, alpha=c(30,60,90,120), cutoff=80000, width=80000/15))
(v.ENYPAa <- variogram(Tmp1_5k~1, ENYPA, alpha=c(20,110), cutoff=60000, width=60000/60))    
(v.MTa <- variogram(Tmp1_5k~1, MT, alpha=c(20,110), cutoff=60000, width=60000/60)) 
(v.NWPANYa <- variogram(Tmp1_5k~1, NWPANY, alpha=c(140,230), cutoff=50000, width=50000/20)) 
(v.SWPAa <- variogram(Tmp1_5k~1, SWPA, alpha=c(40,130), cutoff=60000, width=60000/40)) 
(v.WPAa <- variogram(Tmp1_5k~1, WPA, alpha=c(40,130), cutoff=60000, width=60000/40)) 


#Temp2_5km
(v.CTa <- variogram(Tmp2_5k~1, CT, alpha=seq(0,180,10), cutoff=80000, width=80000/40)) #10-20
(v.CNYa <- variogram(Tmp2_5k~1, CNY, alpha=seq(0,180,10), cutoff=55000, width=55000/10)) #Not enough data
(v.CWVa <- variogram(Tmp2_5k~1, CWV, alpha=seq(0,180,10), cutoff=60000, width=60000/60)) #10
(v.ENYa <- variogram(Tmp2_5k~1, ENY, alpha=seq(0,180,10), cutoff=80000, width=80000/15)) #10
(v.ENYPAa <- variogram(Tmp2_5k~1, ENYPA, alpha=seq(0,180,10), cutoff=60000, width=60000/30)) #20 
(v.MTa <- variogram(Tmp2_5k~1, MT, alpha=seq(0,180,10), cutoff=60000, width=60000/60)) #20 (short range signal)
(v.NWPANYa <- variogram(Tmp2_5k~1, NWPANY, alpha=seq(0,180,10), cutoff=50000, width=50000/20)) #140
(v.SWPAa <- variogram(Tmp2_5k~1, SWPA, alpha=seq(0,180,10), cutoff=60000, width=60000/40)) #40
(v.WPAa <- variogram(Tmp2_5k~1, WPA, alpha=seq(0,180,10), cutoff=60000, width=60000/40)) #40

(v.CTa <- variogram(Tmp2_5k~1, CT, alpha=c(10,100), cutoff=80000, width=80000/40))
(v.CNYa <- variogram(Tmp2_5k~1, CNY, alpha=c(0,45,90,135), cutoff=55000, width=55000/10))
(v.CWVa <- variogram(Tmp2_5k~1, CWV, alpha=c(10,100), cutoff=60000, width=60000/60)) 
(v.ENYa <- variogram(Tmp2_5k~1, ENY, alpha=c(10,100), cutoff=80000, width=80000/15))
(v.ENYPAa <- variogram(Tmp2_5k~1, ENYPA, alpha=c(20,110), cutoff=60000, width=60000/60))    
(v.MTa <- variogram(Tmp2_5k~1, MT, alpha=c(20,110), cutoff=60000, width=60000/60)) 
(v.NWPANYa <- variogram(Tmp2_5k~1, NWPANY, alpha=c(140,230), cutoff=50000, width=50000/20)) 
(v.SWPAa <- variogram(Tmp2_5k~1, SWPA, alpha=c(40,130), cutoff=60000, width=60000/40)) 
(v.WPAa <- variogram(Tmp2_5k~1, WPA, alpha=c(40,130), cutoff=60000, width=60000/40)) 

#Temp3_5km
(v.CTa <- variogram(Tmp3_5k~1, CT, alpha=seq(0,180,10), cutoff=50000, width=50000/40)) #10-20
(v.CNYa <- variogram(Tmp3_5k~1, CNY, alpha=seq(0,180,10), cutoff=50000, width=50000/10)) #Not enough data
(v.CWVa <- variogram(Tmp3_5k~1, CWV, alpha=seq(0,180,10), cutoff=50000, width=50000/60)) #20-30
(v.ENYa <- variogram(Tmp3_5k~1, ENY, alpha=seq(0,180,10), cutoff=60000, width=60000/12)) #?
(v.ENYPAa <- variogram(Tmp3_5k~1, ENYPA, alpha=seq(0,180,10), cutoff=60000, width=60000/30)) #20   
(v.MTa <- variogram(Tmp3_5k~1, MT, alpha=seq(0,180,10), cutoff=60000, width=60000/60)) #45
(v.NWPANYa <- variogram(Tmp3_5k~1, NWPANY, alpha=seq(0,180,10), cutoff=60000, width=60000/20)) #120
(v.SWPAa <- variogram(Tmp3_5k~1, SWPA, alpha=seq(0,180,10), cutoff=60000, width=60000/40)) #40
(v.WPAa <- variogram(Tmp3_5k~1, WPA, alpha=seq(0,180,10), cutoff=60000, width=60000/40)) #iso?

(v.CTa <- variogram(Tmp3_5k~1, CT, alpha=c(15,105), cutoff=50000, width=50000/40)) #10-20
(v.CNYa <- variogram(Tmp3_5k~1, CNY, alpha=c(0,45,90,135), cutoff=50000, width=50000/10)) #Not enough data
(v.CWVa <- variogram(Tmp3_5k~1, CWV, alpha=c(25,115), cutoff=50000, width=50000/60)) #20-30
(v.ENYa <- variogram(Tmp3_5k~1, ENY, alpha=c(0,45,90,135), cutoff=60000, width=60000/12)) #?
(v.ENYPAa <- variogram(Tmp3_5k~1, ENYPA, alpha=c(20,110), cutoff=60000, width=60000/30)) #20   
(v.MTa <- variogram(Tmp3_5k~1, MT, alpha=c(45,135), cutoff=60000, width=60000/60)) #45
(v.NWPANYa <- variogram(Tmp3_5k~1, NWPANY, alpha=c(120,210), cutoff=60000, width=60000/20)) #120
(v.SWPAa <- variogram(Tmp3_5k~1, SWPA, alpha=c(40,130), cutoff=60000, width=60000/40)) #40
(v.WPAa <- variogram(Tmp3_5k~1, WPA, alpha=c(0,45,90,135), cutoff=60000, width=60000/40)) #iso?


##PLOT THE SAMPLE VARIOGRAMS for Anisotropy##
p1 = plot(v.CTa, plot.numbers=F, xlab="Chataqua, NY", ylab=expression(paste("Semivariance (",degree,"C)")^2))
p2 = plot(v.CNYa, plot.numbers=F, xlab="Central NY", ylab=expression(paste("Semivariance (",degree,"C)")^2))     
p9 = plot(v.CWVa, plot.numbers=F, xlab="Central WV", ylab=expression(paste("Semivariance (",degree,"C)")^2)) 
p3 = plot(v.ENYa, plot.numbers=F, xlab="Eastern NY", ylab=expression(paste("Semivariance (",degree,"C)")^2))
p4 = plot(v.ENYPAa,plot.numbers=F, xlab="Eastern NY & PA", ylab=expression(paste("Semivariance (",degree,"C)")^2))
p8 = plot(v.MTa, plot.numbers=F, xlab="Western WV", ylab=expression(paste("Semivariance (",degree,"C)")^2))
p5 = plot(v.NWPANYa,plot.numbers=F, xlab="Northwest NY & PA", ylab=expression(paste("Semivariance (",degree,"C)")^2)) 
p6 = plot(v.SWPAa, plot.numbers=F, xlab="Southwest PA", ylab=expression(paste("Semivariance (",degree,"C)")^2)) 
#p10 = plot(v.VRa, plot.numbers=F, xlab="Valley and Ridge", ylab=expression(paste("Semivariance (",degree,"C)")^2)) 
p7 = plot(v.WPAa, plot.numbers=F, xlab="Western PA", ylab=expression(paste("Semivariance (",degree,"C)")^2)) 


par(mfrow=c(3,3))
plot(p1, split = c(1,1,3,3), more=T) 
plot(p2, split = c(2,1,3,3), more=T) 
plot(p3, split = c(3,1,3,3), more=T) 
plot(p4, split = c(1,2,3,3), more=T) 
plot(p5, split = c(2,2,3,3), more=T) 
plot(p6, split = c(3,2,3,3), more=T) 
plot(p7, split = c(1,3,3,3), more=T)
plot(p8, split = c(2,3,3,3), more=T)
plot(p9, split = c(3,3,3,3), more=F)


##PLOT THE SAMPLE VARIOGRAMS USED FOR MODELLING. 
#Be sure to place the ones that need anisotropy into here

#HeatFlow
p1 = plot(v.CTa, ylim=c(0,200), plot.numbers=F, xlab="Chataqua, NY", ylab=expression(paste("Semivariance (mW/m)")^2))
p2 = plot(v.CNY, ylim=c(0,200), plot.numbers=F, xlab="Central NY", ylab=expression(paste("Semivariance (mW/m)")^2))
p9 = plot(v.CWVa, ylim=c(0,200), plot.numbers=F, xlab="Central WV", ylab=expression(paste("Semivariance (mW/m)")^2))
p3 = plot(v.ENYa, ylim=c(0,200), plot.numbers=F, xlab="Eastern NY", ylab=expression(paste("Semivariance (mW/m)")^2))
p4 = plot(v.ENYPAa, ylim=c(0,200), plot.numbers=F, xlab="Eastern NY & PA", ylab=expression(paste("Semivariance (mW/m)")^2))
p8 = plot(v.MTa, ylim=c(0,200), plot.numbers=F, xlab="Western WV", ylab=expression(paste("Semivariance (mW/m)")^2))
p5 = plot(v.NWPANY, ylim=c(0,200), plot.numbers=F, xlab="Northwest NY & PA", ylab=expression(paste("Semivariance (mW/m)")^2))
p6 = plot(v.SWPAa, ylim=c(0,200), plot.numbers=F, xlab="Southwest PA", ylab=expression(paste("Semivariance (mW/m)")^2))
#p10 = plot(v.VRa, ylim=c(0,200), plot.numbers=F, xlab="Valley and Ridge", ylab=expression(paste("Semivariance (mW/m)")^2))
p7 = plot(v.WPA, ylim=c(0,200), plot.numbers=F, xlab="Western PA", ylab=expression(paste("Semivariance (mW/m)")^2))

#Temp1.5km
p1 = plot(v.CTa, ylim=c(0,10), plot.numbers=F, xlab="Chataqua, NY", ylab=expression(paste("Semivariance (mW/m)")^2))
p2 = plot(v.CNY, ylim=c(0,15), plot.numbers=F, xlab="Central NY", ylab=expression(paste("Semivariance (mW/m)")^2))
p9 = plot(v.CWVa, ylim=c(0,100), plot.numbers=F, xlab="Central WV", ylab=expression(paste("Semivariance (mW/m)")^2))
p3 = plot(v.ENY, ylim=c(0,200), plot.numbers=F, xlab="Eastern NY", ylab=expression(paste("Semivariance (mW/m)")^2))
p4 = plot(v.ENYPAa, ylim=c(0,300), plot.numbers=F, xlab="Eastern NY & PA", ylab=expression(paste("Semivariance (mW/m)")^2))
p8 = plot(v.MTa, ylim=c(0,100), plot.numbers=F, xlab="Western WV", ylab=expression(paste("Semivariance (mW/m)")^2))
p5 = plot(v.NWPANYa, ylim=c(0,100), plot.numbers=F, xlab="Northwest NY & PA", ylab=expression(paste("Semivariance (mW/m)")^2))
p6 = plot(v.SWPAa, ylim=c(0,50), plot.numbers=F, xlab="Southwest PA", ylab=expression(paste("Semivariance (mW/m)")^2))
#p10 = plot(v.VRa, ylim=c(0,500), plot.numbers=F, xlab="Valley and Ridge", ylab=expression(paste("Semivariance (mW/m)")^2))
p7 = plot(v.WPAa, ylim=c(0,30), plot.numbers=F, xlab="Western PA", ylab=expression(paste("Semivariance (mW/m)")^2))


#Temp2.5km
p1 = plot(v.CTa, ylim=c(0,30), plot.numbers=F, xlab="Chataqua, NY", ylab=expression(paste("Semivariance (mW/m)")^2))
p2 = plot(v.CNY, ylim=c(0,40), plot.numbers=F, xlab="Central NY", ylab=expression(paste("Semivariance (mW/m)")^2))
p9 = plot(v.CWVa, ylim=c(0,200), plot.numbers=F, xlab="Central WV", ylab=expression(paste("Semivariance (mW/m)")^2))
p3 = plot(v.ENYa, ylim=c(0,200), plot.numbers=F, xlab="Eastern NY", ylab=expression(paste("Semivariance (mW/m)")^2))
p4 = plot(v.ENYPAa, ylim=c(0,600), plot.numbers=F, xlab="Eastern NY & PA", ylab=expression(paste("Semivariance (mW/m)")^2))
p8 = plot(v.MTa, ylim=c(0,200), plot.numbers=F, xlab="Western WV", ylab=expression(paste("Semivariance (mW/m)")^2))
p5 = plot(v.NWPANY, ylim=c(0,100), plot.numbers=F, xlab="Northwest NY & PA", ylab=expression(paste("Semivariance (mW/m)")^2))
p6 = plot(v.SWPAa, ylim=c(0,100), plot.numbers=F, xlab="Southwest PA", ylab=expression(paste("Semivariance (mW/m)")^2))
#p10 = plot(v.VRa, ylim=c(0,500), plot.numbers=F, xlab="Valley and Ridge", ylab=expression(paste("Semivariance (mW/m)")^2))
p7 = plot(v.WPAa, ylim=c(0,100), plot.numbers=F, xlab="Western PA", ylab=expression(paste("Semivariance (mW/m)")^2))


#Temp3.5km
p1 = plot(v.CTa, ylim=c(0,50), plot.numbers=F, xlab="Chataqua, NY", ylab=expression(paste("Semivariance (mW/m)")^2))
p2 = plot(v.CNY, ylim=c(0,100), plot.numbers=F, xlab="Central NY", ylab=expression(paste("Semivariance (mW/m)")^2))
p9 = plot(v.CWVa, ylim=c(0,500), plot.numbers=F, xlab="Central WV", ylab=expression(paste("Semivariance (mW/m)")^2))
p3 = plot(v.ENY, ylim=c(0,250), plot.numbers=F, xlab="Eastern NY", ylab=expression(paste("Semivariance (mW/m)")^2))
p4 = plot(v.ENYPAa, ylim=c(0,1200), plot.numbers=F, xlab="Eastern NY & PA", ylab=expression(paste("Semivariance (mW/m)")^2))
p8 = plot(v.MTa, ylim=c(0,500), plot.numbers=F, xlab="Western WV", ylab=expression(paste("Semivariance (mW/m)")^2))
p5 = plot(v.NWPANYa, ylim=c(0,500), plot.numbers=F, xlab="Northwest NY & PA", ylab=expression(paste("Semivariance (mW/m)")^2))
p6 = plot(v.SWPAa, ylim=c(0,150), plot.numbers=F, xlab="Southwest PA", ylab=expression(paste("Semivariance (mW/m)")^2))
#p10 = plot(v.VRa, ylim=c(0,500), plot.numbers=F, xlab="Valley and Ridge", ylab=expression(paste("Semivariance (mW/m)")^2))
p7 = plot(v.WPA, ylim=c(0,100), plot.numbers=F, xlab="Western PA", ylab=expression(paste("Semivariance (mW/m)")^2))

#Depth80C
p1 = plot(v.CTa, ylim=c(0,1000000), plot.numbers=F, xlab="Chataqua, NY", ylab=expression(paste("Semivariance (mW/m)")^2))
p2 = plot(v.CNY, ylim=c(0,1000000), plot.numbers=F, xlab="Central NY", ylab=expression(paste("Semivariance (mW/m)")^2))
p9 = plot(v.CWVa, ylim=c(0,1000000), plot.numbers=F, xlab="Central WV", ylab=expression(paste("Semivariance (mW/m)")^2))
p3 = plot(v.ENY, ylim=c(0,1000000), plot.numbers=F, xlab="Eastern NY", ylab=expression(paste("Semivariance (mW/m)")^2))
p4 = plot(v.ENYPAa, ylim=c(0,5000000), plot.numbers=F, xlab="Eastern NY & PA", ylab=expression(paste("Semivariance (mW/m)")^2))
p8 = plot(v.MTa, ylim=c(0,1000000), plot.numbers=F, xlab="Western WV", ylab=expression(paste("Semivariance (mW/m)")^2))
p5 = plot(v.NWPANY, ylim=c(0,1000000), plot.numbers=F, xlab="Northwest NY & PA", ylab=expression(paste("Semivariance (mW/m)")^2))
p6 = plot(v.SWPAa, ylim=c(0,1000000), plot.numbers=F, xlab="Southwest PA", ylab=expression(paste("Semivariance (mW/m)")^2))
#p10 = plot(v.VRa, ylim=c(0,1000000), plot.numbers=F, xlab="Valley and Ridge", ylab=expression(paste("Semivariance (mW/m)")^2))
p7 = plot(v.WPA, ylim=c(0,1000000), plot.numbers=F, xlab="Western PA", ylab=expression(paste("Semivariance (mW/m)")^2))

#Depth100C
p1 = plot(v.CTa, ylim=c(0,300000), plot.numbers=F, xlab="Chataqua, NY", ylab=expression(paste("Semivariance (mW/m)")^2))
p2 = plot(v.CNY, ylim=c(0,750000), plot.numbers=F, xlab="Central NY", ylab=expression(paste("Semivariance (mW/m)")^2))
p9 = plot(v.CWVa, ylim=c(0,2000000), plot.numbers=F, xlab="Central WV", ylab=expression(paste("Semivariance (mW/m)")^2))
p3 = plot(v.ENY, ylim=c(0,750000), plot.numbers=F, xlab="Eastern NY", ylab=expression(paste("Semivariance (mW/m)")^2))
p4 = plot(v.ENYPAa, ylim=c(0,10000000), plot.numbers=F, xlab="Eastern NY & PA", ylab=expression(paste("Semivariance (mW/m)")^2))
p8 = plot(v.MTa, ylim=c(0,2000000), plot.numbers=F, xlab="Western WV", ylab=expression(paste("Semivariance (mW/m)")^2))
p5 = plot(v.NWPANY, ylim=c(0,1000000), plot.numbers=F, xlab="Northwest NY & PA", ylab=expression(paste("Semivariance (mW/m)")^2))
p6 = plot(v.SWPAa, ylim=c(0,2000000), plot.numbers=F, xlab="Southwest PA", ylab=expression(paste("Semivariance (mW/m)")^2))
#p10 = plot(v.VRa, ylim=c(0,2000000), plot.numbers=F, xlab="Valley and Ridge", ylab=expression(paste("Semivariance (mW/m)")^2))
p7 = plot(v.WPA, ylim=c(0,500000), plot.numbers=F, xlab="Western PA", ylab=expression(paste("Semivariance (mW/m)")^2))


par(mfrow=c(3,3))
plot(p1, split = c(1,1,3,3), more=T) 
plot(p2, split = c(2,1,3,3), more=T) 
plot(p3, split = c(3,1,3,3), more=T) 
plot(p4, split = c(1,2,3,3), more=T) 
plot(p5, split = c(2,2,3,3), more=T) 
plot(p6, split = c(3,2,3,3), more=T) 
plot(p7, split = c(1,3,3,3), more=T)
plot(p8, split = c(2,3,3,3), more=T)
plot(p9, split = c(3,3,3,3), more=F)


##COMPUTE THE VARIOGRAM MODEL##

#HeatFlow
vm.CT <- vgm(psill=4, model="Gau", range=40000, nugget=5.5, anis=c(10,1))
vm.CNY <- vgm(psill=10, model="Gau", range=14000, nugget=18)
vm.CWV <- vgm(psill=40, model="Gau", range=55000, nugget=100, anis=c(5,0.7)) 
vm.ENY <- vgm(psill=15, model="Gau", range=60000, nugget=17, anis=c(45,0.50)) 
vm.ENYPA <- vgm(psill=90, model="Gau", range=25000, nugget=30, anis=c(10,0.58))
vm.MT <- vgm(psill=60, model="Gau", range=40000, nugget=120, anis=c(30,0.75))
vm.NWPANY <- vgm(psill=40, model="Gau", range=40000, nugget=21) 
vm.SWPA <- vgm(psill=10, model="Exp", range=20000, nugget=30, anis=c(20,0.67))
#vm.VR <- vgm(psill=80, model="Gau", range=50000, nugget=90, anis=c(10,0.6))
vm.WPA <- vgm(psill=20, model="Exp", range=50000, nugget=7)

print(plot(v.CTa, model=vm.CT, main="Unfitted Semivariogram Model", xlab="Distance to Points (m)", ylab="Semivariance"))
print(plot(v.CNY, model=vm.CNY, main="Unfitted Semivariogram Model", xlab="Distance to Points (m)", ylab="Semivariance"))
print(plot(v.CWVa, model=vm.CWV, main="Unfitted Semivariogram Model", xlab="Distance to Points (m)", ylab="Semivariance"))
print(plot(v.ENYa, model=vm.ENY, main="Unfitted Semivariogram Model", xlab="Distance to Points (m)", ylab="Semivariance"))
print(plot(v.ENYPAa, model=vm.ENYPA, main="Unfitted Semivariogram Model", xlab="Distance to Points (m)", ylab="Semivariance"))
print(plot(v.MTa, model=vm.MT, main="Unfitted Semivariogram Model", xlab="Distance to Points (m)", ylab="Semivariance"))
print(plot(v.NWPANY, model=vm.NWPANY, main="Unfitted Semivariogram Model", xlab="Distance to Points (m)", ylab="Semivariance"))
print(plot(v.SWPAa, model=vm.SWPA, main="Unfitted Semivariogram Model", xlab="Distance to Points (m)", ylab="Semivariance"))
#print(plot(v.VRa, model=vm.VR, main="Unfitted Semivariogram Model", xlab="Distance to Points (m)", ylab="Semivariance"))
print(plot(v.WPA, model=vm.WPA, main="Unfitted Semivariogram Model", xlab="Distance to Points (m)", ylab="Semivariance"))

#CT
(vmf.CT <- fit.variogram(v.CTa, vm.CT, fit.sills=FALSE, fit.method=6)) 
(vmf.CT <- vgm(30, "Gau", 60000*10000, anis=c(100,.0001), add.to = vmf.CT)) 
(vmf.CT <- fit.variogram(v.CTa, vmf.CT, fit.sills=FALSE, fit.method=6)) 

#CNY
(vmf.CNY <- fit.variogram(v.CNY, vm.CNY)) 

#CWV
(vmf.CWV <- fit.variogram(v.CWVa, vm.CWV, fit.method=6)) 
(vmf.CWV <- vgm(15, "Gau", 40000*10000, anis=c(5,.0001), add.to = vmf.CWV)) 
(vmf.CWV <- fit.variogram(v.CWVa, vmf.CWV, fit.sills=FALSE, fit.method=6)) 

#ENY
(vmf.ENY <- fit.variogram(v.ENYa, vm.ENY, fit.ranges=FALSE, fit.sills=FALSE)) 
(vmf.ENY <- vgm(40, "Gau", 45000*10000, anis=c(135,.0001), add.to = vmf.ENY)) 
(vmf.ENY <- fit.variogram(v.ENYa, vmf.ENY, fit.ranges=FALSE, fit.sills=FALSE)) 

#ENYPA
(vmf.ENYPA <- fit.variogram(v.ENYPAa, vm.ENYPA, fit.sills=FALSE)) 
(vmf.ENYPA <- vgm(150, "Gau", 20000*10000, anis=c(100,.0001), add.to = vmf.ENYPA)) 
(vmf.ENYPA <- fit.variogram(v.ENYPAa, vmf.ENYPA, fit.sills=FALSE)) 

#MT
(vmf.MT <- fit.variogram(v.MTa, vm.MT, fit.method = 6)) #OLS seems like a better fit for all directions.

#NWPANY
(vmf.NWPANY <- fit.variogram(v.NWPANY, vm.NWPANY)) 

#SWPA
(vmf.SWPA <- fit.variogram(v.SWPAa, vm.SWPA))
(vmf.SWPA <- vgm(10, "Gau", 23000*10000, anis=c(20,.0001), add.to = vmf.SWPA))

#VR
#(vmf.VR <- fit.variogram(v.VRa, vm.VR, fit.method=6))

#WPA
(vmf.WPA <- fit.variogram(v.WPA, vm.WPA, fit.method=7))
(vmf.WPA <-  vgm(5, "Gau", 50000*10000, add.to = vmf.WPA))


#Temp1.5km
vm.CT <- vgm(psill=0.5, model="Sph", range=10000, nugget=3, anis=c(15,0.8))
vm.CNY <- vgm(psill=6, model="Gau", range=25000, nugget=4)
vm.CWV <- vgm(psill=17, model="Gau", range=55000, nugget=30, anis=c(10,0.8)) 
vm.ENY <- vgm(psill=50, model="Exp", range=10000, nugget=20) 
vm.ENYPA <- vgm(psill=60, model="Gau", range=35000, nugget=10, anis=c(20,0.7))
vm.MT <- vgm(psill=45, model="Sph", range=5000, nugget=4)
vm.NWPANY <- vgm(psill=60, model="Gau", range=25000, nugget=10) 
vm.SWPA <- vgm(psill=30, model="Exp", range=25000, nugget=35, anis=c(40,0.8))
vm.WPA <- vgm(psill=3, model="Exp", range=20000, nugget=4.5, anis=c(40,0.5))

#CT
(vmf.CT <- fit.variogram(v.CTa, vm.CT, fit.sills=FALSE)) 
(vmf.CT <- vgm(1.8, "Exp", 25000*10000, anis=c(105,.0001), add.to = vmf.CT)) 
(vmf.CT <- fit.variogram(v.CTa, vmf.CT, fit.sills=FALSE)) 
(vmf.CT <- vgm(1.2, "Gau", 20000*10000, anis=c(15,.0001), add.to = vmf.CT)) 

#CNY
(vmf.CNY <- fit.variogram(v.CNY, vm.CNY)) 

#CWV
(vmf.CWV <- fit.variogram(v.CWVa, vm.CWV, fit.sills=FALSE)) 
(vmf.CWV <- vgm(10, "Gau", 40000*10000, anis=c(10,.0001), add.to = vmf.CWV)) 

#ENY
(vmf.ENY <- fit.variogram(v.ENY, vm.ENY))
(vmf.ENY <- vgm(100, "Gau", 50000*10000, anis=c(100,.0001), add.to = vmf.ENY)) 
(vmf.ENY <- fit.variogram(v.ENY, vmf.ENY, fit.ranges=FALSE))
(vmf.ENY <- vgm(30, "Gau", 90000*10000, anis=c(100,.0001), add.to = vmf.ENY)) 
(vmf.ENY <- fit.variogram(v.ENY, vmf.ENY, fit.ranges=FALSE))

#ENYPA
(vmf.ENYPA <- fit.variogram(v.ENYPAa, vm.ENYPA, fit.ranges=FALSE)) 
(vmf.ENYPA <- vgm(300, "Gau", 35000*10000, anis=c(110,.0001), add.to = vmf.ENYPA)) 
(vmf.ENYPA <- fit.variogram(v.ENYPAa, vmf.ENYPA, fit.sills=FALSE)) 

#MT
(vmf.MT <- fit.variogram(v.MTa, vm.MT, fit.sills=FALSE, fit.method=6)) #Terrible fit

#NWPANY
(vmf.NWPANY <- fit.variogram(v.NWPANY, vm.NWPANY, fit.method=6)) #OLS Seems better because of odd behavior around the nugget. 

#SWPA
(vmf.SWPA <- fit.variogram(v.SWPAa, vm.SWPA))

#WPA
(vmf.WPA <- fit.variogram(v.WPA, vm.WPA, fit.ranges=FALSE)) 
(vmf.WPA <- vgm(3, "Gau", 35000*10000, anis=c(40, 0.0001), add.to = vmf.WPA))
(vmf.WPA <- fit.variogram(v.WPA, vmf.WPA, fit.sills=FALSE)) #Bad fit


#Temp2.5km
vm.CT <- vgm(psill=3, model="Exp", range=10000, nugget=7, anis=c(10,0.8))
vm.CNY <- vgm(psill=10, model="Gau", range=20000, nugget=21)
vm.CWV <- vgm(psill=5, model="Gau", range=80000, nugget=75, anis=c(10,0.5)) 
vm.ENY <- vgm(psill=20, model="Sph", range=60000, nugget=40, anis=c(10, 0.9)) 
vm.ENYPA <- vgm(psill=150, model="Gau", range=40000, nugget=50, anis=c(20,0.5))
vm.MT <- vgm(psill=150, model="Gau", range=40000, nugget=100, anis=c(20,0.75))
vm.NWPANY <- vgm(psill=30, model="Sph", range=25000, nugget=30) 
vm.SWPA <- vgm(psill=30, model="Exp", range=25000, nugget=35, anis=c(40,0.8))
vm.WPA <- vgm(psill=20, model="Exp", range=20000, nugget=18, anis=c(40,0.5))

#CT
(vmf.CT <- fit.variogram(v.CTa, vm.CT, fit.method=6)) 
(vmf.CT <- vgm(5, "Gau", 20000*10000, anis=c(100,.0001), add.to = vmf.CT)) #Fit not good
(vmf.CT <- fit.variogram(v.CTa, vmf.CT, fit.ranges=FALSE)) 

#CNY
(vmf.CNY <- fit.variogram(v.CNY, vm.CNY)) 

#CWV
(vmf.CWV <- fit.variogram(v.CWVa, vm.CWV, fit.sills=FALSE)) 
(vmf.CWV <- vgm(100, "Gau", 40000*10000, anis=c(10,.0001), add.to = vmf.CWV)) 
(vmf.CWV <- vgm(35, "Gau", 50000*10000, anis=c(100,.0001), add.to = vmf.CWV)) 

#ENY
(vmf.ENY <- fit.variogram(v.ENY, vm.ENY, fit.sills=FALSE))
(vmf.ENY <- vgm(100, "Gau", 50000*10000, anis=c(100,.0001), add.to = vmf.ENY)) 
(vmf.ENY <- fit.variogram(v.ENY, vmf.ENY, fit.ranges=FALSE))
(vmf.ENY <- vgm(30, "Gau", 90000*10000, anis=c(100,.0001), add.to = vmf.ENY)) 
(vmf.ENY <- fit.variogram(v.ENY, vmf.ENY, fit.ranges=FALSE))

#ENYPA
(vmf.ENYPA <- fit.variogram(v.ENYPAa, vm.ENYPA, fit.sills=FALSE)) 
(vmf.ENYPA <- vgm(300, "Gau", 35000*10000, anis=c(110,.0001), add.to = vmf.ENYPA)) 
(vmf.ENYPA <- fit.variogram(v.ENYPAa, vmf.ENYPA, fit.sills=FALSE)) 

#MT
(vmf.MT <- fit.variogram(v.MTa, vm.MT, fit.method=6)) #Terrible fit

#NWPANY
(vmf.NWPANY <- fit.variogram(v.NWPANY, vm.NWPANY, fit.method=6)) #OLS Seems better because of odd behavior around the nugget. 

#SWPA
(vmf.SWPA <- fit.variogram(v.SWPAa, vm.SWPA))

#WPA
(vmf.WPA <- fit.variogram(v.WPA, vm.WPA, fit.ranges=FALSE)) 
(vmf.WPA <- vgm(500, "Gau", 70000, anis=c(40, 0.8), add.to = vmf.WPA))
(vmf.WPA <- fit.variogram(v.WPA, vmf.WPA, fit.ranges=FALSE)) #Bad fit


#Temp3.5km
vm.CT <- vgm(psill=2, model="Exp", range=10000, nugget=13, anis=c(15,0.8))
vm.CNY <- vgm(psill=20, model="Gau", range=20000, nugget=55)
vm.CWV <- vgm(psill=20, model="Gau", range=1000, nugget=180, anis=c(25,0.5)) 
vm.ENY <- vgm(psill=120, model="Gau", range=50000, nugget=70) 
vm.ENYPA <- vgm(psill=300, model="Gau", range=40000, nugget=100, anis=c(20,0.5))
vm.MT <- vgm(psill=200, model="Gau", range=40000, nugget=200, anis=c(45,0.75))
vm.NWPANY <- vgm(psill=50, model="Gau", range=45000, nugget=80, anis=c(120, 0.75)) 
vm.SWPA <- vgm(psill=35, model="Exp", range=25000, nugget=60, anis=c(40,0.8))
vm.WPA <- vgm(psill=10, model="Gau", range=10000, nugget=18)

#CT
(vmf.CT <- fit.variogram(v.CTa, vm.CT, fit.method=6)) 
(vmf.CT <- vgm(5, "Gau", 37000*10000, anis=c(105,.0001), add.to = vmf.CT)) #Fit not good

#CNY
(vmf.CNY <- fit.variogram(v.CNY, vm.CNY)) 

#CWV
(vmf.CWV <- fit.variogram(v.CWVa, vm.CWV)) 
(vmf.CWV <- vgm(30, "Gau", 40000*10000, anis=c(115,.0001), add.to = vmf.CWV)) 
(vmf.CWV <- fit.variogram(v.CWVa, vmf.CWV, fit.sills=FALSE)) 
(vmf.CWV <- vgm(125, "Gau", 40000*10000, anis=c(25,.0001), add.to = vmf.CWV)) 
(vmf.CWV <- fit.variogram(v.CWVa, vmf.CWV, fit.sills=FALSE)) #Fit not good

#ENY
(vmf.ENY <- fit.variogram(v.ENY, vm.ENY))

#ENYPA
(vmf.ENYPA <- fit.variogram(v.ENYPAa, vm.ENYPA, fit.sills=FALSE)) 
(vmf.ENYPA <- vgm(600, "Gau", 40000*10000, anis=c(110,.0001), add.to = vmf.ENYPA)) 
(vmf.ENYPA <- fit.variogram(v.ENYPAa, vmf.ENYPA, fit.sills=FALSE)) 

#MT
(vmf.MT <- fit.variogram(v.MTa, vm.MT, fit.ranges=FALSE, fit.method = 6)) #Terrible fit

#NWPANY
(vmf.NWPANY <- fit.variogram(v.NWPANY, vm.NWPANY)) #OLS Seems better. 

#SWPA
(vmf.SWPA <- fit.variogram(v.SWPAa, vm.SWPA))

#WPA
(vmf.WPA <- fit.variogram(v.WPA, vm.WPA)) 
(vmf.WPA <- vgm(10000, "Gau", 1000000, add.to = vmf.WPA))
(vmf.WPA <- fit.variogram(v.WPA, vmf.WPA)) #Bad fit


#Depth80C
vm.CT <- vgm(psill=30000, model="Exp", range=25000, nugget=50000, anis=c(10,0.8))
vm.CNY <- vgm(psill=100000, model="Gau", range=20000, nugget=80000)
vm.CWV <- vgm(psill=180000, model="Exp", range=60000, nugget=350000, anis=c(25,0.5)) 
vm.ENY <- vgm(psill=100000, model="Gau", range=40000, nugget=70000) 
vm.ENYPA <- vgm(psill=2000000, model="Gau", range=70000, nugget=1900000, anis=c(60,0.3))
vm.MT <- vgm(psill=400000, model="Exp", range=40000, nugget=350000, anis=c(5,0.75))
vm.NWPANY <- vgm(psill=300000, model="Gau", range=50000, nugget=100000) 
vm.SWPA <- vgm(psill=350000, model="Exp", range=20000, nugget=300000, anis=c(40,0.50))
vm.WPA <- vgm(psill=100000, model="Gau", range=40000, nugget=100000)

#CT
(vmf.CT <- fit.variogram(v.CTa, vm.CT)) 
(vmf.CT <- vgm(29000, "Gau", 37000*10000, anis=c(100,.0001), add.to = vmf.CT)) 
(vmf.CT <- fit.variogram(v.CTa, vmf.CT)) 

#CNY
(vmf.CNY <- fit.variogram(v.CNY, vm.CNY)) 

#CWV
(vmf.CWV <- fit.variogram(v.CWVa, vm.CWV)) 

#ENY
(vmf.ENY <- fit.variogram(v.ENY, vm.ENY, fit.sills=FALSE))

#ENYPA
(vmf.ENYPA <- fit.variogram(v.ENYPAa, vm.ENYPA)) 

#MT
(vmf.MT <- fit.variogram(v.MTa, vm.MT, fit.method = 6)) #OLS seems like a better fit for all directions.

#NWPANY
(vmf.NWPANY <- fit.variogram(v.NWPANY, vm.NWPANY, fit.method=6)) #OLS Seems better. 

#SWPA
(vmf.SWPA <- fit.variogram(v.SWPAa, vm.SWPA))

#WPA
(vmf.WPA <- fit.variogram(v.WPA, vm.WPA)) 
(vmf.WPA <- vgm(30000, "Gau", 40000, add.to = vmf.WPA))
(vmf.WPA <- fit.variogram(v.WPA, vmf.WPA))


#Depth100C
vm.CT <- vgm(psill=20000, model="Exp", range=25000, nugget=80000, anis=c(10,0.8))
vm.CNY <- vgm(psill=100000, model="Gau", range=15000, nugget=250000)
vm.CWV <- vgm(psill=150000, model="Exp", range=20000, nugget=800000, anis=c(20,0.5)) 
vm.ENY <- vgm(psill=10000000, model="Gau", range=800000, nugget=185000) 
vm.ENYPA <- vgm(psill=800000, model="Gau", range=10000, nugget=1900000, anis=c(20,0.75))
vm.MT <- vgm(psill=150000, model="Exp", range=10000, nugget=750000, anis=c(15,0.75))
vm.NWPANY <- vgm(psill=300000, model="Gau", range=40000, nugget=200000) 
vm.SWPA <- vgm(psill=500000, model="Exp", range=20000, nugget=700000, anis=c(40,0.5))
vm.WPA <- vgm(psill=50000, model="Exp", range=10000, nugget=100000)

#CT
(vmf.CT <- fit.variogram(v.CTa, vm.CT)) 
(vmf.CT <- vgm(29000, "Gau", 37000*10000, anis=c(100,.0001), add.to = vmf.CT)) 
(vmf.CT <- fit.variogram(v.CTa, vmf.CT)) 

#CNY
(vmf.CNY <- fit.variogram(v.CNY, vm.CNY, fit.ranges=FALSE)) 

#CWV
(vmf.CWV <- fit.variogram(v.CWVa, vm.CWV, fit.sills=FALSE)) 
(vmf.CWV <- vgm(400000, "Gau", 30000*10000, anis=c(20,.0001), add.to = vmf.CWV)) 
(vmf.CWV <- fit.variogram(v.CWVa, vmf.CWV, fit.sills=FALSE)) 

#ENY
(vmf.ENY <- fit.variogram(v.ENY, vm.ENY, fit.range=FALSE, fit.method=6))

#ENYPA
(vmf.ENYPA <- fit.variogram(v.ENYPAa, vm.ENYPA, fit.sills=FALSE)) 
(vmf.ENYPA <- vgm(6000000, "Gau", 30000*10000, anis=c(60,.0001), add.to = vmf.ENYPA)) 
(vmf.ENYPA <- fit.variogram(v.ENYPAa, vmf.ENYPA, fit.ranges=FALSE)) 
(vmf.ENYPA <- vgm(600000, "Gau", 15000*10000, anis=c(150,.0001), add.to = vmf.ENYPA)) 

#MT
(vmf.MT <- fit.variogram(v.MTa, vm.MT, fit.sills=FALSE))
(vmf.MT <- vgm(200000, "Exp", 20000*10000, anis=c(105,.0001), add.to = vmf.MT)) 
(vmf.MT <- fit.variogram(v.MTa, vmf.MT, fit.sills=FALSE))
(vmf.MT <- vgm(500000, "Gau", 30000*10000, anis=c(15,.0001), add.to = vmf.MT)) 
(vmf.MT <- vgm(300000, "Gau", 40000*10000, anis=c(105,.0001), add.to = vmf.MT)) 

#NWPANY
(vmf.NWPANY <- fit.variogram(v.NWPANY, vm.NWPANY, fit.method=6)) #OLS Seems better. 

#SWPA
(vmf.SWPA <- fit.variogram(v.SWPAa, vm.SWPA))

#WPA
(vmf.WPA <- fit.variogram(v.WPA, vm.WPA, fit.sills=FALSE)) 
(vmf.WPA <- vgm(30000, "Gau", 40000, add.to = vmf.WPA))
(vmf.WPA <- fit.variogram(v.WPA, vmf.WPA))


#PLOT THE FITTED VARIOGRAMS

#HeatFlow
print(plot(v.CTa, model=vmf.CT, main=list(label="Chataqua, NY", cex=2), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label=expression(Semivariance ~ (C/km)^2), cex=2), ylim=c(0,200), col.line="black", lwd=2, pch=16, cex=1.2, scales=list(x=list(at=c(0,5000,10000,15000,20000,25000,30000,35000,40000,45000,50000), labels=c(0,5,10,15,20,25,30,35,40,45,50), cex=2), y=list(at=c(0,50,100,150,200), labels=c(0,50,100,150,200), cex=2))))
print(plot(v.CNY, model=vmf.CNY, main=list("Central NY", cex=2), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label=expression(Semivariance ~ (C/km)^2), cex=2), ylim=c(0,200), col.line="black", lwd=2, pch=16, cex=1.2, scales=list(x=list(at=c(0,5000,10000,15000,20000,25000,30000,35000,40000,45000,50000), labels=c(0,5,10,15,20,25,30,35,40,45,50), cex=2), y=list(at=c(0,50,100,150,200), labels=c(0,50,100,150,200), cex=2))))
print(plot(v.CWVa, model=vmf.CWV, multipanel=TRUE, main=list("Central WV", cex=2), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label=expression(Semivariance ~ (C/km)^2), cex=2), ylim=c(0,200), col.line="black", lwd=2, pch=16, cex=1.2, scales=list(x=list(at=c(0,10000,20000,30000,40000,50000), labels=c(0,10,20,30,40,50), cex=2), y=list(at=c(0,50,100,150,200), labels=c(0,50,100,150,200), cex=2))))
print(plot(v.ENYa, model=vmf.ENY, main=list("Eastern NY", cex=2), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label=expression(Semivariance ~ (C/km)^2), cex=2), ylim=c(0,200), col.line="black", lwd=2, pch=16, cex=1.2, scales=list(x=list(at=c(0,5000,10000,15000,20000,25000,30000,35000,40000,45000,50000), labels=c(0,5,10,15,20,25,30,35,40,45,50), cex=2), y=list(at=c(0,50,100,150,200), labels=c(0,50,100,150,200), cex=2))))
print(plot(v.ENYPAa, model=vmf.ENYPA, main=list("Eastern NY & PA", cex=2), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label=expression(Semivariance ~ (C/km)^2), cex=2), ylim=c(0,200), col.line="black", lwd=2, pch=16, cex=1.2, scales=list(x=list(at=c(0,5000,10000,15000,20000,25000,30000,35000,40000,45000,50000), labels=c(0,5,10,15,20,25,30,35,40,45,50), cex=2), y=list(at=c(0,50,100,150,200), labels=c(0,50,100,150,200), cex=2))))
print(plot(v.MTa, model=vmf.MT, main=list("Western WV", cex=2), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label=expression(Semivariance ~ (C/km)^2), cex=2), ylim=c(0,200), col.line="black", lwd=2, pch=16, cex=1.2, scales=list(x=list(at=c(0,5000,10000,15000,20000,25000,30000,35000,40000,45000,50000), labels=c(0,5,10,15,20,25,30,35,40,45,50), cex=2), y=list(at=c(0,50,100,150,200), labels=c(0,50,100,150,200), cex=2))))
print(plot(v.NWPANY, model=vmf.NWPANY, main=list("Whole Region", cex=2), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label=expression(Semivariance ~ (C/km)^2), cex=2), ylim=c(0,200), col.line="black", lwd=2, pch=16, cex=1.2, scales=list(x=list(at=c(0,5000,10000,15000,20000,25000,30000,35000,40000,45000,50000), labels=c(0,5,10,15,20,25,30,35,40,45,50), cex=2), y=list(at=c(0,50,100,150,200), labels=c(0,50,100,150,200), cex=2))))
print(plot(v.SWPAa, model=vmf.SWPA, main=list("Southwest PA", cex=2), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label=expression(Semivariance ~ (C/km)^2), cex=2), ylim=c(0,200), col.line="black", lwd=2, pch=16, cex=1.2, scales=list(x=list(at=c(0,5000,10000,15000,20000,25000,30000,35000,40000,45000,50000), labels=c(0,5,10,15,20,25,30,35,40,45,50), cex=2), y=list(at=c(0,50,100,150,200), labels=c(0,50,100,150,200), cex=2))))
print(plot(v.VRa, model=vmf.VR, main=list("Valley and Ridge", cex=2), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label=expression(Semivariance ~ (C/km)^2), cex=2), ylim=c(0,200), col.line="black", lwd=2, pch=16, cex=1.2, scales=list(x=list(at=c(0,5000,10000,15000,20000,25000,30000,35000,40000,45000,50000), labels=c(0,5,10,15,20,25,30,35,40,45,50), cex=2), y=list(at=c(0,50,100,150,200), labels=c(0,50,100,150,200), cex=2))))
print(plot(v.WPA, model=vmf.WPA, main=list("Western PA", cex=2), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label=expression(Semivariance ~ (C/km)^2), cex=2), ylim=c(0,200), col.line="black", lwd=2, pch=16, cex=1.2, scales=list(x=list(at=c(0,5000,10000,15000,20000,25000,30000,35000,40000,45000,50000), labels=c(0,5,10,15,20,25,30,35,40,45,50), cex=2), y=list(at=c(0,50,100,150,200), labels=c(0,50,100,150,200), cex=2))))

#Gradient
print(plot(v.CTa, model=vmf.CT, main=list(label="Chataqua, NY", cex=2), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label=expression(Semivariance ~ (C/km)^2), cex=2), ylim=c(0,60), col.line="black", lwd=2, pch=16, cex=1.2, scales=list(x=list(at=c(0,5000,10000,15000,20000,25000,30000,35000,40000,45000,50000), labels=c(0,5,10,15,20,25,30,35,40,45,50), cex=2), y=list(at=c(0,10,20,30,40,50), labels=c(0,10,20,30,40,50), cex=2))))
print(plot(v.CNY, model=vmf.CNY, main=list("Central NY", cex=2), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label=expression(Semivariance ~ (C/km)^2), cex=2), ylim=c(0,60), col.line="black", lwd=2, pch=16, cex=1.2, scales=list(x=list(at=c(0,5000,10000,15000,20000,25000,30000,35000,40000,45000,50000), labels=c(0,5,10,15,20,25,30,35,40,45,50), cex=2), y=list(at=c(0,10,20,30,40,50), labels=c(0,10,20,30,40,50), cex=2))))
print(plot(v.CWVa, model=vmf.CWV, multipanel=TRUE, main=list("Central WV", cex=2), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label=expression(Semivariance ~ (C/km)^2), cex=2), ylim=c(0,60), col.line="black", lwd=2, pch=16, cex=1.2, scales=list(x=list(at=c(0,10000,20000,30000,40000,50000), labels=c(0,10,20,30,40,50), cex=2), y=list(at=c(0,10,20,30,40,50), labels=c(0,10,20,30,40,50), cex=2))))
print(plot(v.ENYa, model=vmf.ENY, main=list("Eastern NY", cex=2), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label=expression(Semivariance ~ (C/km)^2), cex=2), ylim=c(0,60), col.line="black", lwd=2, pch=16, cex=1.2, scales=list(x=list(at=c(0,5000,10000,15000,20000,25000,30000,35000,40000,45000,50000), labels=c(0,5,10,15,20,25,30,35,40,45,50), cex=2), y=list(at=c(0,10,20,30,40,50), labels=c(0,10,20,30,40,50), cex=2))))
print(plot(v.ENYPAa, model=vmf.ENYPA, main=list("Eastern NY & PA", cex=2), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label=expression(Semivariance ~ (C/km)^2), cex=2), ylim=c(0,60), col.line="black", lwd=2, pch=16, cex=1.2, scales=list(x=list(at=c(0,5000,10000,15000,20000,25000,30000,35000,40000,45000,50000), labels=c(0,5,10,15,20,25,30,35,40,45,50), cex=2), y=list(at=c(0,10,20,30,40,50), labels=c(0,10,20,30,40,50), cex=2))))
print(plot(v.MTa, model=vmf.MT, main=list("Western WV", cex=2), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label=expression(Semivariance ~ (C/km)^2), cex=2), ylim=c(0,60), col.line="black", lwd=2, pch=16, cex=1.2, scales=list(x=list(at=c(0,5000,10000,15000,20000,25000,30000,35000,40000,45000,50000), labels=c(0,5,10,15,20,25,30,35,40,45,50), cex=2), y=list(at=c(0,10,20,30,40,50), labels=c(0,10,20,30,40,50), cex=2))))
print(plot(v.NWPANY, model=vmf.NWPANY, main=list("Whole Region", cex=2), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label=expression(Semivariance ~ (C/km)^2), cex=2), ylim=c(0,60), col.line="black", lwd=2, pch=16, cex=1.2, scales=list(x=list(at=c(0,5000,10000,15000,20000,25000,30000,35000,40000,45000,50000), labels=c(0,5,10,15,20,25,30,35,40,45,50), cex=2), y=list(at=c(0,10,20,30,40,50), labels=c(0,10,20,30,40,50), cex=2))))
print(plot(v.SWPAa, model=vmf.SWPA, main=list("Southwest PA", cex=2), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label=expression(Semivariance ~ (C/km)^2), cex=2), ylim=c(0,60), col.line="black", lwd=2, pch=16, cex=1.2, scales=list(x=list(at=c(0,5000,10000,15000,20000,25000,30000,35000,40000,45000,50000), labels=c(0,5,10,15,20,25,30,35,40,45,50), cex=2), y=list(at=c(0,10,20,30,40,50), labels=c(0,10,20,30,40,50), cex=2))))
print(plot(v.VR, model=vmf.VR, main=list("Valley and Ridge", cex=2), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label=expression(Semivariance ~ (C/km)^2), cex=2), ylim=c(0,60), col.line="black", lwd=2, pch=16, cex=1.2, scales=list(x=list(at=c(0,5000,10000,15000,20000,25000,30000,35000,40000,45000,50000), labels=c(0,5,10,15,20,25,30,35,40,45,50), cex=2), y=list(at=c(0,10,20,30,40,50), labels=c(0,10,20,30,40,50), cex=2))))
print(plot(v.WPA, model=vmf.WPA, main=list("Western PA", cex=2), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label=expression(Semivariance ~ (C/km)^2), cex=2), ylim=c(0,60), col.line="black", lwd=2, pch=16, cex=1.2, scales=list(x=list(at=c(0,5000,10000,15000,20000,25000,30000,35000,40000,45000,50000), labels=c(0,5,10,15,20,25,30,35,40,45,50), cex=2), y=list(at=c(0,10,20,30,40,50), labels=c(0,10,20,30,40,50), cex=2))))

print(plot(v.CTa_tol, model=vmf.CT_tol, main=list(label="Chataqua, NY", cex=2), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label=expression(Semivariance ~ (C/km)^2), cex=2), ylim=c(0,60), col.line="black", lwd=2, pch=16, cex=1.2, scales=list(x=list(at=c(0,5000,10000,15000,20000,25000,30000,35000,40000,45000,50000), labels=c(0,5,10,15,20,25,30,35,40,45,50), cex=2), y=list(at=c(0,10,20,30,40,50), labels=c(0,10,20,30,40,50), cex=2))))
print(plot(v.CWVa_tol, model=vmf.CWV_tol, multipanel=TRUE, main=list("Central WV", cex=2), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label=expression(Semivariance ~ (C/km)^2), cex=2), ylim=c(0,60), col.line="black", lwd=2, pch=16, cex=1.2, scales=list(x=list(at=c(0,10000,20000,30000,40000,50000), labels=c(0,10,20,30,40,50), cex=2), y=list(at=c(0,10,20,30,40,50), labels=c(0,10,20,30,40,50), cex=2))))
print(plot(v.ENYa_tol, model=vmf.ENY_tol, main=list("Eastern NY", cex=2), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label=expression(Semivariance ~ (C/km)^2), cex=2), ylim=c(0,60), col.line="black", lwd=2, pch=16, cex=1.2, scales=list(x=list(at=c(0,5000,10000,15000,20000,25000,30000,35000,40000,45000,50000), labels=c(0,5,10,15,20,25,30,35,40,45,50), cex=2), y=list(at=c(0,10,20,30,40,50), labels=c(0,10,20,30,40,50), cex=2))))
print(plot(v.ENYPAa_tol, model=vmf.ENYPA_tol, main=list("Eastern NY & PA", cex=2), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label=expression(Semivariance ~ (C/km)^2), cex=2), ylim=c(0,60), col.line="black", lwd=2, pch=16, cex=1.2, scales=list(x=list(at=c(0,5000,10000,15000,20000,25000,30000,35000,40000,45000,50000), labels=c(0,5,10,15,20,25,30,35,40,45,50), cex=2), y=list(at=c(0,10,20,30,40,50), labels=c(0,10,20,30,40,50), cex=2))))
print(plot(v.MTa_tol, model=vmf.MT_tol, main=list("Western WV", cex=2), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label=expression(Semivariance ~ (C/km)^2), cex=2), ylim=c(0,60), col.line="black", lwd=2, pch=16, cex=1.2, scales=list(x=list(at=c(0,5000,10000,15000,20000,25000,30000,35000,40000,45000,50000), labels=c(0,5,10,15,20,25,30,35,40,45,50), cex=2), y=list(at=c(0,10,20,30,40,50), labels=c(0,10,20,30,40,50), cex=2))))
print(plot(v.SWPAa_tol, model=vmf.SWPA_tol, main=list("Southwest PA", cex=2), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label=expression(Semivariance ~ (C/km)^2), cex=2), ylim=c(0,60), col.line="black", lwd=2, pch=16, cex=1.2, scales=list(x=list(at=c(0,5000,10000,15000,20000,25000,30000,35000,40000,45000,50000), labels=c(0,5,10,15,20,25,30,35,40,45,50), cex=2), y=list(at=c(0,10,20,30,40,50), labels=c(0,10,20,30,40,50), cex=2))))


#Temp1.5km
print(plot(v.CTa, model=vmf.CT, main=list(label="Chataqua, NY", cex=2), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label=expression(Semivariance ~ (C/km)^2), cex=2), ylim=c(0,10), col.line="black", lwd=2, pch=16, cex=1.2, scales=list(x=list(at=c(0,5000,10000,15000,20000,25000,30000,35000,40000,45000,50000), labels=c(0,5,10,15,20,25,30,35,40,45,50), cex=2), y=list(at=c(0,50,100,150,200), labels=c(0,50,100,150,200), cex=2))))
print(plot(v.CNY, model=vmf.CNY, main=list("Central NY", cex=2), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label=expression(Semivariance ~ (C/km)^2), cex=2), ylim=c(0,10), col.line="black", lwd=2, pch=16, cex=1.2, scales=list(x=list(at=c(0,5000,10000,15000,20000,25000,30000,35000,40000,45000,50000), labels=c(0,5,10,15,20,25,30,35,40,45,50), cex=2), y=list(at=c(0,50,100,150,200), labels=c(0,50,100,150,200), cex=2))))
print(plot(v.CWVa, model=vmf.CWV, multipanel=TRUE, main=list("Central WV", cex=2), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label=expression(Semivariance ~ (C/km)^2), cex=2), ylim=c(0,70), col.line="black", lwd=2, pch=16, cex=1.2, scales=list(x=list(at=c(0,10000,20000,30000,40000,50000), labels=c(0,10,20,30,40,50), cex=2), y=list(at=c(0,50,100,150,200), labels=c(0,50,100,150,200), cex=2))))
print(plot(v.ENY, model=vmf.ENY, main=list("Eastern NY", cex=2), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label=expression(Semivariance ~ (C/km)^2), cex=2), ylim=c(0,100), col.line="black", lwd=2, pch=16, cex=1.2, scales=list(x=list(at=c(0,5000,10000,15000,20000,25000,30000,35000,40000,45000,50000), labels=c(0,5,10,15,20,25,30,35,40,45,50), cex=2), y=list(at=c(0,50,100,150,200), labels=c(0,50,100,150,200), cex=2))))
print(plot(v.ENYPAa, model=vmf.ENYPA, main=list("Eastern NY & PA", cex=2), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label=expression(Semivariance ~ (C/km)^2), cex=2), ylim=c(0,200), col.line="black", lwd=2, pch=16, cex=1.2, scales=list(x=list(at=c(0,5000,10000,15000,20000,25000,30000,35000,40000,45000,50000), labels=c(0,5,10,15,20,25,30,35,40,45,50), cex=2), y=list(at=c(0,50,100,150,200), labels=c(0,50,100,150,200), cex=2))))
print(plot(v.MT, model=vmf.MT, main=list("Western WV", cex=2), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label=expression(Semivariance ~ (C/km)^2), cex=2), ylim=c(0,200), col.line="black", lwd=2, pch=16, cex=1.2, scales=list(x=list(at=c(0,5000,10000,15000,20000,25000,30000,35000,40000,45000,50000), labels=c(0,5,10,15,20,25,30,35,40,45,50), cex=2), y=list(at=c(0,50,100,150,200), labels=c(0,50,100,150,200), cex=2))))
print(plot(v.NWPANY, model=vmf.NWPANY, main=list("Whole Region", cex=2), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label=expression(Semivariance ~ (C/km)^2), cex=2), ylim=c(0,100), col.line="black", lwd=2, pch=16, cex=1.2, scales=list(x=list(at=c(0,5000,10000,15000,20000,25000,30000,35000,40000,45000,50000), labels=c(0,5,10,15,20,25,30,35,40,45,50), cex=2), y=list(at=c(0,50,100,150,200), labels=c(0,50,100,150,200), cex=2))))
print(plot(v.SWPAa, model=vmf.SWPA, main=list("Southwest PA", cex=2), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label=expression(Semivariance ~ (C/km)^2), cex=2), ylim=c(0,50), col.line="black", lwd=2, pch=16, cex=1.2, scales=list(x=list(at=c(0,5000,10000,15000,20000,25000,30000,35000,40000,45000,50000), labels=c(0,5,10,15,20,25,30,35,40,45,50), cex=2), y=list(at=c(0,50,100,150,200), labels=c(0,50,100,150,200), cex=2))))
print(plot(v.WPAa, model=vmf.WPA, main=list("Western PA", cex=2), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label=expression(Semivariance ~ (C/km)^2), cex=2), ylim=c(0,25), col.line="black", lwd=2, pch=16, cex=1.2, scales=list(x=list(at=c(0,5000,10000,15000,20000,25000,30000,35000,40000,45000,50000), labels=c(0,5,10,15,20,25,30,35,40,45,50), cex=2), y=list(at=c(0,50,100,150,200), labels=c(0,50,100,150,200), cex=2))))


#Temp2.5km
print(plot(v.CTa, model=vmf.CT, main=list(label="Chataqua, NY", cex=2), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label=expression(Semivariance ~ (C/km)^2), cex=2), ylim=c(0,50), col.line="black", lwd=2, pch=16, cex=1.2, scales=list(x=list(at=c(0,5000,10000,15000,20000,25000,30000,35000,40000,45000,50000), labels=c(0,5,10,15,20,25,30,35,40,45,50), cex=2), y=list(at=c(0,50,100,150,200), labels=c(0,50,100,150,200), cex=2))))
print(plot(v.CNY, model=vmf.CNY, main=list("Central NY", cex=2), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label=expression(Semivariance ~ (C/km)^2), cex=2), ylim=c(0,50), col.line="black", lwd=2, pch=16, cex=1.2, scales=list(x=list(at=c(0,5000,10000,15000,20000,25000,30000,35000,40000,45000,50000), labels=c(0,5,10,15,20,25,30,35,40,45,50), cex=2), y=list(at=c(0,50,100,150,200), labels=c(0,50,100,150,200), cex=2))))
print(plot(v.CWVa, model=vmf.CWV, multipanel=TRUE, main=list("Central WV", cex=2), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label=expression(Semivariance ~ (C/km)^2), cex=2), ylim=c(0,500), col.line="black", lwd=2, pch=16, cex=1.2, scales=list(x=list(at=c(0,10000,20000,30000,40000,50000), labels=c(0,10,20,30,40,50), cex=2), y=list(at=c(0,50,100,150,200), labels=c(0,50,100,150,200), cex=2))))
print(plot(v.ENYa, model=vmf.ENY, main=list("Eastern NY", cex=2), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label=expression(Semivariance ~ (C/km)^2), cex=2), ylim=c(0,500), col.line="black", lwd=2, pch=16, cex=1.2, scales=list(x=list(at=c(0,5000,10000,15000,20000,25000,30000,35000,40000,45000,50000), labels=c(0,5,10,15,20,25,30,35,40,45,50), cex=2), y=list(at=c(0,50,100,150,200), labels=c(0,50,100,150,200), cex=2))))
print(plot(v.ENYPAa, model=vmf.ENYPA, main=list("Eastern NY & PA", cex=2), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label=expression(Semivariance ~ (C/km)^2), cex=2), ylim=c(0,1200), col.line="black", lwd=2, pch=16, cex=1.2, scales=list(x=list(at=c(0,5000,10000,15000,20000,25000,30000,35000,40000,45000,50000), labels=c(0,5,10,15,20,25,30,35,40,45,50), cex=2), y=list(at=c(0,50,100,150,200), labels=c(0,50,100,150,200), cex=2))))
print(plot(v.MTa, model=vmf.MT, main=list("Western WV", cex=2), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label=expression(Semivariance ~ (C/km)^2), cex=2), ylim=c(0,200), col.line="black", lwd=2, pch=16, cex=1.2, scales=list(x=list(at=c(0,5000,10000,15000,20000,25000,30000,35000,40000,45000,50000), labels=c(0,5,10,15,20,25,30,35,40,45,50), cex=2), y=list(at=c(0,50,100,150,200), labels=c(0,50,100,150,200), cex=2))))
print(plot(v.NWPANY, model=vmf.NWPANY, main=list("Whole Region", cex=2), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label=expression(Semivariance ~ (C/km)^2), cex=2), ylim=c(0,500), col.line="black", lwd=2, pch=16, cex=1.2, scales=list(x=list(at=c(0,5000,10000,15000,20000,25000,30000,35000,40000,45000,50000), labels=c(0,5,10,15,20,25,30,35,40,45,50), cex=2), y=list(at=c(0,50,100,150,200), labels=c(0,50,100,150,200), cex=2))))
print(plot(v.SWPAa, model=vmf.SWPA, main=list("Southwest PA", cex=2), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label=expression(Semivariance ~ (C/km)^2), cex=2), ylim=c(0,100), col.line="black", lwd=2, pch=16, cex=1.2, scales=list(x=list(at=c(0,5000,10000,15000,20000,25000,30000,35000,40000,45000,50000), labels=c(0,5,10,15,20,25,30,35,40,45,50), cex=2), y=list(at=c(0,50,100,150,200), labels=c(0,50,100,150,200), cex=2))))
print(plot(v.VRa, model=vmf.VR, main=list("Valley and Ridge", cex=2), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label=expression(Semivariance ~ (C/km)^2), cex=2), ylim=c(0,500), col.line="black", lwd=2, pch=16, cex=1.2, scales=list(x=list(at=c(0,5000,10000,15000,20000,25000,30000,35000,40000,45000,50000), labels=c(0,5,10,15,20,25,30,35,40,45,50), cex=2), y=list(at=c(0,50,100,150,200), labels=c(0,50,100,150,200), cex=2))))
print(plot(v.WPA, model=vmf.WPA, main=list("Western PA", cex=2), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label=expression(Semivariance ~ (C/km)^2), cex=2), ylim=c(0,500), col.line="black", lwd=2, pch=16, cex=1.2, scales=list(x=list(at=c(0,5000,10000,15000,20000,25000,30000,35000,40000,45000,50000), labels=c(0,5,10,15,20,25,30,35,40,45,50), cex=2), y=list(at=c(0,50,100,150,200), labels=c(0,50,100,150,200), cex=2))))


#Temp3.5km
print(plot(v.CTa, model=vmf.CT, main=list(label="Chataqua, NY", cex=2), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label=expression(Semivariance ~ (C/km)^2), cex=2), ylim=c(0,500), col.line="black", lwd=2, pch=16, cex=1.2, scales=list(x=list(at=c(0,5000,10000,15000,20000,25000,30000,35000,40000,45000,50000), labels=c(0,5,10,15,20,25,30,35,40,45,50), cex=2), y=list(at=c(0,50,100,150,200), labels=c(0,50,100,150,200), cex=2))))
print(plot(v.CNY, model=vmf.CNY, main=list("Central NY", cex=2), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label=expression(Semivariance ~ (C/km)^2), cex=2), ylim=c(0,500), col.line="black", lwd=2, pch=16, cex=1.2, scales=list(x=list(at=c(0,5000,10000,15000,20000,25000,30000,35000,40000,45000,50000), labels=c(0,5,10,15,20,25,30,35,40,45,50), cex=2), y=list(at=c(0,50,100,150,200), labels=c(0,50,100,150,200), cex=2))))
print(plot(v.CWVa, model=vmf.CWV, multipanel=TRUE, main=list("Central WV", cex=2), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label=expression(Semivariance ~ (C/km)^2), cex=2), ylim=c(0,500), col.line="black", lwd=2, pch=16, cex=1.2, scales=list(x=list(at=c(0,10000,20000,30000,40000,50000), labels=c(0,10,20,30,40,50), cex=2), y=list(at=c(0,50,100,150,200), labels=c(0,50,100,150,200), cex=2))))
print(plot(v.ENY, model=vmf.ENY, main=list("Eastern NY", cex=2), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label=expression(Semivariance ~ (C/km)^2), cex=2), ylim=c(0,500), col.line="black", lwd=2, pch=16, cex=1.2, scales=list(x=list(at=c(0,5000,10000,15000,20000,25000,30000,35000,40000,45000,50000), labels=c(0,5,10,15,20,25,30,35,40,45,50), cex=2), y=list(at=c(0,50,100,150,200), labels=c(0,50,100,150,200), cex=2))))
print(plot(v.ENYPAa, model=vmf.ENYPA, main=list("Eastern NY & PA", cex=2), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label=expression(Semivariance ~ (C/km)^2), cex=2), ylim=c(0,1200), col.line="black", lwd=2, pch=16, cex=1.2, scales=list(x=list(at=c(0,5000,10000,15000,20000,25000,30000,35000,40000,45000,50000), labels=c(0,5,10,15,20,25,30,35,40,45,50), cex=2), y=list(at=c(0,50,100,150,200), labels=c(0,50,100,150,200), cex=2))))
print(plot(v.MTa, model=vmf.MT, main=list("Western WV", cex=2), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label=expression(Semivariance ~ (C/km)^2), cex=2), ylim=c(0,500), col.line="black", lwd=2, pch=16, cex=1.2, scales=list(x=list(at=c(0,5000,10000,15000,20000,25000,30000,35000,40000,45000,50000), labels=c(0,5,10,15,20,25,30,35,40,45,50), cex=2), y=list(at=c(0,50,100,150,200), labels=c(0,50,100,150,200), cex=2))))
print(plot(v.NWPANYa, model=vmf.NWPANY, main=list("Whole Region", cex=2), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label=expression(Semivariance ~ (C/km)^2), cex=2), ylim=c(0,500), col.line="black", lwd=2, pch=16, cex=1.2, scales=list(x=list(at=c(0,5000,10000,15000,20000,25000,30000,35000,40000,45000,50000), labels=c(0,5,10,15,20,25,30,35,40,45,50), cex=2), y=list(at=c(0,50,100,150,200), labels=c(0,50,100,150,200), cex=2))))
print(plot(v.SWPAa, model=vmf.SWPA, main=list("Southwest PA", cex=2), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label=expression(Semivariance ~ (C/km)^2), cex=2), ylim=c(0,500), col.line="black", lwd=2, pch=16, cex=1.2, scales=list(x=list(at=c(0,5000,10000,15000,20000,25000,30000,35000,40000,45000,50000), labels=c(0,5,10,15,20,25,30,35,40,45,50), cex=2), y=list(at=c(0,50,100,150,200), labels=c(0,50,100,150,200), cex=2))))
print(plot(v.VRa, model=vmf.VR, main=list("Valley and Ridge", cex=2), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label=expression(Semivariance ~ (C/km)^2), cex=2), ylim=c(0,500), col.line="black", lwd=2, pch=16, cex=1.2, scales=list(x=list(at=c(0,5000,10000,15000,20000,25000,30000,35000,40000,45000,50000), labels=c(0,5,10,15,20,25,30,35,40,45,50), cex=2), y=list(at=c(0,50,100,150,200), labels=c(0,50,100,150,200), cex=2))))
print(plot(v.WPA, model=vmf.WPA, main=list("Western PA", cex=2), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label=expression(Semivariance ~ (C/km)^2), cex=2), ylim=c(0,500), col.line="black", lwd=2, pch=16, cex=1.2, scales=list(x=list(at=c(0,5000,10000,15000,20000,25000,30000,35000,40000,45000,50000), labels=c(0,5,10,15,20,25,30,35,40,45,50), cex=2), y=list(at=c(0,50,100,150,200), labels=c(0,50,100,150,200), cex=2))))


#Depth80C
print(plot(v.CTa, model=vmf.CT, main=list(label="Chataqua, NY", cex=2), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label=expression(Semivariance ~ (m)^2), cex=2), ylim=c(0,1000000), col.line="black", lwd=2, pch=16, cex=1.2, scales=list(x=list(at=seq(0,50000,10000), labels=seq(0,50,10), cex=2), y=list(at=seq(0,1000000, 250000), labels=seq(0,1000000, 250000), cex=2))))
print(plot(v.CNY, model=vmf.CNY, main=list("Central NY", cex=2), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label=expression(Semivariance ~ (C/km)^2), cex=2), ylim=c(0,1000000), col.line="black", lwd=2, pch=16, cex=1.2, scales=list(x=list(at=seq(0,50000,10000), labels=seq(0,50,10), cex=2), y=list(at=seq(0,1000000, 250000), labels=seq(0,1000000, 250000), cex=2))))
print(plot(v.CWVa, model=vmf.CWV, multipanel=TRUE, main=list("Central WV", cex=2), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label=expression(Semivariance ~ (C/km)^2), cex=2), ylim=c(0,1000000), col.line="black", lwd=2, pch=16, cex=1.2, scales=list(x=list(at=seq(0,50000,10000), labels=seq(0,50,10), cex=2), y=list(at=seq(0,1000000, 250000), labels=seq(0,1000000, 250000), cex=2))))
print(plot(v.ENYa, model=vmf.ENY, main=list("Eastern NY", cex=2), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label=expression(Semivariance ~ (C/km)^2), cex=2), ylim=c(0,1000000), col.line="black", lwd=2, pch=16, cex=1.2, scales=list(x=list(at=seq(0,50000,10000), labels=seq(0,50,10), cex=2), y=list(at=seq(0,1000000, 250000), labels=seq(0,1000000, 250000), cex=2))))
print(plot(v.ENYPAa, model=vmf.ENYPA, main=list("Eastern NY & PA", cex=2), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label=expression(Semivariance ~ (C/km)^2), cex=2), ylim=c(0,5000000), col.line="black", lwd=2, pch=16, cex=1.2, scales=list(x=list(at=seq(0,50000,10000), labels=seq(0,50,10), cex=2), y=list(at=seq(0,5000000, 1000000), labels=seq(0,5000000, 1000000), cex=2))))
print(plot(v.MTa, model=vmf.MT, main=list("Western WV", cex=2), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label=expression(Semivariance ~ (C/km)^2), cex=2), ylim=c(0,1000000), col.line="black", lwd=2, pch=16, cex=1.2, scales=list(x=list(at=seq(0,50000,10000), labels=seq(0,50,10), cex=2), y=list(at=seq(0,1000000, 250000), labels=seq(0,1000000, 250000), cex=2))))
print(plot(v.NWPANY, model=vmf.NWPANY, main=list("Northwest PA & NY", cex=2), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label=expression(Semivariance ~ (C/km)^2), cex=2), ylim=c(0,1000000), col.line="black", lwd=2, pch=16, cex=1.2, scales=list(x=list(at=seq(0,50000,10000), labels=seq(0,50,10), cex=2), y=list(at=seq(0,1000000, 250000), labels=seq(0,1000000, 250000), cex=2))))
print(plot(v.SWPAa, model=vmf.SWPA, main=list("Southwest PA", cex=2), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label=expression(Semivariance ~ (C/km)^2), cex=2), ylim=c(0,1000000), col.line="black", lwd=2, pch=16, cex=1.2, scales=list(x=list(at=seq(0,50000,10000), labels=seq(0,50,10), cex=2), y=list(at=seq(0,1000000, 250000), labels=seq(0,1000000, 250000), cex=2))))
print(plot(v.VRa, model=vmf.VR, main=list("Valley and Ridge", cex=2), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label=expression(Semivariance ~ (C/km)^2), cex=2), ylim=c(0,1000000), col.line="black", lwd=2, pch=16, cex=1.2, scales=list(x=list(at=seq(0,50000,10000), labels=seq(0,50,10), cex=2), y=list(at=seq(0,1000000, 250000), labels=seq(0,1000000, 250000), cex=2))))
print(plot(v.WPA, model=vmf.WPA, main=list("Western PA", cex=2), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label=expression(Semivariance ~ (C/km)^2), cex=2), ylim=c(0,1000000), col.line="black", lwd=2, pch=16, cex=1.2, scales=list(x=list(at=seq(0,50000,10000), labels=seq(0,50,10), cex=2), y=list(at=seq(0,1000000, 250000), labels=seq(0,1000000, 250000), cex=2))))

#Figure of fitted variograms for Depth to 80 C
p1=plot(v.CTa, model=vmf.CT, main=list(label="Chataqua, NY", cex=2), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label=expression(Semivariance ~ (m)^2), cex=2), ylim=c(0,1000000), col.line="black", lwd=2, pch=16, cex=1.2, scales=list(x=list(at=seq(0,50000,10000), labels=seq(0,50,10), cex=2), y=list(at=seq(0,1000000, 250000), labels=seq(0,1000000, 250000), cex=2)))
p2=plot(v.CNY, model=vmf.CNY, main=list("Central NY", cex=2), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label=expression(Semivariance ~ (m)^2), cex=2), ylim=c(0,1000000), col.line="black", lwd=2, pch=16, cex=1.2, scales=list(x=list(at=seq(0,50000,10000), labels=seq(0,50,10), cex=2), y=list(at=seq(0,1000000, 250000), labels=seq(0,1000000, 250000), cex=2)))
p9=plot(v.CWVa, model=vmf.CWV, multipanel=TRUE, main=list("Central WV", cex=2), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label=expression(Semivariance ~ (m)^2), cex=2), ylim=c(0,1000000), col.line="black", lwd=2, pch=16, cex=1.2, scales=list(x=list(at=seq(0,50000,10000), labels=seq(0,50,10), cex=2), y=list(at=seq(0,1000000, 250000), labels=seq(0,1000000, 250000), cex=2)))
p3=plot(v.ENYa, model=vmf.ENY, main=list("Eastern NY", cex=2), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label=expression(Semivariance ~ (m)^2), cex=2), ylim=c(0,1000000), col.line="black", lwd=2, pch=16, cex=1.2, scales=list(x=list(at=seq(0,50000,10000), labels=seq(0,50,10), cex=2), y=list(at=seq(0,1000000, 250000), labels=seq(0,1000000, 250000), cex=2)))
p4=plot(v.ENYPAa, model=vmf.ENYPA, main=list("Eastern NY & PA", cex=2), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label=expression(Semivariance ~ (m)^2), cex=2), ylim=c(0,5000000), col.line="black", lwd=2, pch=16, cex=1.2, scales=list(x=list(at=seq(0,50000,10000), labels=seq(0,50,10), cex=2), y=list(at=seq(0,5000000, 1000000), labels=seq(0,5000000, 1000000), cex=2)))
p8=plot(v.MTa, model=vmf.MT, main=list("Western WV", cex=2), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label=expression(Semivariance ~ (m)^2), cex=2), ylim=c(0,1000000), col.line="black", lwd=2, pch=16, cex=1.2, scales=list(x=list(at=seq(0,50000,10000), labels=seq(0,50,10), cex=2), y=list(at=seq(0,1000000, 250000), labels=seq(0,1000000, 250000), cex=2)))
p5=plot(v.NWPANY, model=vmf.NWPANY, main=list("Northwest PA & NY", cex=2), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label=expression(Semivariance ~ (m)^2), cex=2), ylim=c(0,1000000), col.line="black", lwd=2, pch=16, cex=1.2, scales=list(x=list(at=seq(0,50000,10000), labels=seq(0,50,10), cex=2), y=list(at=seq(0,1000000, 250000), labels=seq(0,1000000, 250000), cex=2)))
p6=plot(v.SWPAa, model=vmf.SWPA, main=list("Southwest PA", cex=2), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label=expression(Semivariance ~ (m)^2), cex=2), ylim=c(0,1000000), col.line="black", lwd=2, pch=16, cex=1.2, scales=list(x=list(at=seq(0,50000,10000), labels=seq(0,50,10), cex=2), y=list(at=seq(0,1000000, 250000), labels=seq(0,1000000, 250000), cex=2)))
p10=plot(v.VRa, model=vmf.VR, main=list("Valley and Ridge", cex=2), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label=expression(Semivariance ~ (m)^2), cex=2), ylim=c(0,1000000), col.line="black", lwd=2, pch=16, cex=1.2, scales=list(x=list(at=seq(0,50000,10000), labels=seq(0,50,10), cex=2), y=list(at=seq(0,1000000, 250000), labels=seq(0,1000000, 250000), cex=2)))
p7=plot(v.WPA, model=vmf.WPA, main=list("Western PA", cex=2), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label=expression(Semivariance ~ (m)^2), cex=2), ylim=c(0,1000000), col.line="black", lwd=2, pch=16, cex=1.2, scales=list(x=list(at=seq(0,50000,10000), labels=seq(0,50,10), cex=2), y=list(at=seq(0,1000000, 250000), labels=seq(0,1000000, 250000), cex=2)))

par(mfrow=c(3,3))
png("Variograms.png", width=20, height=20, units="in", res=150)
plot(p1, split = c(1,1,3,3), more=T) 
plot(p2, split = c(2,1,3,3), more=T) 
plot(p3, split = c(3,1,3,3), more=T) 
plot(p4, split = c(1,2,3,3), more=T) 
plot(p5, split = c(2,2,3,3), more=T) 
plot(p6, split = c(3,2,3,3), more=T) 
plot(p7, split = c(1,3,3,3), more=T)
plot(p8, split = c(2,3,3,3), more=T)
plot(p9, split = c(3,3,3,3), more=F)
dev.off()


#Depth100C
print(plot(v.CTa, model=vmf.CT, main=list(label="Chataqua, NY", cex=2), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label=expression(Semivariance ~ (C/km)^2), cex=2), ylim=c(0,500000), col.line="black", lwd=2, pch=16, cex=1.2, scales=list(x=list(at=c(0,5000,10000,15000,20000,25000,30000,35000,40000,45000,50000), labels=c(0,5,10,15,20,25,30,35,40,45,50), cex=2), y=list(at=c(0,50,100,150,200), labels=c(0,50,100,150,200), cex=2))))
print(plot(v.CNY, model=vmf.CNY, main=list("Central NY", cex=2), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label=expression(Semivariance ~ (C/km)^2), cex=2), ylim=c(0,1000000), col.line="black", lwd=2, pch=16, cex=1.2, scales=list(x=list(at=c(0,5000,10000,15000,20000,25000,30000,35000,40000,45000,50000), labels=c(0,5,10,15,20,25,30,35,40,45,50), cex=2), y=list(at=c(0,50,100,150,200), labels=c(0,50,100,150,200), cex=2))))
print(plot(v.CWVa, model=vmf.CWV, multipanel=TRUE, main=list("Central WV", cex=2), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label=expression(Semivariance ~ (C/km)^2), cex=2), ylim=c(0,2000000), col.line="black", lwd=2, pch=16, cex=1.2, scales=list(x=list(at=c(0,10000,20000,30000,40000,50000), labels=c(0,10,20,30,40,50), cex=2), y=list(at=c(0,50,100,150,200), labels=c(0,50,100,150,200), cex=2))))
print(plot(v.ENYa, model=vmf.ENY, main=list("Eastern NY", cex=2), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label=expression(Semivariance ~ (C/km)^2), cex=2), ylim=c(0,1000000), col.line="black", lwd=2, pch=16, cex=1.2, scales=list(x=list(at=c(0,5000,10000,15000,20000,25000,30000,35000,40000,45000,50000), labels=c(0,5,10,15,20,25,30,35,40,45,50), cex=2), y=list(at=c(0,50,100,150,200), labels=c(0,50,100,150,200), cex=2))))
print(plot(v.ENYPAa, model=vmf.ENYPA, main=list("Eastern NY & PA", cex=2), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label=expression(Semivariance ~ (C/km)^2), cex=2), ylim=c(0,5000000), col.line="black", lwd=2, pch=16, cex=1.2, scales=list(x=list(at=c(0,5000,10000,15000,20000,25000,30000,35000,40000,45000,50000), labels=c(0,5,10,15,20,25,30,35,40,45,50), cex=2), y=list(at=c(0,50,100,150,200), labels=c(0,50,100,150,200), cex=2))))
print(plot(v.MTa, model=vmf.MT, main=list("Western WV", cex=2), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label=expression(Semivariance ~ (C/km)^2), cex=2), ylim=c(0,3000000), col.line="black", lwd=2, pch=16, cex=1.2, scales=list(x=list(at=c(0,5000,10000,15000,20000,25000,30000,35000,40000,45000,50000), labels=c(0,5,10,15,20,25,30,35,40,45,50), cex=2), y=list(at=c(0,50,100,150,200), labels=c(0,50,100,150,200), cex=2))))
print(plot(v.NWPANY, model=vmf.NWPANY, main=list("Whole Region", cex=2), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label=expression(Semivariance ~ (C/km)^2), cex=2), ylim=c(0,1000000), col.line="black", lwd=2, pch=16, cex=1.2, scales=list(x=list(at=c(0,5000,10000,15000,20000,25000,30000,35000,40000,45000,50000), labels=c(0,5,10,15,20,25,30,35,40,45,50), cex=2), y=list(at=c(0,50,100,150,200), labels=c(0,50,100,150,200), cex=2))))
print(plot(v.SWPAa, model=vmf.SWPA, main=list("Southwest PA", cex=2), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label=expression(Semivariance ~ (C/km)^2), cex=2), ylim=c(0,3000000), col.line="black", lwd=2, pch=16, cex=1.2, scales=list(x=list(at=c(0,5000,10000,15000,20000,25000,30000,35000,40000,45000,50000), labels=c(0,5,10,15,20,25,30,35,40,45,50), cex=2), y=list(at=c(0,50,100,150,200), labels=c(0,50,100,150,200), cex=2))))
print(plot(v.VRa, model=vmf.VR, main=list("Valley and Ridge", cex=2), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label=expression(Semivariance ~ (C/km)^2), cex=2), ylim=c(0,1000000), col.line="black", lwd=2, pch=16, cex=1.2, scales=list(x=list(at=c(0,5000,10000,15000,20000,25000,30000,35000,40000,45000,50000), labels=c(0,5,10,15,20,25,30,35,40,45,50), cex=2), y=list(at=c(0,50,100,150,200), labels=c(0,50,100,150,200), cex=2))))
print(plot(v.WPA, model=vmf.WPA, main=list("Western PA", cex=2), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label=expression(Semivariance ~ (C/km)^2), cex=2), ylim=c(0,1000000), col.line="black", lwd=2, pch=16, cex=1.2, scales=list(x=list(at=c(0,5000,10000,15000,20000,25000,30000,35000,40000,45000,50000), labels=c(0,5,10,15,20,25,30,35,40,45,50), cex=2), y=list(at=c(0,50,100,150,200), labels=c(0,50,100,150,200), cex=2))))

p1=plot(v.CTa, model=vmf.CT, main=list(label="Chataqua, NY", cex=2), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label=expression(Semivariance ~ (m)^2), cex=2), xlim=c(0,50000),ylim=c(0,1000000), col.line="black", lwd=2, pch=16, cex=1.2, scales=list(x=list(at=seq(0,60000,10000), labels=seq(0,60,10), cex=2), y=list(at=seq(0,1000000,250000), labels=seq(0,1000000,250000), cex=2)), strip=FALSE)
p2=plot(v.CNY, model=vmf.CNY, main=list("Central NY", cex=2), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label=expression(Semivariance ~ (m)^2), cex=2), xlim=c(0,50000),ylim=c(0,1000000), col.line="black", lwd=2, pch=16, cex=1.2, scales=list(x=list(at=seq(0,60000,10000), labels=seq(0,60,10), cex=2), y=list(at=seq(0,1000000,250000), labels=seq(0,1000000,250000), cex=2)), strip=FALSE)
p9=plot(v.CWVa, model=vmf.CWV, multipanel=TRUE, main=list("Central WV", cex=2), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label=expression(Semivariance ~ (m)^2), cex=2), xlim=c(0,50000),ylim=c(0,1000000), col.line="black", lwd=2, pch=16, cex=1.2, scales=list(x=list(at=seq(0,60000,10000), labels=seq(0,60,10), cex=2), y=list(at=seq(0,1000000,250000), labels=seq(0,1000000,250000), cex=2)), strip=FALSE)
p3=plot(v.ENYa, model=vmf.ENY, main=list("Eastern NY", cex=2), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label=expression(Semivariance ~ (m)^2), cex=2), xlim=c(0,50000),ylim=c(0,1000000), col.line="black", lwd=2, pch=16, cex=1.2, scales=list(x=list(at=seq(0,60000,10000), labels=seq(0,60,10), cex=2), y=list(at=seq(0,1000000,250000), labels=seq(0,1000000,250000), cex=2)), strip=FALSE)
p4=plot(v.ENYPAa, model=vmf.ENYPA, main=list("Eastern NY & PA", cex=2), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label=expression(Semivariance ~ (m)^2), cex=2), xlim=c(0,50000),ylim=c(0,5000000), col.line="black", lwd=2, pch=16, cex=1.2, scales=list(x=list(at=seq(0,60000,10000), labels=seq(0,60,10), cex=2), y=list(at=seq(0,5000000,1000000), labels=seq(0,5000000,1000000), cex=2)), strip=FALSE)
p8=plot(v.MTa, model=vmf.MT, main=list("Western WV", cex=2), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label=expression(Semivariance ~ (m)^2), cex=2), xlim=c(0,50000),ylim=c(0,1000000), col.line="black", lwd=2, pch=16, cex=1.2, scales=list(x=list(at=seq(0,60000,10000), labels=seq(0,60,10), cex=2), y=list(at=seq(0,1000000,250000), labels=seq(0,1000000,250000), cex=2)), strip=FALSE)
p5=plot(v.NWPANY, model=vmf.NWPANY, main=list("Northwest PA & NY", cex=2), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label=expression(Semivariance ~ (m)^2), cex=2), xlim=c(0,50000),ylim=c(0,1000000), col.line="black", lwd=2, pch=16, cex=1.2, scales=list(x=list(at=seq(0,60000,10000), labels=seq(0,60,10), cex=2), y=list(at=seq(0,1000000,250000), labels=seq(0,1000000,250000), cex=2)), strip=FALSE)
p6=plot(v.SWPAa, model=vmf.SWPA, main=list("Southwest PA", cex=2), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label=expression(Semivariance ~ (m)^2), cex=2), xlim=c(0,50000),ylim=c(0,1000000), col.line="black", lwd=2, pch=16, cex=1.2, scales=list(x=list(at=seq(0,60000,10000), labels=seq(0,60,10), cex=2), y=list(at=seq(0,1000000,250000), labels=seq(0,1000000,250000), cex=2)), strip=FALSE)
p7=plot(v.WPA, model=vmf.WPA, main=list("Western PA", cex=2), xlab=list(label="Distance to points (km)", cex=2), ylab=list(label=expression(Semivariance ~ (m)^2), cex=2), xlim=c(0,50000),ylim=c(0,1000000), col.line="black", lwd=2, pch=16, cex=1.2, scales=list(x=list(at=seq(0,60000,10000), labels=seq(0,60,10), cex=2), y=list(at=seq(0,1000000,250000), labels=seq(0,1000000,250000), cex=2)), strip=FALSE)


##KRIGING INTERPOLATION##

##Heatflow Autocorrelation##
#nmax is 50, nmin is 5, 50 km interpolation distance.
k.CT.hf_mn5_mx50 <- krige(Qs~1, locations=CT, newdata=grd.CT, model=vmf.CT, maxdist=50000, nmin = 5, nmax = 50, debug.level=-1)
k.CNY.hf_mn5_mx50 <- krige(Qs~1, locations=CNY, newdata=grd.CNY, model=vmf.CNY, maxdist=50000, nmin = 5, nmax = 50, debug.level=-1)
k.CWV.hf_mn5_mx50 <- krige(Qs~1, locations=CWV, newdata=grd.CWV, model=vmf.CWV, maxdist=50000, nmin = 5, nmax = 50, debug.level=-1)
k.ENY.hf_mn5_mx50 <- krige(Qs~1, locations=ENY, newdata=grd.ENY, model=vmf.ENY, maxdist=50000, nmin = 5, nmax = 50, debug.level=-1)
k.ENYPA.hf_mn5_mx50 <- krige(Qs~1, locations=ENYPA, newdata=grd.ENYPA, model=vmf.ENYPA, maxdist=50000, nmin = 5, nmax = 50, debug.level=-1)
k.MT.hf_mn5_mx50 <- krige(Qs~1, locations=MT, newdata=grd.MT, model=vmf.MT, maxdist=50000, nmin = 5, nmax = 50, debug.level=-1)
k.NWPANY.hf_mn5_mx50 <- krige(Qs~1, locations=NWPANY, newdata=grd.NWPANY, model=vmf.NWPANY, maxdist=50000, nmin = 5, nmax = 50, debug.level=-1)
k.SWPA.hf_mn5_mx50 <- krige(Qs~1, locations=SWPA, newdata=grd.SWPA, model=vmf.SWPA, maxdist=50000, nmin = 5, nmax = 50, debug.level=-1)
k.WPA.hf_mn5_mx50 <- krige(Qs~1, locations=WPA, newdata=grd.WPA, model=vmf.WPA, maxdist=50000, nmin = 5, nmax = 50, debug.level=-1)


##Temp1.5km Autocorrelation##
k.CT.T15_mn5_mx50 <- krige(Tmp1_5k~1, locations=CT, newdata=grd.CT, model=vmf.CT, maxdist=50000, nmin = 5, nmax = 50, debug.level=-1)
k.CNY.T15_mn5_mx50 <- krige(Tmp1_5k~1, locations=CNY, newdata=grd.CNY, model=vmf.CNY, maxdist=40000, nmin = 5, nmax = 50, debug.level=-1)
k.CWV.T15_mn5_mx50 <- krige(Tmp1_5k~1, locations=CWV, newdata=grd.CWV, model=vmf.CWV, maxdist=50000, nmin = 5, nmax = 50, debug.level=-1)
k.ENY.T15_mn5_mx50 <- krige(Tmp1_5k~1, locations=ENY, newdata=grd.ENY, model=vmf.ENY, maxdist=50000, nmin = 5, nmax = 50, debug.level=-1)
k.ENYPA.T15_mn5_mx50 <- krige(Tmp1_5k~1, locations=ENYPA, newdata=grd.ENYPA, model=vmf.ENYPA, maxdist=50000, nmin = 5, nmax = 50, debug.level=-1)
k.MT.T15_mn5_mx50 <- krige(Tmp1_5k~1, locations=MT, newdata=grd.MT, model=vmf.MT, maxdist=50000, nmin = 5, nmax = 50, debug.level=-1)
k.NWPANY.T15_mn5_mx50 <- krige(Tmp1_5k~1, locations=NWPANY, newdata=grd.NWPANY, model=vmf.NWPANY, maxdist=50000, nmin = 5, nmax = 50, debug.level=-1)
k.SWPA.T15_mn5_mx50 <- krige(Tmp1_5k~1, locations=SWPA, newdata=grd.SWPA, model=vmf.SWPA, maxdist=50000, nmin = 5, nmax = 50, debug.level=-1)
k.WPA.T15_mn5_mx50 <- krige(Tmp1_5k~1, locations=WPA, newdata=grd.WPA, model=vmf.WPA, maxdist=50000, nmin = 5, nmax = 50, debug.level=-1)

##Temp2.5km Autocorrelation##
k.CT.T25_mn5_mx50 <- krige(Tmp2_5k~1, locations=CT, newdata=grd.CT, model=vmf.CT, maxdist=50000, nmin = 5, nmax = 50, debug.level=-1)
k.CNY.T25_mn5_mx50 <- krige(Tmp2_5k~1, locations=CNY, newdata=grd.CNY, model=vmf.CNY, maxdist=50000, nmin = 5, nmax = 50, debug.level=-1)
k.CWV.T25_mn5_mx50 <- krige(Tmp2_5k~1, locations=CWV, newdata=grd.CWV, model=vmf.CWV, maxdist=50000, nmin = 5, nmax = 50, debug.level=-1)
k.ENY.T25_mn5_mx50 <- krige(Tmp2_5k~1, locations=ENY, newdata=grd.ENY, model=vmf.ENY, maxdist=50000, nmin = 5, nmax = 50, debug.level=-1)
k.ENYPA.T25_mn5_mx50 <- krige(Tmp2_5k~1, locations=ENYPA, newdata=grd.ENYPA, model=vmf.ENYPA, maxdist=50000, nmin = 5, nmax = 50, debug.level=-1)
k.MT.T25_mn5_mx50 <- krige(Tmp2_5k~1, locations=MT, newdata=grd.MT, model=vmf.MT, maxdist=50000, nmin = 5, nmax = 50, debug.level=-1)
k.NWPANY.T25_mn5_mx50 <- krige(Tmp2_5k~1, locations=NWPANY, newdata=grd.NWPANY, model=vmf.NWPANY, maxdist=50000, nmin = 5, nmax = 50, debug.level=-1)
k.SWPA.T25_mn5_mx50 <- krige(Tmp2_5k~1, locations=SWPA, newdata=grd.SWPA, model=vmf.SWPA, maxdist=50000, nmin = 5, nmax = 50, debug.level=-1)
k.WPA.T25_mn5_mx50 <- krige(Tmp2_5k~1, locations=WPA, newdata=grd.WPA, model=vmf.WPA, maxdist=50000, nmin = 5, nmax = 50, debug.level=-1)

##Temp3.5km Autocorrelation##
k.CT.T35_mn5_mx50 <- krige(Tmp3_5k~1, locations=CT, newdata=grd.CT, model=vmf.CT, maxdist=50000, nmin = 5, nmax = 50, debug.level=-1)
k.CNY.T35_mn5_mx50 <- krige(Tmp3_5k~1, locations=CNY, newdata=grd.CNY, model=vmf.CNY, maxdist=50000, nmin = 5, nmax = 50, debug.level=-1)
k.CWV.T35_mn5_mx50 <- krige(Tmp3_5k~1, locations=CWV, newdata=grd.CWV, model=vmf.CWV, maxdist=50000, nmin = 5, nmax = 50, debug.level=-1)
k.ENY.T35_mn5_mx50 <- krige(Tmp3_5k~1, locations=ENY, newdata=grd.ENY, model=vmf.ENY, maxdist=50000, nmin = 5, nmax = 50, debug.level=-1)
k.ENYPA.T35_mn5_mx50 <- krige(Tmp3_5k~1, locations=ENYPA, newdata=grd.ENYPA, model=vmf.ENYPA, maxdist=50000, nmin = 5, nmax = 50, debug.level=-1)
k.MT.T35_mn5_mx50 <- krige(Tmp3_5k~1, locations=MT, newdata=grd.MT, model=vmf.MT, maxdist=50000, nmin = 5, nmax = 50, debug.level=-1)
k.NWPANY.T35_mn5_mx50 <- krige(Tmp3_5k~1, locations=NWPANY, newdata=grd.NWPANY, model=vmf.NWPANY, maxdist=50000, nmin = 5, nmax = 50, debug.level=-1)
k.SWPA.T35_mn5_mx50 <- krige(Tmp3_5k~1, locations=SWPA, newdata=grd.SWPA, model=vmf.SWPA, maxdist=50000, nmin = 5, nmax = 50, debug.level=-1)
k.WPA.T35_mn5_mx50 <- krige(Tmp3_5k~1, locations=WPA, newdata=grd.WPA, model=vmf.WPA, maxdist=50000, nmin = 5, nmax = 50, debug.level=-1)

##Depth80C Autocorrelation##
k.CT.D80C_mn5_mx50 <- krige(Dpth80C~1, locations=CT, newdata=grd.CT, model=vmf.CT, maxdist=50000, nmin = 5, nmax = 50, debug.level=-1)
k.CNY.D80C_mn5_mx50 <- krige(Dpth80C~1, locations=CNY, newdata=grd.CNY, model=vmf.CNY, maxdist=50000, nmin = 5, nmax = 50, debug.level=-1)
k.CWV.D80C_mn5_mx50 <- krige(Dpth80C~1, locations=CWV, newdata=grd.CWV, model=vmf.CWV, maxdist=50000, nmin = 5, nmax = 50, debug.level=-1)
k.ENY.D80C_mn5_mx50 <- krige(Dpth80C~1, locations=ENY, newdata=grd.ENY, model=vmf.ENY, maxdist=50000, nmin = 5, nmax = 50, debug.level=-1)
k.ENYPA.D80C_mn5_mx50 <- krige(Dpth80C~1, locations=ENYPA, newdata=grd.ENYPA, model=vmf.ENYPA, maxdist=50000, nmin = 5, nmax = 50, debug.level=-1)
k.MT.D80C_mn5_mx50 <- krige(Dpth80C~1, locations=MT, newdata=grd.MT, model=vmf.MT, maxdist=50000, nmin = 5, nmax = 50, debug.level=-1)
k.NWPANY.D80C_mn5_mx50 <- krige(Dpth80C~1, locations=NWPANY, newdata=grd.NWPANY, model=vmf.NWPANY, maxdist=50000, nmin = 5, nmax = 50, debug.level=-1)
k.SWPA.D80C_mn5_mx50 <- krige(Dpth80C~1, locations=SWPA, newdata=grd.SWPA, model=vmf.SWPA, maxdist=50000, nmin = 5, nmax = 50, debug.level=-1)
k.WPA.D80C_mn5_mx50 <- krige(Dpth80C~1, locations=WPA, newdata=grd.WPA, model=vmf.WPA, maxdist=50000, nmin = 5, nmax = 50, debug.level=-1)

##Depth100C Autocorrelation##
k.CT.D100C_mn5_mx50 <- krige(Dpt100C~1, locations=CT, newdata=grd.CT, model=vmf.CT, maxdist=50000, nmin = 5, nmax = 50, debug.level=-1)
k.CNY.D100C_mn5_mx50 <- krige(Dpt100C~1, locations=CNY, newdata=grd.CNY, model=vmf.CNY, maxdist=50000, nmin = 5, nmax = 50, debug.level=-1)
k.CWV.D100C_mn5_mx50 <- krige(Dpt100C~1, locations=CWV, newdata=grd.CWV, model=vmf.CWV, maxdist=50000, nmin = 5, nmax = 50, debug.level=-1)
k.ENY.D100C_mn5_mx50 <- krige(Dpt100C~1, locations=ENY, newdata=grd.ENY, model=vmf.ENY, maxdist=50000, nmin = 5, nmax = 50, debug.level=-1)
k.ENYPA.D100C_mn5_mx50 <- krige(Dpt100C~1, locations=ENYPA, newdata=grd.ENYPA, model=vmf.ENYPA, maxdist=50000, nmin = 5, nmax = 50, debug.level=-1)
k.MT.D100C_mn5_mx50 <- krige(Dpt100C~1, locations=MT, newdata=grd.MT, model=vmf.MT, maxdist=50000, nmin = 5, nmax = 50, debug.level=-1)
k.NWPANY.D100C_mn5_mx50 <- krige(Dpt100C~1, locations=NWPANY, newdata=grd.NWPANY, model=vmf.NWPANY, maxdist=50000, nmin = 5, nmax = 50, debug.level=-1)
k.SWPA.D100C_mn5_mx50 <- krige(Dpt100C~1, locations=SWPA, newdata=grd.SWPA, model=vmf.SWPA, maxdist=50000, nmin = 5, nmax = 50, debug.level=-1)
k.SWPA.D100C_mn5_mx50_U <- krige(Dpt100C~1, locations=SWPA, newdata=grd.SWPA, model=vmf.SWPA, maxdist=50000, nmin = 5, nmax = 50, debug.level=-1)
k.WPA.D100C_mn5_mx50 <- krige(Dpt100C~1, locations=WPA, newdata=grd.WPA, model=vmf.WPA, maxdist=50000, nmin = 5, nmax = 50, debug.level=-1)


##CALCULATE THE STANDARD ERROR OF THE PREDICTED MEAN FROM THE KRIGING VARIANCE OF PREDICTED MEAN##
##Nugget value must come from fitted variogram (vmf). This is located in the "psill" column in row labeled "Nugget", which is row [1]##

#HeatFlow
k.CT.hf_mn5_mx50$nug[1] = vmf.CT$psill[1]
k.CT.hf_mn5_mx50$se = sqrt((k.CT.hf_mn5_mx50$var1.var - k.CT.hf_mn5_mx50$nug[1]))
k.CNY.hf_mn5_mx50$nug[1] = vmf.CNY$psill[1]
k.CNY.hf_mn5_mx50$se = sqrt((k.CNY.hf_mn5_mx50$var1.var - k.CNY.hf_mn5_mx50$nug[1]))
k.CWV.hf_mn5_mx50$nug[1] = vmf.CWV$psill[1]
k.CWV.hf_mn5_mx50$se<- sqrt((k.CWV.hf_mn5_mx50$var1.var - k.CWV.hf_mn5_mx50$nug[1]))
k.ENY.hf_mn5_mx50$nug[1] = vmf.ENY$psill[1]
k.ENY.hf_mn5_mx50$se<- sqrt((k.ENY.hf_mn5_mx50$var1.var - k.ENY.hf_mn5_mx50$nug[1]))
k.ENYPA.hf_mn5_mx50$nug[1] = vmf.ENYPA$psill[1]
k.ENYPA.hf_mn5_mx50$se<- sqrt((k.ENYPA.hf_mn5_mx50$var1.var - k.ENYPA.hf_mn5_mx50$nug[1]))
k.MT.hf_mn5_mx50$nug[1] = vmf.MT$psill[1]
k.MT.hf_mn5_mx50$se<- sqrt((k.MT.hf_mn5_mx50$var1.var - k.MT.hf_mn5_mx50$nug[1]))
k.NWPANY.hf_mn5_mx50$nug[1] = vmf.NWPANY$psill[1]
k.NWPANY.hf_mn5_mx50$se<- sqrt((k.NWPANY.hf_mn5_mx50$var1.var - k.NWPANY.hf_mn5_mx50$nug[1]))
k.SWPA.hf_mn5_mx50$nug[1] = vmf.SWPA$psill[1]
k.SWPA.hf_mn5_mx50$se<- sqrt((k.SWPA.hf_mn5_mx50$var1.var - k.SWPA.hf_mn5_mx50$nug[1]))
#k.VR.hf_mn5_mx50$nug[1] = vmf.VR$psill[1]
#k.VR.hf_mn5_mx50$se<- sqrt((k.VR.hf_mn5_mx50$var1.var - k.VR.hf_mn5_mx50$nug[1]))
k.WPA.hf_mn5_mx50$nug[1] = vmf.WPA$psill[1]
k.WPA.hf_mn5_mx50$se<- sqrt((k.WPA.hf_mn5_mx50$var1.var - k.WPA.hf_mn5_mx50$nug[1]))

#Remove NAs
k.CT.hf_mn5_mx50_narm = k.CT.hf_mn5_mx50[-which(is.na(k.CT.hf_mn5_mx50$var1.pred)==TRUE),]
k.CNY.hf_mn5_mx50_narm = k.CNY.hf_mn5_mx50[-which(is.na(k.CNY.hf_mn5_mx50$var1.pred)==TRUE),]
k.CWV.hf_mn5_mx50_narm = k.CWV.hf_mn5_mx50[-which(is.na(k.CWV.hf_mn5_mx50$var1.pred)==TRUE),]
k.ENY.hf_mn5_mx50_narm = k.ENY.hf_mn5_mx50[-which(is.na(k.ENY.hf_mn5_mx50$var1.pred)==TRUE),]
k.ENYPA.hf_mn5_mx50_narm = k.ENYPA.hf_mn5_mx50[-which(is.na(k.ENYPA.hf_mn5_mx50$var1.pred)==TRUE),]
k.MT.hf_mn5_mx50_narm = k.MT.hf_mn5_mx50[-which(is.na(k.MT.hf_mn5_mx50$var1.pred)==TRUE),]
k.NWPANY.hf_mn5_mx50_narm = k.NWPANY.hf_mn5_mx50[-which(is.na(k.NWPANY.hf_mn5_mx50$var1.pred)==TRUE),]
k.SWPA.hf_mn5_mx50_narm = k.SWPA.hf_mn5_mx50[-which(is.na(k.SWPA.hf_mn5_mx50$var1.pred)==TRUE),]
#k.VR.hf_mn5_mx50_narm = k.VR.hf_mn5_mx50[-which(is.na(k.VR.hf_mn5_mx50$var1.pred)==TRUE),]
k.WPA.hf_mn5_mx50_narm = k.WPA.hf_mn5_mx50[-which(is.na(k.WPA.hf_mn5_mx50$var1.pred)==TRUE),]


#Temp1_5
#nmax is 50, nmin is 5, 50 km interpolation distance.
k.CT.T15_mn5_mx50$nug[1] = vmf.CT$psill[1]
k.CT.T15_mn5_mx50$se = sqrt((k.CT.T15_mn5_mx50$var1.var - k.CT.T15_mn5_mx50$nug[1]))
k.CNY.T15_mn5_mx50$nug[1] = vmf.CNY$psill[1]
k.CNY.T15_mn5_mx50$se = sqrt((k.CNY.T15_mn5_mx50$var1.var - k.CNY.T15_mn5_mx50$nug[1]))
k.CWV.T15_mn5_mx50$nug[1] = vmf.CWV$psill[1]
k.CWV.T15_mn5_mx50$se<- sqrt((k.CWV.T15_mn5_mx50$var1.var - k.CWV.T15_mn5_mx50$nug[1]))
k.ENY.T15_mn5_mx50$nug[1] = vmf.ENY$psill[1]
k.ENY.T15_mn5_mx50$se<- sqrt((k.ENY.T15_mn5_mx50$var1.var - k.ENY.T15_mn5_mx50$nug[1]))
k.ENYPA.T15_mn5_mx50$nug[1] = vmf.ENYPA$psill[1]
k.ENYPA.T15_mn5_mx50$se<- sqrt((k.ENYPA.T15_mn5_mx50$var1.var - k.ENYPA.T15_mn5_mx50$nug[1]))
k.MT.T15_mn5_mx50$nug[1] = vmf.MT$psill[1]
k.MT.T15_mn5_mx50$se<- sqrt((k.MT.T15_mn5_mx50$var1.var - k.MT.T15_mn5_mx50$nug[1]))
k.NWPANY.T15_mn5_mx50$nug[1] = vmf.NWPANY$psill[1]
k.NWPANY.T15_mn5_mx50$se<- sqrt((k.NWPANY.T15_mn5_mx50$var1.var - k.NWPANY.T15_mn5_mx50$nug[1]))
k.SWPA.T15_mn5_mx50$nug[1] = vmf.SWPA$psill[1]
k.SWPA.T15_mn5_mx50$se<- sqrt((k.SWPA.T15_mn5_mx50$var1.var - k.SWPA.T15_mn5_mx50$nug[1]))
k.WPA.T15_mn5_mx50$nug[1] = vmf.WPA$psill[1]
k.WPA.T15_mn5_mx50$se<- sqrt((k.WPA.T15_mn5_mx50$var1.var - k.WPA.T15_mn5_mx50$nug[1]))

#Remove NAs
#nmax is 50, nmin is 5, 50 km interpolation distance.
k.CT.T15_mn5_mx50_narm = k.CT.T15_mn5_mx50[-which(is.na(k.CT.T15_mn5_mx50$var1.pred)==TRUE),]
k.CNY.T15_mn5_mx50_narm = k.CNY.T15_mn5_mx50[-which(is.na(k.CNY.T15_mn5_mx50$var1.pred)==TRUE),]
k.CWV.T15_mn5_mx50_narm = k.CWV.T15_mn5_mx50[-which(is.na(k.CWV.T15_mn5_mx50$var1.pred)==TRUE),]
k.ENY.T15_mn5_mx50_narm = k.ENY.T15_mn5_mx50[-which(is.na(k.ENY.T15_mn5_mx50$var1.pred)==TRUE),]
k.ENYPA.T15_mn5_mx50_narm = k.ENYPA.T15_mn5_mx50[-which(is.na(k.ENYPA.T15_mn5_mx50$var1.pred)==TRUE),]
k.MT.T15_mn5_mx50_narm = k.MT.T15_mn5_mx50[-which(is.na(k.MT.T15_mn5_mx50$var1.pred)==TRUE),]
k.NWPANY.T15_mn5_mx50_narm = k.NWPANY.T15_mn5_mx50[-which(is.na(k.NWPANY.T15_mn5_mx50$var1.pred)==TRUE),]
k.SWPA.T15_mn5_mx50_narm = k.SWPA.T15_mn5_mx50[-which(is.na(k.SWPA.T15_mn5_mx50$var1.pred)==TRUE),]
k.WPA.T15_mn5_mx50_narm = k.WPA.T15_mn5_mx50[-which(is.na(k.WPA.T15_mn5_mx50$var1.pred)==TRUE),]


#Temp2_5
#nmax is 50, nmin is 5, 50 km interpolation distance.
k.CT.T25_mn5_mx50$nug[1] = vmf.CT$psill[1]
k.CT.T25_mn5_mx50$se = sqrt((k.CT.T25_mn5_mx50$var1.var - k.CT.T25_mn5_mx50$nug[1]))
k.CNY.T25_mn5_mx50$nug[1] = vmf.CNY$psill[1]
k.CNY.T25_mn5_mx50$se = sqrt((k.CNY.T25_mn5_mx50$var1.var - k.CNY.T25_mn5_mx50$nug[1]))
k.CWV.T25_mn5_mx50$nug[1] = vmf.CWV$psill[1]
k.CWV.T25_mn5_mx50$se<- sqrt((k.CWV.T25_mn5_mx50$var1.var - k.CWV.T25_mn5_mx50$nug[1]))
k.ENY.T25_mn5_mx50$nug[1] = vmf.ENY$psill[1]
k.ENY.T25_mn5_mx50$se<- sqrt((k.ENY.T25_mn5_mx50$var1.var - k.ENY.T25_mn5_mx50$nug[1]))
k.ENYPA.T25_mn5_mx50$nug[1] = vmf.ENYPA$psill[1]
k.ENYPA.T25_mn5_mx50$se<- sqrt((k.ENYPA.T25_mn5_mx50$var1.var - k.ENYPA.T25_mn5_mx50$nug[1]))
k.MT.T25_mn5_mx50$nug[1] = vmf.MT$psill[1]
k.MT.T25_mn5_mx50$se<- sqrt((k.MT.T25_mn5_mx50$var1.var - k.MT.T25_mn5_mx50$nug[1]))
k.NWPANY.T25_mn5_mx50$nug[1] = vmf.NWPANY$psill[1]
k.NWPANY.T25_mn5_mx50$se<- sqrt((k.NWPANY.T25_mn5_mx50$var1.var - k.NWPANY.T25_mn5_mx50$nug[1]))
k.SWPA.T25_mn5_mx50$nug[1] = vmf.SWPA$psill[1]
k.SWPA.T25_mn5_mx50$se<- sqrt((k.SWPA.T25_mn5_mx50$var1.var - k.SWPA.T25_mn5_mx50$nug[1]))
k.WPA.T25_mn5_mx50$nug[1] = vmf.WPA$psill[1]
k.WPA.T25_mn5_mx50$se<- sqrt((k.WPA.T25_mn5_mx50$var1.var - k.WPA.T25_mn5_mx50$nug[1]))

#Remove NAs
#nmax is 50, nmin is 5, 50 km interpolation distance.
k.CT.T25_mn5_mx50_narm = k.CT.T25_mn5_mx50[-which(is.na(k.CT.T25_mn5_mx50$var1.pred)==TRUE),]
k.CNY.T25_mn5_mx50_narm = k.CNY.T25_mn5_mx50[-which(is.na(k.CNY.T25_mn5_mx50$var1.pred)==TRUE),]
k.CWV.T25_mn5_mx50_narm = k.CWV.T25_mn5_mx50[-which(is.na(k.CWV.T25_mn5_mx50$var1.pred)==TRUE),]
k.ENY.T25_mn5_mx50_narm = k.ENY.T25_mn5_mx50[-which(is.na(k.ENY.T25_mn5_mx50$var1.pred)==TRUE),]
k.ENYPA.T25_mn5_mx50_narm = k.ENYPA.T25_mn5_mx50[-which(is.na(k.ENYPA.T25_mn5_mx50$var1.pred)==TRUE),]
k.MT.T25_mn5_mx50_narm = k.MT.T25_mn5_mx50[-which(is.na(k.MT.T25_mn5_mx50$var1.pred)==TRUE),]
k.NWPANY.T25_mn5_mx50_narm = k.NWPANY.T25_mn5_mx50[-which(is.na(k.NWPANY.T25_mn5_mx50$var1.pred)==TRUE),]
k.SWPA.T25_mn5_mx50_narm = k.SWPA.T25_mn5_mx50[-which(is.na(k.SWPA.T25_mn5_mx50$var1.pred)==TRUE),]
k.WPA.T25_mn5_mx50_narm = k.WPA.T25_mn5_mx50[-which(is.na(k.WPA.T25_mn5_mx50$var1.pred)==TRUE),]


#Temp3_5
#nmax is 50, nmin is 5, 50 km interpolation distance.
k.CT.T35_mn5_mx50$nug[1] = vmf.CT$psill[1]
k.CT.T35_mn5_mx50$se = sqrt((k.CT.T35_mn5_mx50$var1.var - k.CT.T35_mn5_mx50$nug[1]))
k.CNY.T35_mn5_mx50$nug[1] = vmf.CNY$psill[1]
k.CNY.T35_mn5_mx50$se = sqrt((k.CNY.T35_mn5_mx50$var1.var - k.CNY.T35_mn5_mx50$nug[1]))
k.CWV.T35_mn5_mx50$nug[1] = vmf.CWV$psill[1]
k.CWV.T35_mn5_mx50$se<- sqrt((k.CWV.T35_mn5_mx50$var1.var - k.CWV.T35_mn5_mx50$nug[1]))
k.ENY.T35_mn5_mx50$nug[1] = vmf.ENY$psill[1]
k.ENY.T35_mn5_mx50$se<- sqrt((k.ENY.T35_mn5_mx50$var1.var - k.ENY.T35_mn5_mx50$nug[1]))
k.ENYPA.T35_mn5_mx50$nug[1] = vmf.ENYPA$psill[1]
k.ENYPA.T35_mn5_mx50$se<- sqrt((k.ENYPA.T35_mn5_mx50$var1.var - k.ENYPA.T35_mn5_mx50$nug[1]))
k.MT.T35_mn5_mx50$nug[1] = vmf.MT$psill[1]
k.MT.T35_mn5_mx50$se<- sqrt((k.MT.T35_mn5_mx50$var1.var - k.MT.T35_mn5_mx50$nug[1]))
k.NWPANY.T35_mn5_mx50$nug[1] = vmf.NWPANY$psill[1]
k.NWPANY.T35_mn5_mx50$se<- sqrt((k.NWPANY.T35_mn5_mx50$var1.var - k.NWPANY.T35_mn5_mx50$nug[1]))
k.SWPA.T35_mn5_mx50$nug[1] = vmf.SWPA$psill[1]
k.SWPA.T35_mn5_mx50$se<- sqrt((k.SWPA.T35_mn5_mx50$var1.var - k.SWPA.T35_mn5_mx50$nug[1]))
k.WPA.T35_mn5_mx50$nug[1] = vmf.WPA$psill[1]
k.WPA.T35_mn5_mx50$se<- sqrt((k.WPA.T35_mn5_mx50$var1.var - k.WPA.T35_mn5_mx50$nug[1]))

#Remove NAs
#nmax is 50, nmin is 5, 50 km interpolation distance.
k.CT.T35_mn5_mx50_narm = k.CT.T35_mn5_mx50[-which(is.na(k.CT.T35_mn5_mx50$var1.pred)==TRUE),]
k.CNY.T35_mn5_mx50_narm = k.CNY.T35_mn5_mx50[-which(is.na(k.CNY.T35_mn5_mx50$var1.pred)==TRUE),]
k.CWV.T35_mn5_mx50_narm = k.CWV.T35_mn5_mx50[-which(is.na(k.CWV.T35_mn5_mx50$var1.pred)==TRUE),]
k.ENY.T35_mn5_mx50_narm = k.ENY.T35_mn5_mx50[-which(is.na(k.ENY.T35_mn5_mx50$var1.pred)==TRUE),]
k.ENYPA.T35_mn5_mx50_narm = k.ENYPA.T35_mn5_mx50[-which(is.na(k.ENYPA.T35_mn5_mx50$var1.pred)==TRUE),]
k.MT.T35_mn5_mx50_narm = k.MT.T35_mn5_mx50[-which(is.na(k.MT.T35_mn5_mx50$var1.pred)==TRUE),]
k.NWPANY.T35_mn5_mx50_narm = k.NWPANY.T35_mn5_mx50[-which(is.na(k.NWPANY.T35_mn5_mx50$var1.pred)==TRUE),]
k.SWPA.T35_mn5_mx50_narm = k.SWPA.T35_mn5_mx50[-which(is.na(k.SWPA.T35_mn5_mx50$var1.pred)==TRUE),]
k.WPA.T35_mn5_mx50_narm = k.WPA.T35_mn5_mx50[-which(is.na(k.WPA.T35_mn5_mx50$var1.pred)==TRUE),]


#Depth80C
#nmax is 50, nmin is 5, 50 km interpolation distance.
k.CT.D80C_mn5_mx50$nug[1] = vmf.CT$psill[1]
k.CT.D80C_mn5_mx50$se = sqrt((k.CT.D80C_mn5_mx50$var1.var - k.CT.D80C_mn5_mx50$nug[1]))
k.CNY.D80C_mn5_mx50$nug[1] = vmf.CNY$psill[1]
k.CNY.D80C_mn5_mx50$se = sqrt((k.CNY.D80C_mn5_mx50$var1.var - k.CNY.D80C_mn5_mx50$nug[1]))
k.CWV.D80C_mn5_mx50$nug[1] = vmf.CWV$psill[1]
k.CWV.D80C_mn5_mx50$se<- sqrt((k.CWV.D80C_mn5_mx50$var1.var - k.CWV.D80C_mn5_mx50$nug[1]))
k.ENY.D80C_mn5_mx50$nug[1] = vmf.ENY$psill[1]
k.ENY.D80C_mn5_mx50$se<- sqrt((k.ENY.D80C_mn5_mx50$var1.var - k.ENY.D80C_mn5_mx50$nug[1]))
k.ENYPA.D80C_mn5_mx50$nug[1] = vmf.ENYPA$psill[1]
k.ENYPA.D80C_mn5_mx50$se<- sqrt((k.ENYPA.D80C_mn5_mx50$var1.var - k.ENYPA.D80C_mn5_mx50$nug[1]))
k.MT.D80C_mn5_mx50$nug[1] = vmf.MT$psill[1]
k.MT.D80C_mn5_mx50$se<- sqrt((k.MT.D80C_mn5_mx50$var1.var - k.MT.D80C_mn5_mx50$nug[1]))
k.NWPANY.D80C_mn5_mx50$nug[1] = vmf.NWPANY$psill[1]
k.NWPANY.D80C_mn5_mx50$se<- sqrt((k.NWPANY.D80C_mn5_mx50$var1.var - k.NWPANY.D80C_mn5_mx50$nug[1]))
k.SWPA.D80C_mn5_mx50$nug[1] = vmf.SWPA$psill[1]
k.SWPA.D80C_mn5_mx50$se<- sqrt((k.SWPA.D80C_mn5_mx50$var1.var - k.SWPA.D80C_mn5_mx50$nug[1]))
k.WPA.D80C_mn5_mx50$nug[1] = vmf.WPA$psill[1]
k.WPA.D80C_mn5_mx50$se<- sqrt((k.WPA.D80C_mn5_mx50$var1.var - k.WPA.D80C_mn5_mx50$nug[1]))

#Remove NAs
#nmax is 50, nmin is 5, 50 km interpolation distance.
k.CT.D80C_mn5_mx50_narm = k.CT.D80C_mn5_mx50[-which(is.na(k.CT.D80C_mn5_mx50$var1.pred)==TRUE),]
k.CNY.D80C_mn5_mx50_narm = k.CNY.D80C_mn5_mx50[-which(is.na(k.CNY.D80C_mn5_mx50$var1.pred)==TRUE),]
k.CWV.D80C_mn5_mx50_narm = k.CWV.D80C_mn5_mx50[-which(is.na(k.CWV.D80C_mn5_mx50$var1.pred)==TRUE),]
k.ENY.D80C_mn5_mx50_narm = k.ENY.D80C_mn5_mx50[-which(is.na(k.ENY.D80C_mn5_mx50$var1.pred)==TRUE),]
k.ENYPA.D80C_mn5_mx50_narm = k.ENYPA.D80C_mn5_mx50[-which(is.na(k.ENYPA.D80C_mn5_mx50$var1.pred)==TRUE),]
k.MT.D80C_mn5_mx50_narm = k.MT.D80C_mn5_mx50[-which(is.na(k.MT.D80C_mn5_mx50$var1.pred)==TRUE),]
k.NWPANY.D80C_mn5_mx50_narm = k.NWPANY.D80C_mn5_mx50[-which(is.na(k.NWPANY.D80C_mn5_mx50$var1.pred)==TRUE),]
k.SWPA.D80C_mn5_mx50_narm = k.SWPA.D80C_mn5_mx50[-which(is.na(k.SWPA.D80C_mn5_mx50$var1.pred)==TRUE),]
k.WPA.D80C_mn5_mx50_narm = k.WPA.D80C_mn5_mx50[-which(is.na(k.WPA.D80C_mn5_mx50$var1.pred)==TRUE),]


#Depth100C
#nmax is 50, nmin is 5, 50 km interpolation distance.
k.CT.D100C_mn5_mx50$nug[1] = vmf.CT$psill[1]
k.CT.D100C_mn5_mx50$se = sqrt((k.CT.D100C_mn5_mx50$var1.var - k.CT.D100C_mn5_mx50$nug[1]))
k.CNY.D100C_mn5_mx50$nug[1] = vmf.CNY$psill[1]
k.CNY.D100C_mn5_mx50$se = sqrt((k.CNY.D100C_mn5_mx50$var1.var - k.CNY.D100C_mn5_mx50$nug[1]))
k.CWV.D100C_mn5_mx50$nug[1] = vmf.CWV$psill[1]
k.CWV.D100C_mn5_mx50$se<- sqrt((k.CWV.D100C_mn5_mx50$var1.var - k.CWV.D100C_mn5_mx50$nug[1]))
k.ENY.D100C_mn5_mx50$nug[1] = vmf.ENY$psill[1]
k.ENY.D100C_mn5_mx50$se<- sqrt((k.ENY.D100C_mn5_mx50$var1.var - k.ENY.D100C_mn5_mx50$nug[1]))
k.ENYPA.D100C_mn5_mx50$nug[1] = vmf.ENYPA$psill[1]
k.ENYPA.D100C_mn5_mx50$se<- sqrt((k.ENYPA.D100C_mn5_mx50$var1.var - k.ENYPA.D100C_mn5_mx50$nug[1]))
k.MT.D100C_mn5_mx50$nug[1] = vmf.MT$psill[1]
k.MT.D100C_mn5_mx50$se<- sqrt((k.MT.D100C_mn5_mx50$var1.var - k.MT.D100C_mn5_mx50$nug[1]))
k.NWPANY.D100C_mn5_mx50$nug[1] = vmf.NWPANY$psill[1]
k.NWPANY.D100C_mn5_mx50$se<- sqrt((k.NWPANY.D100C_mn5_mx50$var1.var - k.NWPANY.D100C_mn5_mx50$nug[1]))
k.SWPA.D100C_mn5_mx50$nug[1] = vmf.SWPA$psill[1]
k.SWPA.D100C_mn5_mx50$se<- sqrt((k.SWPA.D100C_mn5_mx50$var1.var - k.SWPA.D100C_mn5_mx50$nug[1]))
k.SWPA.D100C_mn5_mx50_U$nug[1] = vmf.SWPA$psill[1]
k.SWPA.D100C_mn5_mx50_U$se<- sqrt((k.SWPA.D100C_mn5_mx50_U$var1.var - k.SWPA.D100C_mn5_mx50_U$nug[1]))
k.WPA.D100C_mn5_mx50$nug[1] = vmf.WPA$psill[1]
k.WPA.D100C_mn5_mx50$se<- sqrt((k.WPA.D100C_mn5_mx50$var1.var - k.WPA.D100C_mn5_mx50$nug[1]))

#Remove NAs
#nmax is 50, nmin is 5, 50 km interpolation distance.
k.CT.D100C_mn5_mx50_narm = k.CT.D100C_mn5_mx50[-which(is.na(k.CT.D100C_mn5_mx50$var1.pred)==TRUE),]
k.CNY.D100C_mn5_mx50_narm = k.CNY.D100C_mn5_mx50[-which(is.na(k.CNY.D100C_mn5_mx50$var1.pred)==TRUE),]
k.CWV.D100C_mn5_mx50_narm = k.CWV.D100C_mn5_mx50[-which(is.na(k.CWV.D100C_mn5_mx50$var1.pred)==TRUE),]
k.ENY.D100C_mn5_mx50_narm = k.ENY.D100C_mn5_mx50[-which(is.na(k.ENY.D100C_mn5_mx50$var1.pred)==TRUE),]
k.ENYPA.D100C_mn5_mx50_narm = k.ENYPA.D100C_mn5_mx50[-which(is.na(k.ENYPA.D100C_mn5_mx50$var1.pred)==TRUE),]
k.MT.D100C_mn5_mx50_narm = k.MT.D100C_mn5_mx50[-which(is.na(k.MT.D100C_mn5_mx50$var1.pred)==TRUE),]
k.NWPANY.D100C_mn5_mx50_narm = k.NWPANY.D100C_mn5_mx50[-which(is.na(k.NWPANY.D100C_mn5_mx50$var1.pred)==TRUE),]
k.SWPA.D100C_mn5_mx50_narm = k.SWPA.D100C_mn5_mx50[-which(is.na(k.SWPA.D100C_mn5_mx50$var1.pred)==TRUE),]
k.SWPA.D100C_mn5_mx50_narm_U = k.SWPA.D100C_mn5_mx50[-which(is.na(k.SWPA.D100C_mn5_mx50$var1.pred)==TRUE),]
k.WPA.D100C_mn5_mx50_narm = k.WPA.D100C_mn5_mx50[-which(is.na(k.WPA.D100C_mn5_mx50$var1.pred)==TRUE),]


##EXPORT GRID TO GIS##
#Heatflow
writeGDAL(k.CT.hf_mn5_mx50_narm, "k_CT_hf_mn5_mx50.tif", driver="GTiff")
writeGDAL(k.CNY.hf_mn5_mx50_narm, "k_CNY_hf_mn5_mx50.tif", driver="GTiff")
writeGDAL(k.CWV.hf_mn5_mx50_narm, "k_CWV_hf_mn5_mx50.tif", driver="GTiff")
writeGDAL(k.ENY.hf_mn5_mx50_narm, "k_ENY_hf_mn5_mx50.tif", driver="GTiff")
writeGDAL(k.ENYPA.hf_mn5_mx50_narm, "k_ENYPA_hf_mn5_mx50.tif", driver="GTiff")
writeGDAL(k.MT.hf_mn5_mx50_narm, "k_MT_hf_mn5_mx50.tif", driver="GTiff")
writeGDAL(k.NWPANY.hf_mn5_mx50_narm, "k_NWPANY_hf_mn5_mx50.tif", driver="GTiff")
writeGDAL(k.SWPA.hf_mn5_mx50_narm, "k_SWPA_hf_mn5_mx50.tif", driver="GTiff")
#writeGDAL(k.VR.hf_mn5_mx50_narm, "k_VR_hf_mn5_mx50.tif", driver="GTiff")
writeGDAL(k.WPA.hf_mn5_mx50_narm, "k_WPA_hf_mn5_mx50.tif", driver="GTiff")


#Temp1.5km
writeGDAL(k.CT.T15_mn5_mx50_narm, "k_CT_T15_mn5_mx50.tif", driver="GTiff")
writeGDAL(k.CNY.T15_mn5_mx50_narm, "k_CNY_T15_mn5_mx50.tif", driver="GTiff")
writeGDAL(k.CWV.T15_mn5_mx50_narm, "k_CWV_T15_mn5_mx50.tif", driver="GTiff")
writeGDAL(k.ENY.T15_mn5_mx50_narm, "k_ENY_T15_mn5_mx50.tif", driver="GTiff")
writeGDAL(k.ENYPA.T15_mn5_mx50_narm, "k_ENYPA_T15_mn5_mx50.tif", driver="GTiff")
writeGDAL(k.MT.T15_mn5_mx50_narm, "k_MT_T15_mn5_mx50.tif", driver="GTiff")
writeGDAL(k.NWPANY.T15_mn5_mx50_narm, "k_NWPANY_T15_mn5_mx50.tif", driver="GTiff")
writeGDAL(k.SWPA.T15_mn5_mx50_narm, "k_SWPA_T15_mn5_mx50.tif", driver="GTiff")
writeGDAL(k.WPA.T15_mn5_mx50_narm, "k_WPA_T15_mn5_mx50.tif", driver="GTiff")


#Temp2.5km
writeGDAL(k.CT.T25_mn5_mx50_narm, "k_CT_T25_mn5_mx50.tif", driver="GTiff")
writeGDAL(k.CNY.T25_mn5_mx50_narm, "k_CNY_T25_mn5_mx50.tif", driver="GTiff")
writeGDAL(k.CWV.T25_mn5_mx50_narm, "k_CWV_T25_mn5_mx50.tif", driver="GTiff")
writeGDAL(k.ENY.T25_mn5_mx50_narm, "k_ENY_T25_mn5_mx50.tif", driver="GTiff")
writeGDAL(k.ENYPA.T25_mn5_mx50_narm, "k_ENYPA_T25_mn5_mx50.tif", driver="GTiff")
writeGDAL(k.MT.T25_mn5_mx50_narm, "k_MT_T25_mn5_mx50.tif", driver="GTiff")
writeGDAL(k.NWPANY.T25_mn5_mx50_narm, "k_NWPANY_T25_mn5_mx50.tif", driver="GTiff")
writeGDAL(k.SWPA.T25_mn5_mx50_narm, "k_SWPA_T25_mn5_mx50.tif", driver="GTiff")
writeGDAL(k.WPA.T25_mn5_mx50_narm, "k_WPA_T25_mn5_mx50.tif", driver="GTiff")

#Temp3.5km
writeGDAL(k.CT.T35_mn5_mx50_narm, "k_CT_T35_mn5_mx50.tif", driver="GTiff")
writeGDAL(k.CNY.T35_mn5_mx50_narm, "k_CNY_T35_mn5_mx50.tif", driver="GTiff")
writeGDAL(k.CWV.T35_mn5_mx50_narm, "k_CWV_T35_mn5_mx50.tif", driver="GTiff")
writeGDAL(k.ENY.T35_mn5_mx50_narm, "k_ENY_T35_mn5_mx50.tif", driver="GTiff")
writeGDAL(k.ENYPA.T35_mn5_mx50_narm, "k_ENYPA_T35_mn5_mx50.tif", driver="GTiff")
writeGDAL(k.MT.T35_mn5_mx50_narm, "k_MT_T35_mn5_mx50.tif", driver="GTiff")
writeGDAL(k.NWPANY.T35_mn5_mx50_narm, "k_NWPANY_T35_mn5_mx50.tif", driver="GTiff")
writeGDAL(k.SWPA.T35_mn5_mx50_narm, "k_SWPA_T35_mn5_mx50.tif", driver="GTiff")
writeGDAL(k.WPA.T35_mn5_mx50_narm, "k_WPA_T35_mn5_mx50.tif", driver="GTiff")

#Depth80C
#nmax is 50, nmin is 5, 50 km interpolation distance.
writeGDAL(k.CT.D80C_mn5_mx50_narm, "k_CT_D80C_mn5_mx50.tif", driver="GTiff")
writeGDAL(k.CNY.D80C_mn5_mx50_narm, "k_CNY_D80C_mn5_mx50.tif", driver="GTiff")
writeGDAL(k.CWV.D80C_mn5_mx50_narm, "k_CWV_D80C_mn5_mx50.tif", driver="GTiff")
writeGDAL(k.ENY.D80C_mn5_mx50_narm, "k_ENY_D80C_mn5_mx50.tif", driver="GTiff")
writeGDAL(k.ENYPA.D80C_mn5_mx50_narm, "k_ENYPA_D80C_mn5_mx50.tif", driver="GTiff")
writeGDAL(k.MT.D80C_mn5_mx50_narm, "k_MT_D80C_mn5_mx50.tif", driver="GTiff")
writeGDAL(k.NWPANY.D80C_mn5_mx50_narm, "k_NWPANY_D80C_mn5_mx50.tif", driver="GTiff")
writeGDAL(k.SWPA.D80C_mn5_mx50_narm, "k_SWPA_D80C_mn5_mx50.tif", driver="GTiff")
writeGDAL(k.WPA.D80C_mn5_mx50_narm, "k_WPA_D80C_mn5_mx50.tif", driver="GTiff")

#Depth100C
#nmax is 50, nmin is 5, 50 km interpolation distance.
writeGDAL(k.CT.D100C_mn5_mx50_narm, "k_CT_D100C_mn5_mx50.tif", driver="GTiff")
writeGDAL(k.CNY.D100C_mn5_mx50_narm, "k_CNY_D100C_mn5_mx50.tif", driver="GTiff")
writeGDAL(k.CWV.D100C_mn5_mx50_narm, "k_CWV_D100C_mn5_mx50.tif", driver="GTiff")
writeGDAL(k.ENY.D100C_mn5_mx50_narm, "k_ENY_D100C_mn5_mx50.tif", driver="GTiff")
writeGDAL(k.ENYPA.D100C_mn5_mx50_narm, "k_ENYPA_D100C_mn5_mx50.tif", driver="GTiff")
writeGDAL(k.MT.D100C_mn5_mx50_narm, "k_MT_D100C_mn5_mx50.tif", driver="GTiff")
writeGDAL(k.NWPANY.D100C_mn5_mx50_narm, "k_NWPANY_D100C_mn5_mx50.tif", driver="GTiff")
writeGDAL(k.SWPA.D100C_mn5_mx50_narm, "k_SWPA_D100C_mn5_mx50.tif", driver="GTiff")
writeGDAL(k.SWPA.D100C_mn5_mx50_narm_U, "k_SWPA_D100C_mn5_mx50_U.tif", driver="GTiff")
writeGDAL(k.WPA.D100C_mn5_mx50_narm, "k_WPA_D100C_mn5_mx50.tif", driver="GTiff")